@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -44,7 +44,7 @@ class ArcObstacle : public Obstacle {
 		float _rotation, float _angle, float _ratio,
 		const float _texsize[4], bool _useNormals,
 		int _divisions, const BzMaterial* mats[MaterialCount],
-		int physics, bool bounce, bool drive, bool shoot);
+		int physics, bool bounce, bool drive, bool shoot, bool ricochet);
     ~ArcObstacle();
 
     Obstacle* copyWithTransform(const MeshTransform&) const;
@@ -77,7 +77,7 @@ class ArcObstacle : public Obstacle {
 
     int packSize() const;
     void *pack(void*) const;
-    void *unpack(void*);
+    const void *unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
 
@@ -112,4 +112,3 @@ class ArcObstacle : public Obstacle {
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
