@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -44,7 +44,7 @@ class BzMaterial {
 
     void reset();
 
-    void setReference();
+    void setReference() const;	// const exploits mutable "referenced" variable below
     bool getReference() const;
 
     //
@@ -128,7 +128,7 @@ class BzMaterial {
 
     int packSize() const;
     void *pack(void *) const;
-    void *unpack(void *);
+    const void *unpack(const void *);
 
     void print(std::ostream& out, const std::string& indent) const;
     void printMTL(std::ostream& out, const std::string& indent) const;
@@ -140,7 +140,7 @@ class BzMaterial {
     std::string name;
     std::vector<std::string> aliases;
 
-    bool referenced;
+    mutable bool referenced;
 
     int dynamicColor;
     float ambient[4];
@@ -194,7 +194,7 @@ inline const BzMaterial* BzMaterial::getDefault()
   return &defaultMaterial;
 }
 
-inline void BzMaterial::setReference()
+inline void BzMaterial::setReference() const
 {
   referenced = true;
   return;
@@ -222,7 +222,7 @@ class BzMaterialManager {
     void setTextureLocal(const std::string& url, const std::string& local);
 
     void* pack(void*);
-    void* unpack(void*);
+    const void* unpack(const void*);
     int packSize();
 
     void print(std::ostream& out, const std::string& indent) const;
@@ -247,4 +247,3 @@ extern BzMaterialManager MATERIALMGR;
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
