@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -31,8 +31,8 @@ class CacheManager {
       std::string key;
     } CacheRecord;
 
-    bool isCacheFileType(const std::string name) const;
-    std::string getLocalName(const std::string name) const;
+    bool isCacheFileType(const std::string &name) const;
+    std::string getLocalName(const std::string &name) const;
 
     bool loadIndex();
     bool saveIndex();
