@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -49,7 +49,7 @@ typedef union {
 
 typedef struct {
   int count;
-  class ColDetNode** list;
+  const class ColDetNode** list;
 } ColDetNodeList;
 
 
