@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -42,7 +42,7 @@ class ConeObstacle : public Obstacle {
 		 float _rotation, float _angle,
 		 const float _texsize[2], bool _useNormals,
 		 int _divisions, const BzMaterial* mats[MaterialCount],
-		 int physics, bool bounce, bool drive, bool shoot);
+		 int physics, bool bounce, bool drive, bool shoot, bool ricochet);
     ~ConeObstacle();
 
     Obstacle* copyWithTransform(const MeshTransform&) const;
@@ -74,7 +74,7 @@ class ConeObstacle : public Obstacle {
 
     int packSize() const;
     void *pack(void*) const;
-    void *unpack(void*);
+    const void *unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
 
@@ -104,4 +104,3 @@ class ConeObstacle : public Obstacle {
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
