@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -25,7 +25,7 @@ class PyramidBuilding : public Obstacle {
   public:
 			PyramidBuilding();
 			PyramidBuilding(const float* pos, float rotation,
-				float width, float breadth, float height, bool drive = false, bool shoot = false);
+				float width, float breadth, float height, bool drive = false, bool shoot = false, bool ricochet = false);
 			~PyramidBuilding();
 
     virtual Obstacle*	copyWithTransform(const MeshTransform&) const;
@@ -60,7 +60,7 @@ class PyramidBuilding : public Obstacle {
 
     int packSize() const;
     void *pack(void*) const;
-    void *unpack(void*);
+    const void *unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
     void printOBJ(std::ostream& out, const std::string& indent) const;
@@ -86,4 +86,3 @@ class PyramidBuilding : public Obstacle {
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
