@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,13 +7,14 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef	BZF_RAY_H
 #define	BZF_RAY_H
 
 #include "common.h"
+#include <string.h> // for memset()
 
 /** Encapsulates a semi-infinite ray. */
 
@@ -38,10 +39,7 @@ class Ray {
 // Ray
 //
 
-inline Ray::Ray()
-{
-  memset(o, 0, sizeof(float) * 3);
-}
+inline Ray::Ray(){memset(o,0,sizeof(float)*3); memset(d,0,sizeof(float)*3);}
 
 inline Ray::~Ray()
 {
@@ -67,4 +65,3 @@ inline const float*	Ray::getDirection() const
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
