@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,10 +17,6 @@
 #ifndef	BZF_SCENE_RENDERER_H
 #define	BZF_SCENE_RENDERER_H
 
-#if defined(_MSC_VER)
-#pragma warning(disable: 4786)
-#endif
-
 /* the common header */
 #include "common.h"
 
@@ -34,6 +30,7 @@
 #include "OpenGLLight.h"
 #include "ViewFrustum.h"
 #include "RenderNode.h"
+#include "vectors.h"
 
 #define RENDERER (SceneRenderer::instance())
 
@@ -78,7 +75,10 @@ public:
   bool		useWireframe() const;
   bool		useHiddenLine() const;
   float		getPanelOpacity() const;
+  float         getRadarOpacity() const;
+  bool          isPanelOpaque() const;
   int		getRadarSize() const;
+  int		getPanelHeight() const;
   int		getMaxMotionFactor() const;
   bool		isLastFrame() const;
   bool		isSameFrame() const;
@@ -92,7 +92,9 @@ public:
   void		setWireframe(bool on);
   void		setHiddenLine(bool on);
   void		setPanelOpacity(float opacity);
+  void          setRadarOpacity(float opacity);
   void		setRadarSize(int size);
+  void		setPanelHeight(int size);
   void		setMaxMotionFactor(int size);
   void		setDim(bool on);
   void		setViewType(ViewType);
@@ -149,6 +151,13 @@ public:
 
   const RenderNodeList& getShadowList() const;
 
+  bool		isFogActive() const { return fogActive; }
+  void			setFogActive(bool b) { fogActive = b; }
+
+  const fvec4&	getFogColor() const { return fogColor; }
+  void	setFogColor( float *color) { fogColor = color; }
+
+
   void		render(bool lastFrame = true,
 		       bool sameFrame = false,
 		       bool fullWindow = false);
@@ -177,8 +186,7 @@ private:
 
   void		doRender();
   void		renderDepthComplexity();
-  void		renderPreDimming();
-  void		renderPostDimming();
+  void		renderDimming();
 
   MainWindow*		window;
   bool			blank;
@@ -218,9 +226,10 @@ private:
   bool		useWireframeOn;
   bool		useHiddenLineOn;
   float		panelOpacity;
+  float         radarOpacity;
   int		radarSize;
+  int		panelHeight;
   int		maxMotionFactor;
-  bool		useFogHack;
   bool		useStencilOn;
   ViewType	viewType;
   bool		inOrder;
@@ -234,6 +243,8 @@ private:
   bool		sameFrame;
   bool		needStyleUpdate;
   bool		rebuildTanks;
+  bool		fogActive;
+  fvec4		fogColor;
 
   std::vector<FlareLight>	flareLightList;
   RenderNodeList		shadowList;
