@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -37,7 +37,7 @@ public:
   char callsign[CallSignLen];
   char password[PasswordLen];
   char token[TokenLen];
-  char email[EmailLen];
+  char motto[MottoLen];
   std::string listServerURL;
   int listServerPort;
   bool joystick;
