@@ -1,9 +1,9 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
- * named LICENSE that should have accompanied this file.
+ * named COPYING that should have accompanied this file.
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
@@ -22,19 +22,15 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <string.h>
 #include <time.h>
 #ifndef _WIN32
 #  include <sys/time.h>
 #  include <unistd.h>
-typedef int64_t s64;
-#else
-typedef __int64 s64;
 #endif
 
 // common headers
 #include "common.h"
-#include "global.h"
-#include "Protocol.h"
 #include "Pack.h"
 #include "TextUtils.h"
 #include "version.h"
@@ -46,55 +42,13 @@ typedef __int64 s64;
 #include "MsgStrings.h"
 
 
-// Type Definitions
-// ----------------
-
-typedef uint16_t u16;
-typedef uint32_t u32;
-typedef s64 RRtime;
-
-typedef struct RRpacket {
-  struct RRpacket *next;
-  struct RRpacket *prev;
-  u16 mode;
-  u16 code;
-  u32 len;
-  u32 nextFilePos;
-  u32 prevFilePos;
-  RRtime timestamp;
-  char *data;
-} RRpacket;
-
-static const int RRpacketHdrSize = sizeof(RRpacket) -
-				   (2 * sizeof(RRpacket*) - sizeof(char*));
-typedef struct {
-  u32 magic;			// record file type identifier
-  u32 version;			// record file version
-  u32 offset;			// length of the full header
-  RRtime filetime;		// amount of time in the file
-  u32 player;			// player that saved this record file
-  u32 flagsSize;		// size of the flags data
-  u32 worldSize;		// size of world database
-  char callSign[CallSignLen];	// player's callsign
-  char email[EmailLen];		// player's email
-  char serverVersion[8];	// BZFS protocol version
-  char appVersion[MessageLen];	// BZFS application version
-  char realHash[64];		// hash of worldDatabase
-  char worldSettings[4 + WorldSettingsSize]; // the game settings
-  char *flags;			// a list of the flags types
-  char *world;			// the world
-} ReplayHeader;
-
-static const int ReplayHeaderSize = sizeof(ReplayHeader) - (2 * sizeof(char*));
-
-
 // Function Prototypes
 // -------------------
 
 static void printHelp(const char* execName);
 static bool loadHeader(ReplayHeader *h, FILE *f);
 static RRpacket *loadPacket(FILE *f);
-static void *nboUnpackRRtime(void *buf, RRtime& value);
+static const void *nboUnpackRRtime(const void *buf, RRtime& value);
 static std::string strRRtime(RRtime timestamp);
 
 
@@ -111,7 +65,7 @@ int main(int argc, char** argv)
   RRpacket *p;
   const char* execName = argv[0];
   bool useColor = true;
-  bool useEmail = true;
+  bool useMotto = true;
   bool onlyMessages = false;
 
   printf("\nRRLOG-%s\nProtocol BZFS%s:  %i known packet types\n\n",
@@ -145,7 +99,7 @@ int main(int argc, char** argv)
       argv++;
     }
     else if (strcmp("-e", argv[1]) == 0) {
-      useEmail = false;
+      useMotto = false;
       argc--;
       argv++;
     }
@@ -204,18 +158,23 @@ int main(int argc, char** argv)
 	  days, hours, minutes, secs, usecs);
   printf("start:     %s", ctime(&startTime));
   printf("end:       %s", ctime(&endTime));
-  printf("author:    %s  (%s)\n", header.callSign, header.email);
+  printf("author:    %s  (%s)\n", header.callSign, header.motto);
   printf("bzfs:      bzfs-%s\n", header.appVersion);
-  printf("protocol:  %.8s\n", header.serverVersion);
+  printf("protocol:  %.8s\n", header.ServerVersion);
   printf("flagSize:  %i\n", header.flagsSize);
   printf("worldSize: %i\n", header.worldSize);
   printf("worldHash: %s\n", header.realHash);
   printf("\n");
 
+  if (!p) {
+    printf("Error in first packet\n");
+    fclose(file);
+    exit(1);
+  }
 
   MsgStrings::init();
   MsgStrings::colorize(useColor);
-  MsgStrings::showEmail(useEmail);
+  MsgStrings::showMotto(useMotto);
 //  MsgStrings::colorize(false);
   bool needUpdate = true;
 
@@ -274,7 +233,7 @@ static void printHelp(const char* execName)
   printf("  -h	  : print help\n");
   printf("  -o <level>  : set output level\n");
   printf("  -c	  : disable printing ANSI colors\n");
-//  printf("  -e	  : disable printing emails\n");
+//  printf("  -e	  : disable printing mottos\n");
 //  printf("  -m	  : only print message packets\n");
   printf("\n");
   return;
@@ -285,7 +244,7 @@ static void printHelp(const char* execName)
 static bool loadHeader(ReplayHeader *h, FILE *f)
 {
   char buffer[ReplayHeaderSize];
-  void *buf;
+  const void *buf;
 
   if (fread(buffer, ReplayHeaderSize, 1, f) <= 0) {
     return false;
@@ -299,8 +258,8 @@ static bool loadHeader(ReplayHeader *h, FILE *f)
   buf = nboUnpackUInt(buf, h->flagsSize);
   buf = nboUnpackUInt(buf, h->worldSize);
   buf = nboUnpackString(buf, h->callSign, sizeof(h->callSign));
-  buf = nboUnpackString(buf, h->email, sizeof(h->email));
-  buf = nboUnpackString(buf, h->serverVersion, sizeof(h->serverVersion));
+  buf = nboUnpackString(buf, h->motto, sizeof(h->motto));
+  buf = nboUnpackString(buf, h->ServerVersion, sizeof(h->ServerVersion));
   buf = nboUnpackString(buf, h->appVersion, sizeof(h->appVersion));
   buf = nboUnpackString(buf, h->realHash, sizeof(h->realHash));
 
@@ -330,10 +289,10 @@ static RRpacket* loadPacket(FILE *f)
 {
   RRpacket *p;
   char bufStart[RRpacketHdrSize];
-  void *buf;
+  const void *buf;
 
   if (f == NULL) {
-    return false;
+    return NULL;
   }
 
   p = new RRpacket;
@@ -359,12 +318,13 @@ static RRpacket* loadPacket(FILE *f)
     p->data = NULL;
   }
   else {
-    p->data = new char [p->len];
-    if (fread(p->data, p->len, 1, f) <= 0) {
-      delete[] p->data;
+    char *d = new char [p->len];
+    if (fread(d, p->len, 1, f) <= 0) {
+      delete[] d;
       delete p;
       return NULL;
     }
+    p->data = d;
   }
 
   return p;
@@ -372,7 +332,7 @@ static RRpacket* loadPacket(FILE *f)
 
 /****************************************************************************/
 
-static void* nboUnpackRRtime(void *buf, RRtime& value)
+static const void* nboUnpackRRtime(const void *buf, RRtime& value)
 {
   u32 msb, lsb;
   buf = nboUnpackUInt(buf, msb);
