@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -41,7 +41,8 @@ BZAdminClient::BZAdminClient(BZAdminUI* bzInterface)
     switch (sLink.getState()) {
       case ServerLink::BadVersion: {
 	static char versionError[] = "Incompatible server version XXXXXXXX";
-	strncpy(versionError + strlen(versionError) - 8,
+	// Flawfinder: ignore
+	strncpy(versionError + sizeof(versionError) - 8 - 1,
 	    sLink.getVersion(), 8);
 	std::cout << versionError;
 	break;
@@ -135,15 +136,13 @@ PlayerId BZAdminClient::getMyId() {
 BZAdminClient::ServerCode BZAdminClient::checkMessage() {
   uint16_t code, len;
   char inbuf[MaxPacketLen];
-  std::string dstName, srcName;
-  int i = 0;
   PlayerIdMap::iterator iter;
 
   // read until we have a package, or until we have waited 100 ms
   if (sLink.read(code, len, inbuf, 100) == 1) {
     lastMessage.first = "";
     lastMessage.second = Default;
-    void* vbuf = inbuf;
+    const void* vbuf = inbuf;
     PlayerId p;
     PlayerIdMap::const_iterator it;
     std::string victimName, killerName;
@@ -188,8 +187,11 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
       uint16_t numVars;
       uint8_t nameLen, valueLen;
 
+      // Flawfinder: ignore
       char name[MaxPacketLen];
+      // Flawfinder: ignore
       char value[MaxPacketLen];
+      int i;
 
       vbuf = nboUnpackUShort(vbuf, numVars);
       for (i = 0; i < numVars; i++) {
@@ -214,8 +216,10 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
 
     case MsgAddPlayer:
       uint16_t team, type, wins, losses, tks;
+      // Flawfinder: ignore
       char callsign[CallSignLen];
-      char email[EmailLen];
+      // Flawfinder: ignore
+      char motto[MottoLen];
       vbuf = nboUnpackUByte(vbuf, p);
       vbuf = nboUnpackUShort(vbuf, type);
       vbuf = nboUnpackUShort(vbuf, team);
@@ -223,7 +227,7 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
       vbuf = nboUnpackUShort(vbuf, losses);
       vbuf = nboUnpackUShort(vbuf, tks);
       vbuf = nboUnpackString(vbuf, callsign, CallSignLen);
-      vbuf = nboUnpackString(vbuf, email, EmailLen);
+      vbuf = nboUnpackString(vbuf, motto, MottoLen);
       players[p].name = callsign;
       players[p].team = TeamColor(team);
       players[p].wins = wins;
@@ -334,7 +338,6 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
 	PlayerId victim, killer;
 	FlagType* flagType;
 	int16_t shotId, reason;
-	int phydrv;
 	vbuf = nboUnpackUByte(vbuf, victim);
 	vbuf = nboUnpackUByte(vbuf, killer);
 	vbuf = nboUnpackShort(vbuf, reason);
@@ -343,7 +346,6 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
 	if (reason == PhysicsDriverDeath) {
 	  int32_t inPhyDrv;
 	  vbuf = nboUnpackInt(vbuf, inPhyDrv);
-	  phydrv = int(inPhyDrv);
 	}
 
 	// find the player names and build a kill message string
@@ -393,15 +395,22 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
       // unpack the message header
       PlayerId src;
       PlayerId dst;
+      uint8_t mtype;
       PlayerId me = sLink.getId();
       vbuf = nboUnpackUByte(vbuf, src);
       vbuf = nboUnpackUByte(vbuf, dst);
+      vbuf = nboUnpackUByte(vbuf, mtype);
+
+      // Only bother processing the message if we know how to handle it
+      if (MessageType(mtype) != ChatMessage && MessageType(mtype) != ActionMessage)
+	break;
 
       // format the message depending on src and dst
-      TeamColor dstTeam = (dst >= 244 && dst <= 250 ?
-			   TeamColor(250 - dst) : NoTeam);
+      TeamColor dstTeam = (LastRealPlayer < dst && dst <= FirstTeam ?
+			   TeamColor(FirstTeam - dst) : NoTeam);
       if (messageMask[MsgMessage]) {
-	lastMessage.first = formatMessage((char*)vbuf, src, dst,dstTeam, me);
+	lastMessage.first = formatMessage((const char*)vbuf, MessageType(mtype),
+					  src, dst, dstTeam, me);
 	PlayerIdMap::const_iterator iterator = players.find(src);
 	lastMessage.second = (iterator == players.end() ?
 			      colorMap[NoTeam] :
@@ -468,7 +477,7 @@ void BZAdminClient::outputServerList() const {
     std::vector<ServerItem> servers = serverList.getServers();
     for (std::vector<ServerItem>::const_iterator server = servers.begin();
 	 server != servers.end();
-	 server++) {
+	 ++server) {
       ui->outputMessage(std::string("  ") + server->description, Yellow);
     }
     ui->outputMessage(std::string("End Server List."), Yellow);
@@ -479,7 +488,6 @@ void BZAdminClient::outputServerList() const {
 
 void BZAdminClient::runLoop() {
   std::string cmd;
-  std::map<std::string, uint16_t>::iterator iter;
   ServerCode what(NoMessage);
   while (true) {
     what = checkMessage();
@@ -489,7 +497,7 @@ void BZAdminClient::runLoop() {
       if (cmd == "/quit")
 	break;
       else if (cmd.substr(0, 6) == "/show ") {
-	if ((iter = msgTypeMap.find(cmd.substr(6))) == msgTypeMap.end()) {
+	if (msgTypeMap.find(cmd.substr(6)) == msgTypeMap.end()) {
 	  ui->outputMessage(std::string("--- ERROR: ") + cmd.substr(6) +
 			    " is an unknown message type", Red);
 	}
@@ -500,7 +508,7 @@ void BZAdminClient::runLoop() {
 	}
       }
       else if (cmd.substr(0, 6) == "/hide ") {
-	if ((iter = msgTypeMap.find(cmd.substr(6))) == msgTypeMap.end()) {
+	if (msgTypeMap.find(cmd.substr(6)) == msgTypeMap.end()) {
 	  ui->outputMessage(std::string("--- ERROR: ") + cmd.substr(6) +
 			    " is an unknown message type", Red);
 	}
@@ -544,19 +552,23 @@ void BZAdminClient::sendMessage(const std::string& msg,
     return;
   }
 
+  // Flawfinder: ignore
   char buffer[MessageLen];
+  // Flawfinder: ignore
   char buffer2[1 + MessageLen];
   void* buf = buffer2;
 
   buf = nboPackUByte(buf, target);
-  memset(buffer, 0, MessageLen);
+  // Flawfinder: ignore
   strncpy(buffer, msg.c_str(), MessageLen - 1);
+  buffer[MessageLen - 1] = '\0';
   nboPackString(buffer2 + 1, buffer, MessageLen);
   sLink.send(MsgMessage, sizeof(buffer2), buffer2);
 }
 
 
-std::string BZAdminClient::formatMessage(const std::string& msg, PlayerId src,
+std::string BZAdminClient::formatMessage(const std::string& msg,
+				    const MessageType type, PlayerId src,
 				    PlayerId dst, TeamColor dstTeam,
 				    PlayerId me) {
   std::string formatted = "    ";
@@ -568,35 +580,24 @@ std::string BZAdminClient::formatMessage(const std::string& msg, PlayerId src,
   const std::string dstName = (players.count(dst) ? players[dst].name :
 			       "(UNKNOWN)");
 
-  // display action messages differently
-  bool isAction = false;
-  std::string message;
-  if ((msg[0] == '*') && (msg[1] == ' ') &&
-      (msg[msg.size () - 1] == '*') && (msg[msg.size () - 2] == '\t')) {
-    isAction = true;
-    message = msg.substr(2, msg.size() - 4);
-  } else {
-    message = msg;
-  }
-
   // direct message to or from me
   if (dst == me || players.count(dst)) {
     if (!(src == me && dst == me)) {
       if (src == me) {
-	if (isAction) {
-	  formatted += "[->" + message + "]";
+	if (type == ActionMessage) {
+	  formatted += "[->" + dstName + "][" + srcName + " " + msg + "]";
 	} else {
-	  formatted += "[->" + dstName + "] " + message;
+	  formatted += "[->" + dstName + "] " + msg;
 	}
       } else {
-	if (isAction) {
-	  formatted += "[" + message + "->]";
+	if (type == ActionMessage) {
+	  formatted += "[" + srcName + " " + msg + "]";
 	} else {
-	  formatted += "[" + srcName + "->] " + message;
+	  formatted += "[" + srcName + "->] " + msg;
 	}
       }
     } else {
-      formatted += message;
+      formatted += msg;
     }
   }
 
@@ -607,11 +608,11 @@ std::string BZAdminClient::formatMessage(const std::string& msg, PlayerId src,
     else if (dstTeam != NoTeam)
       formatted += "[Team] ";
 
-    if (!isAction) {
-      formatted += srcName;
-      formatted += ": ";
-    }
-    formatted += message;
+    formatted += srcName;
+    if (type != ActionMessage)
+      formatted += ":";
+    formatted += " ";
+    formatted += msg;
   }
 
   return formatted;
@@ -632,9 +633,8 @@ void BZAdminClient::waitForServer() {
   PlayerId me = sLink.getId();
   if (sLink.getState() == ServerLink::Okay) {
     sendMessage("bzadminping", me);
-    std::string expected = formatMessage("bzadminping", me, me, NoTeam, me);
-    std::string noTalk = formatMessage("We're sorry, you are not allowed to talk!", ServerPlayer, me, NoTeam, me);
-    std::string str;
+    std::string expected = formatMessage("bzadminping", ChatMessage, me, me, NoTeam, me);
+    std::string noTalk = formatMessage("We're sorry, you are not allowed to talk!", ChatMessage, ServerPlayer, me, NoTeam, me);
     BZAdminUI* tmpUI = ui;
     ui = NULL;
     do {
@@ -667,9 +667,11 @@ void BZAdminClient::showMessageType(std::string type) {
 
 
 void BZAdminClient::listSetVars(const std::string& name, void* thisObject) {
+  //Flawfinder: ignore
   char message[MessageLen];
   if (BZDB.getPermission(name) == StateDatabase::Locked) {
-    sprintf(message, "/set %s %f", name.c_str(), BZDB.eval(name));
+    // Flawfinder: ignore
+    snprintf(message, sizeof(message), "/set %s %f", name.c_str(), BZDB.eval(name));
     ((BZAdminClient*)thisObject)->ui->outputMessage(message, Default);
   }
 }
