@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -22,8 +22,11 @@
 /** This struct stores information about a player that is relevant to
     bzadmin. */
 struct PlayerInfo {
-  PlayerInfo() {}
-  PlayerInfo(const std::string& n) : name(n) { }
+  PlayerInfo(): wins(), losses(), tks(),
+    isRegistered(), isVerified(), isAdmin() {}
+  PlayerInfo(const std::string& n) : name(n),
+    wins(), losses(), tks(), isRegistered(),
+    isVerified(), isAdmin() {}
   std::string name;
   std::string ip;
   TeamColor team;
@@ -48,4 +51,3 @@ typedef std::map<PlayerId, PlayerInfo> PlayerIdMap;
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
