@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,10 +27,10 @@
 
 class BaseLocalPlayer : public Player {
  public:
-  BaseLocalPlayer(const PlayerId&, const char* name, const char* email);
+  BaseLocalPlayer(const PlayerId&, const char* name, const char* motto);
   ~BaseLocalPlayer();
 
-  void update();
+  void update(float inputDT = -1.0f);
   Ray getLastMotion() const;
   const float (*getLastMotionBBox() const)[3];
 
