@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,6 +20,9 @@
 #include <assert.h>
 #include <time.h>
 #include <string.h>
+#ifdef HAVE_PTHREADS
+#  include <pthread.h>
+#endif
 
 /* common implementation headers */
 #include "BZDBCache.h"
@@ -27,10 +30,14 @@
 #include "TextUtils.h"
 #include "ErrorHandler.h"
 #include "global.h"
+#ifdef _WIN32
+#  include <DirectoryNames.h>
+#endif
 
 /* local implementation headers */
 #include "SceneRenderer.h"
 #include "RadarRenderer.h"
+#include "TimeKeeper.h"
 #include "bzflag.h"
 
 //
@@ -38,20 +45,42 @@
 //
 
 ControlPanelMessage::ControlPanelMessage(const std::string& _string) :
-  string(_string), numlines(0)
+  numlines(0), string(_string), year(0), month(0), day(0), hour(0), min(0), sec(0)
 {
+  TimeKeeper::localTime(&year, &month, &day, &hour, &min, &sec);
+}
+
+std::string ControlPanelMessage::getString() const {
+  return formatTimestamp(BZDBCache::controlPanelTimestamp) + string;
+}
+
+std::string ControlPanelMessage::getString(bool withTimeDate) const {
+  return formatTimestamp(withTimeDate?2:0) + string;
+}
+
+std::string ControlPanelMessage::formatTimestamp(int mode) const {
+  // Just the date
+  if (mode == 1)
+    return TextUtils::format("[%02d:%02d:%02d] ", hour, min, sec);
+
+  if (mode == 2)
+    return TextUtils::format("[%04d-%02d-%02d %02d:%02d:%02d] ", year, month, day, hour, min, sec);
+
+  return "";
 }
 
 void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSize)
 {
   FontManager &fm = FontManager::instance();
 
+  std::string _string = getString();
+
   // get message and its length
-  const char* msg = string.c_str();
-  int lineLen     = (int)string.length();
+  const char* msg = _string.c_str();
+  int lineLen     = (int)_string.length();
 
   // if there are tabs in the message, find the last one
-  int lastTab = (int)string.rfind('\t');
+  int lastTab = (int)_string.rfind('\t');
 
   lines.clear();
   numlines=0;
@@ -127,6 +156,27 @@ void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSi
   }
 }
 
+
+static std::deque<std::string> mutexMsgs;
+
+#if defined(HAVE_PTHREADS)
+static pthread_mutex_t controlpanel_mutex = PTHREAD_MUTEX_INITIALIZER;
+#elif defined(_WIN32)
+static CRITICAL_SECTION controlpanel_critical;
+#endif
+
+#if defined(HAVE_PTHREADS)
+# define LOCK_CONTROLPANEL_MUTEX   pthread_mutex_lock(&controlpanel_mutex);
+# define UNLOCK_CONTROLPANEL_MUTEX pthread_mutex_unlock(&controlpanel_mutex);
+#elif defined(_WIN32)
+# define LOCK_CONTROLPANEL_MUTEX   EnterCriticalSection(&controlpanel_critical);
+# define UNLOCK_CONTROLPANEL_MUTEX LeaveCriticalSection(&controlpanel_critical);
+#else
+# define LOCK_CONTROLPANEL_MUTEX
+# define UNLOCK_CONTROLPANEL_MUTEX
+#endif
+
+
 //
 // ControlPanel
 //
@@ -146,7 +196,8 @@ ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& _renderer) :
 				dimming(1.0f),
 				du(0),
 				dv(0),
-				messageMode(MessageAll)
+				messageMode(MessageAll),
+				paused(false)
 {
   setControlColor();
 
@@ -155,6 +206,7 @@ ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& _renderer) :
   window.getWindow()->addExposeCallback(exposeCallback, this);
   BZDB.addCallback("displayRadar", bzdbCallback, this);
   BZDB.addCallback(StateDatabase::BZDB_RADARLIMIT, bzdbCallback, this);
+  BZDB.addCallback("controlPanelTimestamp", bzdbCallback, this);
 
   // other initialization
   radarAreaPixels[0] = 0;
@@ -184,6 +236,12 @@ ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& _renderer) :
     tabs->push_back("Misc");
   }
 
+  // construct critical section for threadsafe messages
+#if defined(HAVE_PTHREADS)
+#elif defined(_WIN32)
+  InitializeCriticalSection(&controlpanel_critical);
+#endif
+
   resize(); // need resize to set up font and window dimensions
 }
 
@@ -194,6 +252,13 @@ ControlPanel::~ControlPanel()
   window.getWindow()->removeExposeCallback(exposeCallback, this);
   BZDB.removeCallback("displayRadar", bzdbCallback, this);
   BZDB.removeCallback(StateDatabase::BZDB_RADARLIMIT, bzdbCallback, this);
+  BZDB.removeCallback("controlPanelTimestamp", bzdbCallback, this);
+
+  // destroy critical section for threadsafe messages
+#if defined(HAVE_PTHREADS)
+#elif defined(_WIN32)
+  DeleteCriticalSection(&controlpanel_critical);
+#endif
 
   if (echoToConsole && echoAnsi) {
     std::cout << ColorStrings[FinalResetColor] << std::flush;
@@ -206,7 +271,7 @@ ControlPanel::~ControlPanel()
   }
 }
 
-void ControlPanel::bzdbCallback(const std::string& /*name*/, void* data)
+void ControlPanel::bzdbCallback(const std::string& UNUSED(name), void* data)
 {
   ((ControlPanel*)data)->resize();
   return;
@@ -222,6 +287,11 @@ void			ControlPanel::setControlColor(const GLfloat *color)
 
 void			ControlPanel::render(SceneRenderer& _renderer)
 {
+  while (!mutexMsgs.empty()) {
+    addMessage(mutexMsgs.front());
+    mutexMsgs.pop_front();
+  }
+
   if (!BZDB.isTrue("displayConsole")) {
     // always draw the console if its fully opaque
     const float opacity = RENDERER.getPanelOpacity();
@@ -241,7 +311,7 @@ void			ControlPanel::render(SceneRenderer& _renderer)
   const int x = window.getOriginX();
   const int y = window.getOriginY();
   const int w = window.getWidth();
-  const int tabStyle = (int)BZDB.eval("showtabs");
+  const int tabStyle = BZDB.evalInt("showtabs");
   const bool showTabs = (tabStyle > 0);
   tabsOnRight = (tabStyle == 2);
 
@@ -483,11 +553,8 @@ void			ControlPanel::render(SceneRenderer& _renderer)
   OpenGLGState::resetState();
 
   // draw the lines around the console panel
-  long xpos;
-  long ypos;
-
   float outlineOpacity = RENDERER.getPanelOpacity();
-  float fudgeFactor = BZDBCache::hudGUIBorderOpacityFactor;	// bzdb cache this manybe?
+  float fudgeFactor = BZDBCache::hudGUIBorderOpacityFactor;	// bzdb cache this maybe?
   if ( outlineOpacity < 1.0f )
 	outlineOpacity = (outlineOpacity*fudgeFactor) + (1.0f - fudgeFactor);
 
@@ -496,7 +563,11 @@ void			ControlPanel::render(SceneRenderer& _renderer)
 
   // nice border
   glColor4f(teamColor[0], teamColor[1], teamColor[2],outlineOpacity );
-  glBegin(GL_LINE_LOOP); {
+  glBegin(GL_LINE_LOOP);
+  {
+    long xpos;
+    long ypos;
+
     // bottom left
     xpos = x + messageAreaPixels[0] - 1;
     ypos = y + messageAreaPixels[1] - 1;
@@ -517,7 +588,6 @@ void			ControlPanel::render(SceneRenderer& _renderer)
     }
 
     // across the top from right to left
-    long int drawnTabWidth = 0;
     for (int tab = (int)tabs->size() - 1; tab >= 0; tab--) {
 
       if (messageMode == MessageModes(tab)) {
@@ -533,7 +603,6 @@ void			ControlPanel::render(SceneRenderer& _renderer)
 	xpos -= long(tabTextWidth[tab]);
 	glVertex2f((float) xpos, (float) ypos);
       }
-      drawnTabWidth += long(tabTextWidth[tab]);
     }
 
     // over from panel on right
@@ -544,39 +613,41 @@ void			ControlPanel::render(SceneRenderer& _renderer)
 
   } glEnd();
 
-  // some engines miss the corners
-  glBegin(GL_POINTS); {
-    glVertex2f((float) (x + messageAreaPixels[0] - 1),
-	       (float) (y + messageAreaPixels[1] - 1));
-    glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2]),
-	       (float) (y + messageAreaPixels[1] - 1));
-    glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2]),
-	       (float) (y + messageAreaPixels[1] + messageAreaPixels[3]));
-    glVertex2f((float) (x + messageAreaPixels[0] - 1),
-	       (float) (y + messageAreaPixels[1] + messageAreaPixels[3]));
-    long int tabPosition = 0;
-    for (int tab = 0; tab < (int)tabs->size(); tab++) {
-      if (messageMode == MessageModes(tab)) {
-	if (tabsOnRight) {
-	  glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + tabPosition),
-		     (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
-	  glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + tabPosition + long(tabTextWidth[tab])),
-		     (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
-	} else {
-	  glVertex2f((float) (x + messageAreaPixels[0] + tabPosition),
-		     (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
-	  glVertex2f((float) (x + messageAreaPixels[0] + tabPosition + long(tabTextWidth[tab])),
-		     (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
+  if (0){
+    // some engines miss the corners
+    glBegin(GL_POINTS); {
+      glVertex2f((float) (x + messageAreaPixels[0] - 1),
+		 (float) (y + messageAreaPixels[1] - 1));
+      glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2]),
+		 (float) (y + messageAreaPixels[1] - 1));
+      glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2]),
+		 (float) (y + messageAreaPixels[1] + messageAreaPixels[3]));
+      glVertex2f((float) (x + messageAreaPixels[0] - 1),
+		 (float) (y + messageAreaPixels[1] + messageAreaPixels[3]));
+      long int tabPosition = 0;
+      for (int tab = 0; tab < (int)tabs->size(); tab++) {
+	if (messageMode == MessageModes(tab)) {
+	  if (tabsOnRight) {
+	    glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + tabPosition),
+		       (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
+	    glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + tabPosition + long(tabTextWidth[tab])),
+		       (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
+	  } else {
+	    glVertex2f((float) (x + messageAreaPixels[0] + tabPosition),
+		       (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
+	    glVertex2f((float) (x + messageAreaPixels[0] + tabPosition + long(tabTextWidth[tab])),
+		       (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
+	  }
 	}
+	tabPosition += long(tabTextWidth[tab]);
       }
-      tabPosition += long(tabTextWidth[tab]);
-    }
-  } glEnd();
+    } glEnd();
+  }
 
   if (BZDBCache::blend)
 	  glDisable(GL_BLEND);
 
-  glColor4f(teamColor[0], teamColor[1], teamColor[2],1.0f );
+glColor4f(teamColor[0], teamColor[1], teamColor[2],1.0f );
 
   glPopMatrix();
 
@@ -585,29 +656,36 @@ void			ControlPanel::render(SceneRenderer& _renderer)
 
 void			ControlPanel::resize()
 {
-  float radarSpace, radarSize;
+  float radarSpace, radarSize, panelHeight;
   // get important metrics
   const float w = (float)window.getWidth();
   const float h = (float)window.getHeight();
   const float opacity = RENDERER.getPanelOpacity();
-  radarSize = float(window.getHeight() - window.getViewHeight());
   if (opacity == 1.0f) {
     radarSize = float(window.getHeight() - window.getViewHeight());
+    panelHeight = radarSize;
     radarSpace = 0.0f;
   } else {
     radarSize = h * (14 + RENDERER.getRadarSize()) / 60.0f;
+    panelHeight = h * (14 + RENDERER.getPanelHeight()) / 60.0f;
     radarSpace = 3.0f * w / MinY;
   }
 
   // compute areas in pixels x,y,w,h
   // leave off 1 pixel for the border
-  radarAreaPixels[0] = radarAreaPixels[1] = (int)radarSpace + 1;
+  radarAreaPixels[1] = (int)radarSpace + 1;
   radarAreaPixels[2] = radarAreaPixels[3] = (int)(radarSize - (radarSpace * 2.0f)) - 2;
+  if (BZDB.get("radarPosition") == "1") {                    //radar on right
+    radarAreaPixels[0] = (int)(w - radarSize + radarSpace);  // radar X coord
+    messageAreaPixels[0] = (int)radarSpace + 1;              // message box X coord
+  } else {                                      //radar on left
+    radarAreaPixels[0] = radarAreaPixels[1];    // radar X coord
+    messageAreaPixels[0] = (int)radarSize + 1;  // message box X coord
+  }
+  messageAreaPixels[1] = radarAreaPixels[1];                            // Y coord
+  messageAreaPixels[2] = (int)(w - radarSize - radarSpace) - 2;         // Width
+  messageAreaPixels[3] = (int)(panelHeight - (radarSpace * 2.0f)) - 2;  // Height
 
-  messageAreaPixels[0] = (int)radarSize + 1;		    // X coord
-  messageAreaPixels[1] = radarAreaPixels[1];		    // Y coord
-  messageAreaPixels[2] = (int)(w - radarSize - radarSpace) - 2; // Width
-  messageAreaPixels[3] = radarAreaPixels[3];		    // Height
   if (!BZDB.isTrue("displayRadar") || (BZDBCache::radarLimit <= 0.0f)) {
     messageAreaPixels[0] = (int)radarSpace + 1;
     messageAreaPixels[2] = (int)(w - (radarSpace * 2.0f)) - 2;
@@ -751,6 +829,13 @@ void			ControlPanel::setMessagesMode(int _messageMode)
   invalidate();
 }
 
+void ControlPanel::addMutexMessage(const std::string& msg)
+{
+  LOCK_CONTROLPANEL_MUTEX
+  mutexMsgs.push_back(msg);
+  UNLOCK_CONTROLPANEL_MUTEX
+}
+
 void			ControlPanel::addMessage(const std::string& line,
 						 const int realmode)
 {
@@ -787,7 +872,13 @@ void			ControlPanel::addMessage(const std::string& line,
 
       // visible changes, force a console refresh
       if (messageMode == tab) {
-	invalidate();
+        // Don't scroll the messages unless we're at the bottom
+	if ((BZDB.isTrue("pauseConsole") && messagesOffset > 0 && messageMode >= 0) ||
+	    paused) {
+	  setMessagesOffset(1, 1 /* current */, false);
+	}
+
+        invalidate();
       }
 
       // mark the tab as unread (if viewing tabs)
@@ -801,7 +892,8 @@ void			ControlPanel::addMessage(const std::string& line,
   if (echoToConsole){
 #ifdef _WIN32
     // this is cheap but it will work on windows
-    FILE *fp = fopen ("stdout.txt","a+");
+    std::string filename = getConfigDirName() + "stdout.txt";
+    FILE *fp = fopen (filename.c_str(), "a+");
     if (fp){
       fprintf(fp,"%s\n", stripAnsiCodes(line).c_str());
       fclose(fp);
@@ -819,7 +911,7 @@ void			ControlPanel::addMessage(const std::string& line,
 
 
 void ControlPanel::saveMessages(const std::string& filename,
-				bool stripAnsi) const
+				bool stripAnsi, bool timestamp) const
 {
   FILE* file = fopen(filename.c_str(), "a+");
   if (!file) {
@@ -831,10 +923,10 @@ void ControlPanel::saveMessages(const std::string& filename,
   fprintf(file, "Messages saved: %s", ctime(&nowTime));
   fprintf(file, "----------------------------------------\n\n");
 
-  // add to the appropriate tabs
+  // Iterate through the 'All' tab messages
   std::deque<ControlPanelMessage>::const_iterator msg = messages[MessageAll].begin()++;
   for (; msg != messages[MessageAll].end(); ++msg) {
-    const std::string& line = msg->string;
+    const std::string line = msg->getString(timestamp);
     if (stripAnsi) {
       fprintf(file, "%s\n", stripAnsiCodes(line).c_str());
     } else {
