@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -26,7 +26,7 @@
 class EntryZone {
   public:
     EntryZone();
-    void* unpack(void*);
+    const void* unpack(const void*);
 
   public:
     float pos[3];
