@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -36,7 +36,7 @@ public:
   }
   void execute();
   void resize(int width, int height);
-  static void callback(HUDuiControl* w, void* data);
+  static void callback(HUDuiControl* w, const void* data);
 
   static const int maxRadarSize = 30;
 
