@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -37,7 +37,7 @@ class GuidedMissileStrategy : public ShotStrategy {
     void		update(float dt);
     float		checkHit(const BaseLocalPlayer*, float[3]) const;
     void		sendUpdate(const FiringInfo&) const;
-    void		readUpdate(uint16_t, void*);
+    void		readUpdate(uint16_t, const void*);
     void		addShot(SceneDatabase*, bool colorblind);
     void		expire();
     void		radarRender() const;
@@ -55,9 +55,9 @@ class GuidedMissileStrategy : public ShotStrategy {
     float		nextPos[3];
     BoltSceneNode*	ptSceneNode;
 
-		float	puffTime;
+		float	puffTime,rootPuff;
 		TimeKeeper lastPuff;
-    bool		needUpdate;
+    mutable bool	needUpdate;
     PlayerId		lastTarget;
 };
 
