@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -115,7 +115,7 @@ HUDuiCallback		HUDuiControl::getCallback() const
   return cb;
 }
 
-void*			HUDuiControl::getUserData() const
+const void*		HUDuiControl::getUserData() const
 {
   return userData;
 }
@@ -171,7 +171,7 @@ void			HUDuiControl::setNext(HUDuiControl* _next)
   else next = _next;
 }
 
-void			HUDuiControl::setCallback(HUDuiCallback _cb, void* _ud)
+void			HUDuiControl::setCallback(HUDuiCallback _cb, const void* _ud)
 {
   cb = _cb;
   userData = _ud;
@@ -295,4 +295,3 @@ void			HUDuiControl::render()
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
