@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -28,7 +28,7 @@ class HUDuiTextureLabel : public HUDuiLabel {
 			~HUDuiTextureLabel();
 
     void		setTexture(const int);
-    int			getTexture();
+    int			getTexture() const;
 
   protected:
     void		doRender();
@@ -38,7 +38,7 @@ class HUDuiTextureLabel : public HUDuiLabel {
     int		texture;
 };
 
-inline int HUDuiTextureLabel::getTexture() {
+inline int HUDuiTextureLabel::getTexture() const {
   return texture;
 }
 
