@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -112,12 +112,12 @@ JoinMenu::JoinMenu() : serverStartMenu(NULL), serverMenu(NULL)
   port->setString(buffer);
   listHUD.push_back(port);
 
-  email = new HUDuiTypeIn;
-  email->setFontFace(fontFace);
-  email->setLabel("Email:");
-  email->setMaxLength(EmailLen - 1);
-  email->setString(info->email);
-  listHUD.push_back(email);
+  motto = new HUDuiTypeIn;
+  motto->setFontFace(fontFace);
+  motto->setLabel("Motto:");
+  motto->setMaxLength(MottoLen - 1);
+  motto->setString(info->motto);
+  listHUD.push_back(motto);
 
   startServer = new HUDuiLabel;
   startServer->setFontFace(fontFace);
@@ -194,7 +194,7 @@ void JoinMenu::loadInfo()
   info->team = getTeam();
   strcpy(info->serverName, server->getString().c_str());
   info->serverPort = atoi(port->getString().c_str());
-  strcpy(info->email, email->getString().c_str());
+  strcpy(info->motto, motto->getString().c_str());
 }
 
 void JoinMenu::execute()
@@ -233,21 +233,32 @@ void JoinMenu::execute()
     }
 
     // let user know we're trying
-    setStatus("Trying...");
+    if (startupInfo.autoConnect) {
+      setStatus("Trying Automatic Connection...");
+      startupInfo.autoConnect = false;
+    }
+    else {
+      setStatus("Trying...");
+    }
 
     // schedule attempt to join game
     joinGame();
   }
 }
 
+void JoinMenu::centerLabelHorizontally(HUDuiLabel *label)
+{
+  FontManager &fm = FontManager::instance();
+  const float _width = fm.getStrLength(MainMenu::getFontFace(),
+    label->getFontSize(), label->getString());
+  
+  label->setPosition(center - 0.5f * _width, label->getY());
+}
+
 void JoinMenu::setFailedMessage(const char* msg)
 {
   failedMessage->setString(msg);
-
-  FontManager &fm = FontManager::instance();
-  const float _width = fm.getStrLength(MainMenu::getFontFace(),
-	failedMessage->getFontSize(), failedMessage->getString());
-  failedMessage->setPosition(center - 0.5f * _width, failedMessage->getY());
+  centerLabelHorizontally(failedMessage);
 }
 
 TeamColor JoinMenu::getTeam() const
@@ -263,18 +274,15 @@ void JoinMenu::setTeam(TeamColor teamcol)
 void JoinMenu::setStatus(const char* msg, const std::vector<std::string> *)
 {
   status->setString(msg);
-  FontManager &fm = FontManager::instance();
-  const float _width = fm.getStrLength(status->getFontFace(),
-		status->getFontSize(), status->getString());
-  status->setPosition(center - 0.5f * _width, status->getY());
+  centerLabelHorizontally(status);
 }
 
-void JoinMenu::teamCallback(HUDuiControl*, void* source)
+void JoinMenu::teamCallback(HUDuiControl*, const void* source)
 {
-  ((JoinMenu*)source)->updateTeamTexture();
+  ((const JoinMenu*)source)->updateTeamTexture();
 }
 
-void JoinMenu::updateTeamTexture()
+void JoinMenu::updateTeamTexture() const
 {
   TextureManager &tm = TextureManager::instance();
   FontManager &fm = FontManager::instance();
@@ -334,7 +342,11 @@ void JoinMenu::resize(int _width, int _height)
       y -= 1.0f * h;
     if (i <= 2 || i == 9) y -= 0.5f * h;
   }
-
+  
+  // these should be centered
+  centerLabelHorizontally(status);
+  centerLabelHorizontally(failedMessage);
+  
   updateTeamTexture();
 }
 
