@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -31,7 +31,6 @@ MainWindow::MainWindow(BzfWindow* _window, BzfJoystick* _joystick) :
 				isFullView(true),
 				allowMouseGrab(true),
 				grabEnabled(true),
-				zoomFactor(1),
 				width(0),
 				minWidth(MinX),
 				minHeight(MinY),
@@ -46,11 +45,6 @@ MainWindow::~MainWindow()
   window->removeResizeCallback(resizeCB, this);
 }
 
-void			MainWindow::setZoomFactor(int _zoomFactor)
-{
-  zoomFactor = _zoomFactor;
-}
-
 void			MainWindow::setMinSize(int _minWidth, int _minHeight)
 {
   minWidth = _minWidth;
@@ -76,20 +70,56 @@ void			MainWindow::showWindow(bool on)
   if (on) resize();
 }
 
+
+inline int MainWindow::getYOffset() const
+{
+  if (quadrant == FullWindow) {
+    return 0;
+  }
+  return ((trueHeight + 1) >> 1) - yOrigin;
+}
+
 void			MainWindow::warpMouse()
 {
   // move mouse to center of view window (zero motion box)
-  int y = viewHeight >> 1;
-  if (quadrant != FullWindow) y += ((trueHeight+1) >> 1) - yOrigin;
-  window->warpMouse((width >> 1) + xOrigin, y);
+  window->warpMouse((width >> 1) + xOrigin, (viewHeight >> 1) + getYOffset());
+}
+
+void			MainWindow::warpMouse(int mx, int my)
+{
+  window->warpMouse(mx, my);
+}
+
+void			MainWindow::warpMouseCenterX()
+{
+  int mx, my;
+  getMousePosition(mx, my);
+  window->warpMouse((width >> 1) + xOrigin, my + (viewHeight >> 1) + getYOffset());
+}
+
+void			MainWindow::warpMouseCenterY()
+{
+  int mx, my;
+  getMousePosition(mx, my);
+  const int y = (viewHeight >> 1) + getYOffset();
+  window->warpMouse(mx + (width >> 1) + xOrigin, y);
 }
 
 void			MainWindow::getMousePosition(int& mx, int& my) const
 {
   window->getMouse(mx, my);
   mx -= (width >> 1) + xOrigin;
-  my -= (viewHeight >> 1);
-  if (quadrant != FullWindow) my -= ((trueHeight+1) >> 1) - yOrigin;
+  my -= (viewHeight >> 1) + getYOffset();
+}
+
+void			MainWindow::disableConfineToMotionbox()
+{
+  window->disableConfineToMotionbox();
+}
+
+void			MainWindow::confineToMotionbox(int x1, int y1, int x2, int y2)
+{
+  window->confineToMotionbox(x1, y1, x2, y2);
 }
 
 void			MainWindow::grabMouse()
@@ -108,12 +138,12 @@ void			MainWindow::enableGrabMouse(bool on)
   grabEnabled = on;
 }
 
-bool			MainWindow::isGrabEnabled(void)
+bool MainWindow::isGrabEnabled(void) const
 {
   return grabEnabled;
 }
 
-bool			MainWindow::getFullscreen()
+bool MainWindow::getFullscreen() const
 {
   return isFullscreen;
 }
@@ -214,8 +244,8 @@ void			MainWindow::setQuadrant(Quadrant _quadrant)
   }
 
   if (quadrant == ZoomRegion) {
-    width = inWidth / zoomFactor + 1;
-    height = inHeight / zoomFactor + 1;
+    width = inWidth + 1;
+    height = inHeight + 1;
   }
 
   glViewport(xOrigin, yOrigin, width, height);
@@ -254,6 +284,16 @@ void			MainWindow::getJoyPosition(int& mx, int& my) const
   my = ((height >> 1) * my) / (900);
 }
 
+int                     MainWindow::getNumHats() const
+{
+  return joystick->getNumHats();
+}
+
+void                    MainWindow::getJoyHat(int hat, float &hatX, float &hatY) const
+{
+  joystick->getJoyHat(hat, hatX, hatY);
+}
+
 unsigned long		  MainWindow::getJoyButtonSet() const
 {
   return joystick->getJoyButtons();
@@ -271,12 +311,12 @@ void		    MainWindow::getJoyDeviceAxes(std::vector<std::string>
   joystick->getJoyDeviceAxes(list);
 }
 
-void		    MainWindow::setJoyXAxis(const std::string axis)
+void MainWindow::setJoyXAxis(const std::string &axis)
 {
   joystick->setXAxis(axis);
 }
 
-void		    MainWindow::setJoyYAxis(const std::string axis)
+void MainWindow::setJoyYAxis(const std::string &axis)
 {
   joystick->setYAxis(axis);
 }
@@ -292,4 +332,3 @@ void			MainWindow::initJoystick(std::string &joystickName) {
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
