@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -29,7 +29,7 @@
 class RemotePlayer : public Player {
 public:
   RemotePlayer(const PlayerId&, TeamColor team,
-	       const char* name, const char* email,
+	       const char* name, const char* motto,
 	       const PlayerType);
   ~RemotePlayer();
 
