@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -35,7 +35,7 @@ class RobotPlayer : public LocalPlayer {
   public:
 			RobotPlayer(const PlayerId&,
 				const char* name, ServerLink*,
-				const char* _email);
+				const char* _motto);
 
     float		getTargetPriority(const Player*) const;
     const Player*	getTarget() const;
@@ -48,7 +48,6 @@ class RobotPlayer : public LocalPlayer {
   private:
     void		doUpdate(float dt);
     void		doUpdateMotion(float dt);
-    virtual int	 getHandicapScoreBase() const;
     BzfRegion*		findRegion(const float p[2], float nearest[2]) const;
     float		getRegionExitPoint(
 				const float p1[2], const float p2[2],
@@ -79,4 +78,3 @@ class RobotPlayer : public LocalPlayer {
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
