@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,6 +17,7 @@
 
 /* system interface headers */
 #include <string>
+#include <vector>
 
 /* common interface headers */
 #include "bzfgl.h"
@@ -37,7 +38,7 @@ public:
   void		setDim(bool);
   void    setWindowSize (float x, float y, float width, float height);
   void		render(bool forceDisplay);
-  static Player* getLeader(std::string *label=NULL);
+  static Player* getLeader(std::string *label = NULL);
 
   static const int HUNT_NONE = 0;
   static const int HUNT_SELECTING = 1;
@@ -59,23 +60,29 @@ public:
   static const char **getSortLabels();
   static const int SORT_SCORE = 0;
   static const int SORT_NORMALIZED = 1;
-  static const int SORT_CALLSIGN = 2;
-  static const int SORT_TKS = 3;
-  static const int SORT_TKRATIO = 4;
-  static const int SORT_TEAM = 5;
-  static const int SORT_MYRATIO = 6;
+  static const int SORT_REVERSE = 2;
+  static const int SORT_CALLSIGN = 3;
+  static const int SORT_TKS = 4;
+  static const int SORT_TKRATIO = 5;
+  static const int SORT_TEAM = 6;
+  static const int SORT_MYRATIO = 7;
   static const int SORT_MAXNUM = SORT_MYRATIO;
 
   void setTeamScoreY ( float val ){teamScoreYVal = val;}
   void setRoaming ( bool val ){roaming = val;}
 
+  // does not include observers
+  static void getPlayerList(std::vector<Player*>& players);
+
 protected:
   void hudColor3fv(const GLfloat*);
   void renderTeamScores (float y, float x, float dy);
-  void renderScoreboard(void);
-  void renderCtfFlags (void);
+  void renderScoreboard();
+  void renderCtfFlags();
+  void drawRoamTarget(float x0, float y0, float x1, float y1);
   void drawPlayerScore(const Player*,
-		float x1, float x2, float x3, float xs, float y, int emailLen, bool huntInd);
+				   float x1, float x2, float x3, float xs, float y,
+				   int mottoLen, bool huntInd);
   static const char *sortLabels[SORT_MAXNUM+2];
   static int sortMode;
   static bool alwaysShowTeamScore;
@@ -97,7 +104,6 @@ private:
   float winHeight;
 
   bool dim;
-  bool huntIndicator;
   int huntPosition;
   bool huntSelectEvent;
   int huntPositionEvent;
