@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -63,7 +63,7 @@ class ServerLink {
 						int millisecondsToBlock = 0);
 
     void		sendEnter(PlayerType, TeamColor,
-				  const char* name, const char* email, const char* token);
+				  const char* name, const char* motto, const char* token);
     bool		readEnter(std::string& reason,
 				  uint16_t& code, uint16_t& rejcode);
 
@@ -109,7 +109,7 @@ class ServerLink {
     std::string	 rejectionMessage;
 
     int		 udpLength;
-    char	       *udpBufferPtr;
+    const char	       *udpBufferPtr;
     char		ubuf[MaxPacketLen];
 };
 
@@ -149,4 +149,3 @@ inline const char*	ServerLink::getVersion() const
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
