@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -319,14 +319,6 @@ HUDuiDefaultKey* ServerStartMenu::getDefaultKey()
 
 void ServerStartMenu::setSettings(const char* _settings)
 {
-  // FIXME -- temporary to automatically upgrade old configurations
-  if (strlen(_settings) == 14) {
-    strcpy(settings, _settings);
-    settings[12] = settings[13];
-    settings[13] = settings[14];
-    return;
-  }
-
   if (strlen(_settings) != strlen(settings)) return;
   strcpy(settings, _settings);
 }
@@ -370,18 +362,15 @@ void ServerStartMenu::execute()
     // other options as they were set
 
     // get path to server from path to client
-    // add 256 for flags room
-    char serverCmd[PATH_MAX + 256];
-    strcpy(serverCmd, argv0);
-    char* base = strrchr(serverCmd, '/');
+    const char* base = strrchr(argv0, '/');
 #if defined(_WIN32)
-    char* base2 = strrchr(serverCmd, '\\');
-    if (base2 && (!base || base2 - serverCmd > base - serverCmd))
+    const char* base2 = strrchr(argv0, '\\');
+    if (base2 && (!base || base2 - argv0 > base - argv0))
       base = base2;
 #endif
-    if (!base) base = serverCmd;
+    if (!base) base = argv0;
     else base++;
-    strcpy(base, serverApp);
+    std::string serverCmd = TextUtils::format("%.*s%s", base-argv0, argv0, serverApp);
 
     // prepare arguments for starting server
     const char* args[30];
@@ -497,7 +486,7 @@ void ServerStartMenu::execute()
 #if defined(_WIN32)
 
     // Windows
-    int result = _spawnvp(_P_DETACH, serverCmd, (char* const*) args);
+    int result = _spawnvp(_P_DETACH, serverCmd.c_str(), const_cast<char* const*>(args));
     if (result < 0) {
       if (errno == ENOENT)
 	setStatus("Failed... can't find server program.");
@@ -506,8 +495,8 @@ void ServerStartMenu::execute()
       else if (errno == ENOEXEC)
 	setStatus("Failed... server program is not executable.");
       else
-	setStatus(TextUtils::format("Failed... unknown error (%d).", errno, serverCmd).c_str());
-      logDebugMessage(1,"Failed to start server (%s) - error %d.\n", serverCmd, errno);
+	setStatus(TextUtils::format("Failed... unknown error (%d).", errno).c_str());
+      logDebugMessage(1,"Failed to start server (%s) - error %d.\n", serverCmd.c_str(), errno);
     }
     else {
       setStatus("Server started.");
@@ -549,10 +538,10 @@ void ServerStartMenu::execute()
       close(2);
 
       // exec server
-      execvp(serverCmd, (char* const*)args);
+      execvp(serverCmd.c_str(), const_cast<char* const*>(args));
       // If execvp returns, bzfs wasnt at the anticipated location.
       // Let execvp try to find it in $PATH by feeding it the "bzfs" name by it self
-      execvp(serverApp, (char* const*)args);
+      execvp(serverApp, const_cast<char* const*>(args));
       // If that returns too, something bad has happened. Exit.
       exit(2);
     }
