@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,7 +18,7 @@
 
 /* local implementation headers */
 #include "LocalPlayer.h"
-#include "playing.h"
+#include "Roster.h"
 #include "World.h"
 
 
@@ -33,7 +33,7 @@ ShockWaveStrategy::ShockWaveStrategy(ShotPath *_path) :
 
   // make scene node
   const float* pos = _path->getPosition();
-  if (RENDERER.useQuality() >= 3) {
+  if (RENDERER.useQuality() >= 2) {
     shockNode = new SphereLodSceneNode(pos, radius);
     shockNode->setShockWave(true);
   } else {
@@ -44,15 +44,14 @@ ShockWaveStrategy::ShockWaveStrategy(ShotPath *_path) :
   if (_path->getPlayer() == ServerPlayer) {
     TeamColor tmpTeam = _path->getFiringInfo().shot.team;
     team = (tmpTeam < RogueTeam) ? RogueTeam :
-	   (tmpTeam > RabbitTeam) ? RogueTeam : tmpTeam;
+	   (tmpTeam > HunterTeam) ? RogueTeam : tmpTeam;
   } else {
     Player* p = lookupPlayer(_path->getPlayer());
     team = p ? p->getTeam() : RogueTeam;
   }
 
-  bool rabbitMode = World::getWorld()->allowRabbit();
-  const float* c = Team::getRadarColor(team, rabbitMode);
-  if (RENDERER.useQuality() >= 3) {
+  const float* c = Team::getShotColor(team);
+  if (RENDERER.useQuality() >= 2) {
     shockNode->setColor(c[0], c[1], c[2], 0.5f);
   } else {
     shockNode->setColor(c[0], c[1], c[2], 0.75f);
@@ -84,11 +83,10 @@ void ShockWaveStrategy::update(float dt)
     currentTeam = team;
   }
 
-  bool rabbitMode = World::getWorld()->allowRabbit();
-  const float* c = Team::getRadarColor(currentTeam, rabbitMode);
+  const float* c = Team::getShotColor(currentTeam);
 
   // fade old-style shockwaves
-  if (RENDERER.useQuality() >= 3) {
+  if (RENDERER.useQuality() >= 2) {
     shockNode->setColor(c[0], c[1], c[2], 0.5f);
   } else {
     const float shockIn = BZDB.eval(StateDatabase::BZDB_SHOCKINRADIUS);
