@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -52,7 +52,7 @@ class ShotStrategy {
 
     // update shot based on message.  code is the message code.  msg
     // points to the part of the message after the ShotUpdate portion.
-    virtual void	readUpdate(uint16_t code, void* msg);
+    virtual void	readUpdate(uint16_t code, const void* msg);
 
     static const Obstacle*	getFirstBuilding(const Ray&, float min, float& t);
     static void		reflect(float* v, const float* n); // const
