@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -121,9 +121,8 @@ float TargetingUtils::getOpenDistance( const float *src, const float azimuth )
   float t = MAXFLOAT; //Some constant?
 
   float dir[3] = { cosf(azimuth), sinf(azimuth), 0.0f };
-  *((float *) &src[2]) += 0.1f; //Don't hit building because your sitting on one
-  Ray tankRay( src, dir );
-  *((float *) &src[2]) -= 0.1f;
+  const float pos[3] = { src[0], src[1], src[2] + 0.1f };	// Don't hit building because you're sitting on one.
+  Ray tankRay( pos, dir );
   ShotStrategy::getFirstBuilding(tankRay, -0.5f, t);
   return t;
 }
