@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -30,6 +30,9 @@
 #  include <sys/types.h>
 #  include <sys/stat.h>
 #  include <direct.h>
+#  if !defined(HAVE_SDL)
+#    include <tchar.h>
+#  endif /* !defined(HAVE_SDL) */
 #else
 #  include <pwd.h>
 #  include <dirent.h>
@@ -37,6 +40,7 @@
 
 /* common headers */
 #include "Address.h"
+#include "AresHandler.h"
 #include "BZDBCache.h"
 #include "BZDBLocal.h"
 #include "BundleMgr.h"
@@ -54,7 +58,6 @@
 #include "KeyManager.h"
 #include "OSFile.h"
 #include "OpenGLGState.h"
-#include "ParseColor.h"
 #include "PlatformFactory.h"
 #include "Protocol.h"
 #include "ServerListCache.h"
@@ -89,8 +92,6 @@
 int beginendCount = 0;
 
 const char*		argv0;
-static bool		anonymous = false;
-static std::string	anonymousName("anonymous");
 std::string		alternateConfig;
 static bool		noAudio = false;
 struct tm		userTime;
@@ -121,22 +122,6 @@ int bail ( int returnCode )
 	return returnCode;
 }
 
-static void		setTeamColor(TeamColor team, const std::string& str)
-{
-  float color[4];
-  parseColorString(str, color);
-  // don't worry about alpha, Team::setColors() doesn't use it
-  Team::setColors(team, color, Team::getRadarColor(team));
-}
-
-static void		setRadarColor(TeamColor team, const std::string& str)
-{
-  float color[4];
-  parseColorString(str, color);
-  // don't worry about alpha, Team::setColors() doesn't use it
-  Team::setColors(team, Team::getTankColor(team), color);
-}
-
 static void		setVisual(BzfVisual* visual)
 {
   // sine qua non
@@ -155,8 +140,11 @@ static void		setVisual(BzfVisual* visual)
   }
 
   // optional
+  visual->setStencil(4);
 #if defined(DEBUG_RENDERING)
   visual->setStencil(4);
+#else
+  visual->setStencil(1);
 #endif
   if (BZDB.isTrue("multisample"))
     visual->setMultisample(4);
@@ -164,22 +152,24 @@ static void		setVisual(BzfVisual* visual)
   if (BZDB.isSet("view") && BZDB.get("view") == configViewValues[1])
     visual->setStereo(true);
 #endif
+  visual->setVerticalSync(BZDB.evalInt("saveEnergy") == 2);
 }
 
 static void		usage()
 {
   printFatalError("usage: %s"
-	" [-3dfx] [-no3dfx]"
-	" [-anonymous]"
 	" [-badwords <filterfile>]"
 	" [-config <configfile>]"
 	" [-configdir <config dir name>]"
 	" [-d | -debug]"
+#ifdef DEBUG
 	" [-date mm/dd/yyyy]"
+#endif
 	" [{-dir | -directory} <data-directory>]"
 	" [-e | -echo]"
 	" [-ea | -echoAnsi]"
-	" [{-g | -geometry} <geometry-spec>]"
+	" [-eyesep separation]"
+	" [-focal distance]"
 	" [-h | -help | --help]"
 	" [-latitude <latitude>] [-longitude <longitude>]"
 	" [-list <list-server-url>] [-nolist]"
@@ -194,8 +184,8 @@ static void		usage()
 	" [-time hh:mm:ss] [-notime]"
 	" [-v | -version | --version]"
 	" [-view {normal|stereo|stacked|three|anaglyph|interlaced}]"
-	" [-window]"
-	" [-zoom <zoom-factor>]"
+	" [-window <geometry-spec>]"
+	" [-zbuffer {on|off}]"
 	" [callsign[:password]@]server[:port]\n\nExiting.", argv0);
   if (display != NULL) {
     delete display;
@@ -217,50 +207,36 @@ static void		parse(int argc, char** argv)
 {
 // = 9;
   for (int i = 1; i < argc; i++) {
-    if (strcmp(argv[i], "-a") == 0 ||
-		strcmp(argv[i], "-anonymous") == 0) {
-      anonymous = true;
-    } else if (strcmp(argv[i], "-config") == 0) {
+    if (strcmp(argv[i], "-config") == 0) {
       checkArgc(i, argc, argv[i]);
       // the setting has already been done in parseConfigName()
-	} else if (strcmp(argv[i], "-configdir") == 0) {
-		checkArgc(i, argc, argv[i]);
-		// the setting has already been done in parseConfigName()
-	} else if ((strcmp(argv[i], "-d") == 0) ||
-	       (strcmp(argv[i], "-debug") == 0)) {
-      debugLevel++;
-    } else if ((strcmp(argv[i], "-dir") == 0) ||
-	       (strcmp(argv[i], "-directory") == 0)) {
+    }
+    else if (strcmp(argv[i], "-configdir") == 0) {
+      checkArgc(i, argc, argv[i]);
+      // the setting has already been done in parseConfigName()
+    }
+    else if ((strcmp(argv[i], "-dir") == 0) ||
+	     (strcmp(argv[i], "-directory") == 0)) {
       checkArgc(i, argc, argv[i]);
       if (strlen(argv[i]) == 0) {
 	BZDB.unset("directory");
       } else {
 	BZDB.set("directory", argv[i]);
       }
-    } else if (strcmp(argv[i], "-e") == 0 || strcmp(argv[i], "-echo") == 0) {
+    }
+    else if (strcmp(argv[i], "-e") == 0 || strcmp(argv[i], "-echo") == 0) {
       echoToConsole = true;
-    } else if (strcmp(argv[i], "-ea") == 0 || strcmp(argv[i], "-echoAnsi") == 0) {
+    }
+    else if (strcmp(argv[i], "-ea") == 0 || strcmp(argv[i], "-echoAnsi") == 0) {
       echoToConsole = true;
       echoAnsi = true;
-    } else if (strcmp(argv[i], "-h") == 0 ||
+    }
+    else if (strcmp(argv[i], "-h") == 0 ||
 	     strcmp(argv[i], "-help") == 0 ||
 	     strcmp(argv[i], "--help") == 0) {
       usage();
-    } else if (strcmp(argv[i], "-g") == 0 || strcmp(argv[i], "-geometry") == 0) {
-      checkArgc(i, argc, argv[i]);
-      int w, h, x, y, count;
-      char xs = '+', ys = '+';
-      if (strcmp(argv[i], "default") != 0 &&
-	  (((count = sscanf(argv[i], "%dx%d%c%d%c%d",
-		&w, &h, &xs, &x, &ys, &y)) != 6 && count != 2) ||
-	  (xs != '-' && xs != '+') || (ys != '-' && ys != '+'))) {
-	printFatalError("Invalid argument for %s.\n"
-			"Correct format is <width>x<height>[+|-]<x>[+|-]<y>.",
-			argv[i-1]);
-	usage();
-      }
-      BZDB.set("geometry", argv[i]);
-    } else if (strcmp(argv[i], "-latitude") == 0) {
+    }
+    else if (strcmp(argv[i], "-latitude") == 0) {
       checkArgc(i, argc, argv[i]);
       double latitude = atof(argv[i]);
       if (latitude < -90.0 || latitude > 90.0) {
@@ -268,7 +244,8 @@ static void		parse(int argc, char** argv)
 	usage();
       }
       BZDB.set("latitude", argv[i]);
-    } else if (strcmp(argv[i], "-longitude") == 0) {
+    }
+    else if (strcmp(argv[i], "-longitude") == 0) {
       checkArgc(i, argc, argv[i]);
       double longitude = atof(argv[i]);
       if (longitude < -180.0 || longitude > 180.0) {
@@ -276,7 +253,8 @@ static void		parse(int argc, char** argv)
 	usage();
       }
       BZDB.set("longitude", argv[i]);
-    } else if (strcmp(argv[i], "-list") == 0) {
+    }
+    else if (strcmp(argv[i], "-list") == 0) {
       checkArgc(i, argc, argv[i]);
       if (strcmp(argv[i], "default") == 0) {
 	BZDB.set("list", BZDB.getDefault("list"));
@@ -284,7 +262,8 @@ static void		parse(int argc, char** argv)
 	startupInfo.listServerURL = argv[i];
 	BZDB.set("list", argv[i]);
       }
-    } else if (strcmp(argv[i], "-locale") == 0) {
+    }
+    else if (strcmp(argv[i], "-locale") == 0) {
       checkArgc(i, argc, argv[i]);
       BZDB.set("locale", argv[i]);
     } else if (strcmp(argv[i], "-motd") == 0) {
@@ -295,18 +274,23 @@ static void		parse(int argc, char** argv)
 	BZDB.set("motdServer", argv[i]);
       }
       BZDB.unset("disableMOTD");
-    } else if (strcmp(argv[i], "-nomotd") == 0) {
+    }
+    else if (strcmp(argv[i], "-nomotd") == 0) {
       BZDB.set("disableMOTD", "1");
-    } else if (strcmp(argv[i], "-nolist") == 0) {
+    }
+    else if (strcmp(argv[i], "-nolist") == 0) {
       startupInfo.listServerURL = "";
       BZDB.set("list", "");
-    } else if (strcmp(argv[i], "-m") == 0 ||
+    }
+    else if (strcmp(argv[i], "-m") == 0 ||
 		strcmp(argv[i], "-mute") == 0) {
       noAudio = true;
-    } else if (strcmp(argv[i], "-multisample") == 0) {
+    }
+    else if (strcmp(argv[i], "-multisample") == 0) {
       BZDB.set("_multisample", "1");
 #ifdef ROBOT
-    } else if (strcmp(argv[i], "-solo") == 0) {
+    }
+    else if (strcmp(argv[i], "-solo") == 0) {
       checkArgc(i, argc, argv[i]);
       numRobotTanks = atoi(argv[i]);
       if (numRobotTanks < 1 || numRobotTanks > MAX_ROBOTS) {
@@ -314,7 +298,8 @@ static void		parse(int argc, char** argv)
 	usage();
       }
 #endif
-    } else if (strcmp(argv[i], "-team") == 0) {
+    }
+    else if (strcmp(argv[i], "-team") == 0) {
       checkArgc(i, argc, argv[i]);
       if ((strcmp(argv[i], "a") == 0) ||
 	  (strcmp(argv[i], "auto") == 0) ||
@@ -345,22 +330,24 @@ static void		parse(int argc, char** argv)
 		bzfcopyright);
       bail(0);
       exit(0);
-    } else if (strcmp(argv[i], "-window") == 0) {
+    }
+    else if (strcmp(argv[i], "-window") == 0) {
       BZDB.set("_window", "1");
-    } else if (strcmp(argv[i], "-3dfx") == 0 || strcmp(argv[i], "-3Dfx") == 0) {
-#if !defined(__linux__)
-      putenv("MESA_GLX_FX=fullscreen");
-#else
-      setenv("MESA_GLX_FX", "fullscreen", 1);
-#endif
-    } else if (strcmp(argv[i], "-no3dfx") == 0 || strcmp(argv[i], "-no3Dfx") == 0) {
-#if !defined(__linux__)
-      putenv("MESA_GLX_FX=");
-#else
-      unsetenv("MESA_GLX_FX");
-#endif
+      checkArgc(i, argc, argv[i]);
+      int w, h, x, y, count;
+      char xs ='+', ys='+';
+      if (strcmp(argv[i], "default") != 0
+	 && (((count = sscanf(argv[i], "%dx%d%c%d%c%d", &w, &h, &xs, &x, &ys, &y)) != 6 && count != 2)
+	 || (xs != '-' && xs != '+')
+	 || (ys != '-' && ys != '+')))
+      {
+	printFatalError("Invalid argument for %s. \nCorrect format is <width>x<height>[+|-]<x>[+|-].", argv[i-1]);
+	usage();
+      }
+      BZDB.set("geometry", argv[i]);
 #ifdef DEBUG
-    } else if (strcmp(argv[i], "-date") == 0) {
+    }
+    else if (strcmp(argv[i], "-date") == 0) {
       checkArgc(i, argc, argv[i]);
       int month, day, year;
       // FIXME: should use iso yyyy.mm.dd format
@@ -377,23 +364,19 @@ static void		parse(int argc, char** argv)
       userTime.tm_mon = month - 1;
       userTime.tm_year = year;
 #endif
-    } else if (strcmp(argv[i], "-time") == 0) {
+    }
+    else if (strcmp(argv[i], "-time") == 0) {
       checkArgc(i, argc, argv[i]);
       BZDB.set("fixedTime", argv[i]);
-    } else if (strcmp(argv[i], "-notime") == 0) {
+    }
+    else if (strcmp(argv[i], "-notime") == 0) {
       BZDB.unset("fixedTime");
-    } else if (strcmp(argv[i], "-view") == 0) {
+    }
+    else if (strcmp(argv[i], "-view") == 0) {
       checkArgc(i, argc, argv[i]);
       BZDB.set("view", argv[i]);
-    } else if (strcmp(argv[i], "-zoom") == 0) {
-      checkArgc(i, argc, argv[i]);
-      const int zoom = atoi(argv[i]);
-      if (zoom < 1 || zoom > 8) {
-	printFatalError("Invalid argument for %s.", argv[i-1]);
-	usage();
-      }
-      BZDB.set("displayZoom", argv[i]);
-    } else if (strcmp(argv[i], "-zbuffer") == 0) {
+    }
+    else if (strcmp(argv[i], "-zbuffer") == 0) {
       checkArgc(i, argc, argv[i]);
       if (strcmp(argv[i], "on") == 0) {
 	BZDB.set("zbuffer", "1");
@@ -403,83 +386,150 @@ static void		parse(int argc, char** argv)
 	printFatalError("Invalid argument for %s.", argv[i-1]);
 	usage();
       }
-    } else if (strcmp(argv[i], "-eyesep") == 0) {
+    }
+    else if (strcmp(argv[i], "-eyesep") == 0) {
       checkArgc(i, argc, argv[i]);
       BZDB.set("eyesep", argv[i]);
-    } else if (strcmp(argv[i], "-focal") == 0) {
+    }
+    else if (strcmp(argv[i], "-focal") == 0) {
       checkArgc(i, argc, argv[i]);
       BZDB.set("focal", argv[i]);
-    } else if (strncmp(argv[i], "-psn", 4) == 0) {
+    }
+    else if (strncmp(argv[i], "-psn", 4) == 0) {
       std::vector<std::string> args;
       args.push_back(argv[i]);
       printError("Ignoring Finder argument \"{1}\"", &args);
       // ignore process serial number argument (-psn_x_xxxx for MacOS X
-    } else if (strcmp(argv[i], "-badwords") == 0) {
+    }
+    else if (strcmp(argv[i], "-badwords") == 0) {
       checkArgc(i, argc, argv[i], "Missing bad word filter file");
       BZDB.set("filterFilename", argv[i], StateDatabase::ReadOnly);
-    } else if (argv[i][0] != '-') {
-      if (i == argc-1) {
-
-	// find the beginning of the server name, parse the callsign
-	char* serverName;
-	if ((serverName = strchr(argv[i], '@')) != NULL) {
-    char* password;
-	  *serverName = '\0';
-	  if (strlen(argv[i]) >= sizeof(startupInfo.callsign))
-	    printFatalError("Callsign truncated.");
-	  strncpy(startupInfo.callsign, argv[i],
-		  sizeof(startupInfo.callsign) - 1);
-	  startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
-	  if ((password = strchr(startupInfo.callsign, ':')) != NULL) {
-      *(strchr(startupInfo.callsign, ':')) = '\0';
-	    *password = '\0', ++password;
-	    if (strlen(argv[i]) >= sizeof(startupInfo.password))
-	      printFatalError("Password truncated.");
-	    strncpy(startupInfo.password, password, sizeof(startupInfo.password) - 1);
-	    startupInfo.password[sizeof(startupInfo.password) - 1] = '\0';
     }
-	  ++serverName;
-	} else {
-	  serverName = argv[i];
+    else if (argv[i][0] != '-') {
+      if (i == (argc - 1)) {
+        // argv[i] = username:password@server:port
+        // variables to store
+        std::string serverName, callsign, password;
+        int port;
+
+        // start splitting stuff
+	const std::string argument = std::string(argv[i]);
+	const size_t atSplit = argument.find("@");
+	const size_t portSplit = argument.rfind(":");
+	const size_t passSplit = argument.find(":");
+
+        if (atSplit != std::string::npos) { // we found an "@"
+          if (portSplit != std::string::npos) { // we have a port
+            serverName = argument.substr(atSplit + 1, portSplit - atSplit - 1);
+            port = atoi(argument.substr(portSplit + 1, argument.length() - portSplit).c_str());
+
+            if (port < 1 || port > 65535) { // invalid port
+              printFatalError("Bad port, using default %d.", ServerPort);
+              port = ServerPort;
+            }
+          }
+          else { //we don't have a port
+            serverName = argument.substr(atSplit + 1, argument.length() - atSplit);
+            port = ServerPort;
+          }
+
+          if (portSplit != passSplit) { // there's a password to parse
+            callsign = argument.substr(0, passSplit);
+            password = argument.substr(passSplit + 1, atSplit - passSplit - 1);
+          }
+          else { // just a username
+            callsign = argument.substr(0, atSplit);
+            password = "";
+          }
+
+          // length checks and always truncate everything after the max length
+          if (callsign.length() > sizeof(startupInfo.callsign)) {
+            callsign.erase(sizeof(startupInfo.callsign) - 1, std::string::npos);
+            printFatalError("Callsign truncated after %d characters.", sizeof(startupInfo.callsign));
+          }
+          if (password.length() > sizeof(startupInfo.password)) {
+            password.erase(sizeof(startupInfo.password) - 1, std::string::npos);
+            printFatalError("Password truncated after %d characters.", sizeof(startupInfo.password));
+          }
+          if (serverName.length() > sizeof(startupInfo.serverName)) {
+            serverName.erase(sizeof(startupInfo.serverName) - 1, std::string::npos);
+            printFatalError("Server name truncated after %d characters.", sizeof(startupInfo.serverName));
+          }
+
+          // assign variables with strcpy because char[] can't be assigned
+          strcpy(startupInfo.callsign, callsign.c_str());
+          strcpy(startupInfo.password, password.c_str());
+          strcpy(startupInfo.serverName, serverName.c_str());
+          startupInfo.serverPort = port;
+        }
+	else { // there is no callsign/password so only a destination
+          if (portSplit != std::string::npos) { // we have a port
+            serverName = argument.substr(atSplit + 1, portSplit - atSplit - 1);
+            port = atoi(argument.substr(portSplit + 1, argument.length() - portSplit).c_str());
+
+            if (port < 1 || port > 65535) { // invalid port
+              printFatalError("Bad port, using default %d.", ServerPort);
+              port = ServerPort;
+            }
+          }
+          else { //we don't have a port
+            serverName = argument.substr(atSplit + 1, argument.length() - atSplit);
+            port = ServerPort;
+          }
+
+	  // sanity check for length
+          if (serverName.length() > sizeof(startupInfo.serverName)) {
+            serverName.erase(sizeof(startupInfo.serverName) - 1, std::string::npos);
+            printFatalError("Server name truncated after %d characters.", sizeof(startupInfo.serverName));
+          }
+
+          strcpy(startupInfo.serverName, serverName.c_str());
+          startupInfo.serverPort = port;
 	}
 
-	// find the beginning of the port number, parse it
-	char* portNumber;
-	if ((portNumber = strchr(serverName, ':')) != NULL) {
-	  *portNumber = '\0';
-	  ++portNumber;
-	  startupInfo.serverPort = atoi(portNumber);
-	  if (startupInfo.serverPort < 1 || startupInfo.serverPort > 65535) {
-	    startupInfo.serverPort = ServerPort;
-	    printFatalError("Bad port, using default %d.",
-			    startupInfo.serverPort);
-	  }
-	}
-	if (strlen(serverName) >= sizeof(startupInfo.serverName)) {
-	  printFatalError("Server name too long.  Ignoring.");
-	} else {
-	  strcpy(startupInfo.serverName, serverName);
-	  startupInfo.autoConnect = true;
-	}
-      } else {
+	startupInfo.autoConnect = true; // automatically connect on start up
+      }
+      else {
 	printFatalError("Unexpected: %s. Server must go after all options.", argv[i]);
       }
-    } else {
+    }
+    else if (strcmp(argv[i], "-debug") == 0) {
+      debugLevel++;
+    }
+    // has to be the last option that starts with -d
+    else if (strncmp(argv[i], "-d", 2) == 0) {
+      const char num = argv[i][2];
+      if ((num >= '0') && (num <= '9') && (argv[i][3] == 0)) {
+	debugLevel = num - '0';
+      }
+      else {
+	const char* c = argv[i] + 2;
+	while (*c != 0) {
+	  if (*c != 'd') {
+	    printFatalError("Unknown option %s.", argv[i]);
+	    usage();
+	  }
+	  c++;
+	}
+	debugLevel += (int)((c - argv[i]) - 1);
+      }
+    }
+    else {
       printFatalError("Unknown option %s.", argv[i]);
       usage();
     }
   }
 }
 
-static void		parseConfigName(int argc, char** argv)
+static void parseConfigName(int argc, char** argv)
 {
-	for (int i = 1; i < argc; i++) {
-		if (strcmp(argv[i], "-configdir") == 0) {
-			checkArgc(i, argc, argv[i]);
-			setCustomConfigDir(argv[i]);
-			alternateConfig += argv[i];
-		}
-	}
+  for (int i = 1; i < argc; i++) {
+    if (strcmp(argv[i], "-configdir") == 0) {
+      checkArgc(i, argc, argv[i]);
+      setCustomConfigDir(argv[i]);
+      alternateConfig += argv[i];
+    }
+  }
   for (int i = 1; i < argc; i++) {
     if (strcmp(argv[i], "-config") == 0) {
       checkArgc(i, argc, argv[i]);
@@ -495,7 +545,7 @@ static void		parseConfigName(int argc, char** argv)
 // (so user won't have to wait through performance testing again).
 //
 
-void			dumpResources()
+void dumpResources()
 {
   // collect new configuration
 
@@ -536,8 +586,12 @@ void			dumpResources()
 
   BZDB.set("panelopacity", TextUtils::format("%f", RENDERER.getPanelOpacity()));
 
+  BZDB.set("radaropacity", TextUtils::format("%f", RENDERER.getRadarOpacity()));
+
   BZDB.set("radarsize", TextUtils::format("%d", RENDERER.getRadarSize()));
 
+  BZDB.set("panelheight", TextUtils::format("%d", RENDERER.getPanelHeight()));
+
   BZDB.set("mouseboxsize", TextUtils::format("%d", RENDERER.getMaxMotionFactor()));
 
   // don't save these configurations
@@ -560,7 +614,7 @@ void			dumpResources()
     BZDB.set(TextUtils::format("silencedPerson%d", i), list[i]);
   }
 
-  BZDB.set("email", startupInfo.email); // note email of zero length does not stick
+  BZDB.set("motto", startupInfo.motto);
 
   BZDB.set("serverCacheAge", TextUtils::format("%1d", (long)(ServerListCache::get())->getMaxCacheAge()));
 
@@ -600,8 +654,8 @@ static void createCacheSignature ()
   cacheTagName += "CACHEDIR.TAG";
   std::ostream* cacheTag = FILEMGR.createDataOutStream(cacheTagName, true, true);
   if (cacheTag != NULL) {
-    cacheTag->write(cacheSignature, strlen(cacheSignature));
-    cacheTag->write(cacheComment, strlen(cacheComment));
+    cacheTag->write(cacheSignature, strlen(cacheSignature)); // Flawfinder: ignore
+    cacheTag->write(cacheComment, strlen(cacheComment)); // Flawfinder: ignore
   }
   delete cacheTag;
 
@@ -639,6 +693,8 @@ int			main(int argc, char** argv)
   }
 #endif
 
+  initGlobalAres();
+
   WordFilter *filter = (WordFilter *)NULL;
 
   argv0 = argv[0];
@@ -686,7 +742,7 @@ int			main(int argc, char** argv)
   createCacheSignature();
 
   // initialize global objects and classes
-  bzfsrand(time(0));
+  bzfsrand((unsigned int)time(0));
 
     // set default DB entries
   for (unsigned int gi = 0; gi < numGlobalDBItems; ++gi) {
@@ -704,17 +760,6 @@ int			main(int argc, char** argv)
 
   Flags::init();
 
-  if (getenv("BZFLAGID")) {
-    BZDB.set("callsign", getenv("BZFLAGID"));
-    strncpy(startupInfo.callsign, getenv("BZFLAGID"),
-					sizeof(startupInfo.callsign) - 1);
-    startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
-  } else if (getenv("BZID")) {
-    BZDB.set("callsign", getenv("BZID"));
-    strncpy(startupInfo.callsign, getenv("BZID"),
-					sizeof(startupInfo.callsign) - 1);
-    startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
-  }
   time_t timeNow;
   time(&timeNow);
   userTime = *localtime(&timeNow);
@@ -755,11 +800,13 @@ int			main(int argc, char** argv)
   // restore some configuration (command line overrides these)
   if (startupInfo.hasConfiguration) {
     if (BZDB.isSet("callsign")) {
+      // Flawfinder: ignore
       strncpy(startupInfo.callsign, BZDB.get("callsign").c_str(),
 					sizeof(startupInfo.callsign) - 1);
       startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
     }
     if (BZDB.isSet("password")) {
+      // Flawfinder: ignore
       strncpy(startupInfo.password, BZDB.get("password").c_str(),
 					sizeof(startupInfo.password) - 1);
       startupInfo.password[sizeof(startupInfo.password) - 1] = '\0';
@@ -770,6 +817,7 @@ int			main(int argc, char** argv)
       startupInfo.team = Team::getTeam(value);
     }
     if (BZDB.isSet("server")) {
+      // Flawfinder: ignore
       strncpy(startupInfo.serverName, BZDB.get("server").c_str(),
 					sizeof(startupInfo.serverName) - 1);
       startupInfo.serverName[sizeof(startupInfo.serverName) - 1] = '\0';
@@ -778,31 +826,6 @@ int			main(int argc, char** argv)
       startupInfo.serverPort = atoi(BZDB.get("port").c_str());
     }
 
-    // check for reassigned team colors
-    if (BZDB.isSet("roguecolor"))
-      setTeamColor(RogueTeam, BZDB.get("roguecolor"));
-    if (BZDB.isSet("redcolor"))
-      setTeamColor(RedTeam, BZDB.get("redcolor"));
-    if (BZDB.isSet("greencolor"))
-      setTeamColor(GreenTeam, BZDB.get("greencolor"));
-    if (BZDB.isSet("bluecolor"))
-      setTeamColor(BlueTeam, BZDB.get("bluecolor"));
-    if (BZDB.isSet("purplecolor"))
-      setTeamColor(PurpleTeam, BZDB.get("purplecolor"));
-
-    // check for reassigned radar colors
-    if (BZDB.isSet("rogueradar"))
-      setRadarColor(RogueTeam, BZDB.get("rogueradar"));
-    if (BZDB.isSet("redradar"))
-      setRadarColor(RedTeam, BZDB.get("redradar"));
-    if (BZDB.isSet("greenradar"))
-      setRadarColor(GreenTeam, BZDB.get("greenradar"));
-    if (BZDB.isSet("blueradar"))
-      setRadarColor(BlueTeam, BZDB.get("blueradar"));
-    if (BZDB.isSet("purpleradar"))
-      setRadarColor(PurpleTeam, BZDB.get("purpleradar"));
-
-
     // ignore window name in config file (it's used internally)
     BZDB.unset("_window");
     BZDB.unset("_multisample");
@@ -823,12 +846,13 @@ int			main(int argc, char** argv)
 #ifdef _WIN32
   // this is cheap but it will work on windows
   // clear out the stdout file
-  if (echoToConsole){
-	  FILE	*fp = fopen ("stdout.txt","w");
-	  if (fp) {
-		  fprintf(fp,"stdout started\r\n" );
-		  fclose(fp);
-	  }
+  if (echoToConsole) {
+    std::string filename = getConfigDirName() + "stdout.txt";
+    FILE *fp = fopen (filename.c_str(), "w");
+    if (fp) {
+      fprintf(fp,"stdout started\r\n" );
+      fclose(fp);
+    }
   }
 #endif
 
@@ -846,7 +870,9 @@ int			main(int argc, char** argv)
   if (BZDB.isSet("fixedTime")) {
     int hours, minutes, seconds;
     char dbTime[256];
+    // Flawfinder: ignore
     strncpy(dbTime, BZDB.get("fixedTime").c_str(), sizeof(dbTime) - 1);
+    dbTime[sizeof(dbTime) - 1] = '\0';
     if (sscanf(dbTime, "%d:%d:%d", &hours, &minutes, &seconds) != 3 ||
 	hours < 0 || hours > 23 ||
 	minutes < 0 || minutes > 59 ||
@@ -901,36 +927,14 @@ int			main(int argc, char** argv)
     }
   }
 
-  // get email address if not anonymous
-  std::string email = "default";
-  if (!anonymous) {
-    if (BZDB.isSet("email")) {
-      email = BZDB.get("email");
-    }
+  // use empty motto string unless previously set
+  std::string motto = BZDB.get("motto");
+  motto = motto.substr(0, sizeof(startupInfo.motto) - 1);
+  //Flawfinder: ignore
+  strcpy(startupInfo.motto, motto.c_str());
 
-    if (email == "default") {
-      email = anonymousName;
-      std::string hostname = Address::getHostName();
-#if defined(_WIN32)
-      char username[256];
-      DWORD usernameLen = sizeof(username);
-      GetUserName(username, &usernameLen);
-#else
-      struct passwd* pwent = getpwuid(getuid());
-      const char* username = pwent ? pwent->pw_name : NULL;
-#endif
-      if (hostname == "") {
-	hostname = "unknown";
-      }
-      if (username) {
-	email = username;
-	email += "@";
-	email += hostname;
-      }
-    }
-  }
-  email = email.substr(0, sizeof(startupInfo.email) - 1);
-  strcpy(startupInfo.email, email.c_str());
+  // load the default values for shot colors
+  Team::updateShotColors();
 
   // make platform factory
   PlatformFactory* platformFactory = PlatformFactory::getInstance();
@@ -954,11 +958,8 @@ int			main(int argc, char** argv)
   }
   window->setTitle("bzflag");
 
-  // create & initialize the joystick
+  // create the joystick
   BzfJoystick* joystick = platformFactory->createJoystick();
-  joystick->initJoystick(BZDB.get("joystickname").c_str());
-  joystick->setXAxis(BZDB.get("jsXAxis"));
-  joystick->setYAxis(BZDB.get("jsYAxis"));
 
   // Change audio driver if requested
   if (BZDB.isSet("audioDriver"))
@@ -975,14 +976,37 @@ int			main(int argc, char** argv)
 
 #if (defined(_WIN32) || defined(WIN32))
     char exePath[MAX_PATH];
+    char dataPath[MAX_PATH];
     GetModuleFileName(NULL,exePath,MAX_PATH);
     char* last = strrchr(exePath,'\\');
     if (last)
       *last = '\0';
-    strcat(exePath,"\\data");
+
+    strcpy(dataPath,exePath);
+
+    char temp[MAX_PATH];
+    getcwd(temp,MAX_PATH);
+
+    // find the data dir
+    strcat(dataPath,"\\data");
+
+    if (chdir(dataPath) != 0)
+    {
+      strcpy(dataPath,exePath);
+
+      char* last = strrchr(dataPath,'\\');
+      if (last)
+	*last = '\0';
+
+      strcat(dataPath,"\\data");
+    }
+
+    chdir(temp);
     BzfMedia *media = PlatformFactory::getMedia();
     if (media)
-      media->setMediaDirectory(exePath);
+      media->setMediaDirectory(dataPath);
+
+    FileManager::instance().setDataPath(std::string(dataPath));
 #else
     // It's only checking existence of l10n directory
     std::string mediadir = DEFAULT_MEDIA_DIR;
@@ -1053,8 +1077,7 @@ int			main(int argc, char** argv)
   }
 
   // set window size (we do it here because the OpenGL context isn't yet
-  // bound and 3Dfx passthrough cards use the window size to determine
-  // the resolution to use)
+  // bound.)
   const bool useFullscreen = needsFullscreen();
   if (useFullscreen) {
 #ifndef HAVE_SDL
@@ -1108,10 +1131,18 @@ int			main(int argc, char** argv)
       setSoundVolume(static_cast<int>(BZDB.eval("volume")));
   }
 
+  // Initialize the joystick
+  joystick->initJoystick(BZDB.get("joystickname").c_str());
+  joystick->setXAxis(BZDB.get("jsXAxis"));
+  joystick->setYAxis(BZDB.get("jsYAxis"));
+
   // set main window's minimum size (arbitrary but should be big enough
   // to see stuff in control panel)
   pmainWindow->setMinSize(256, 192);
 
+  // enable vsync if needed
+  pmainWindow->getWindow()->setVerticalSync(BZDB.evalInt("saveEnergy") == 2);
+
   // initialize graphics state
   pmainWindow->getWindow()->makeCurrent();
   glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
@@ -1140,7 +1171,7 @@ int			main(int argc, char** argv)
   // there's no sense in continuing.
   const char* const glRenderer = (const char*)glGetString(GL_RENDERER);
   if (!glRenderer) {
-    // bad code, no donut for you
+    // bad code, no doughnut for you
 
     GLenum error = GL_NO_ERROR;
     while ((error = glGetError()) != GL_NO_ERROR) {
@@ -1192,13 +1223,12 @@ int			main(int argc, char** argv)
   // add the zbuffer callback here, after the OpenGL context is initialized
   BZDB.addCallback("zbuffer", setDepthBuffer, NULL);
 
-  // if we're running on 3Dfx fullscreen add a fake cursor.
-  // let the defaults file override this, though.
+  //add a fake cursor. Let the defaults file override this, though.
   if (!BZDB.isSet("fakecursor")) {
     // check that the glrenderer is Mesa Glide
-    if ((glRenderer != NULL) && (strncmp(glRenderer, "Mesa Glide", 10) == 0 ||
-	strncmp(glRenderer, "3Dfx", 4) == 0))
+    if ((glRenderer != NULL) && (strncmp(glRenderer, "Mesa Glide", 10) == 0)){
       BZDB.set("fakecursor", "1");
+    }
   }
 
   // set gamma if set in resources and we have gamma control
@@ -1250,9 +1280,15 @@ int			main(int argc, char** argv)
     if (BZDB.isSet("panelopacity"))
       RENDERER.setPanelOpacity(BZDB.eval("panelopacity"));
 
+    if (BZDB.isSet("radaropacity"))
+          RENDERER.setRadarOpacity(BZDB.eval("radaropacity"));
+
     if (BZDB.isSet("radarsize"))
       RENDERER.setRadarSize(BZDB.getIntClamped("radarsize", 0, GUIOptionsMenu::maxRadarSize));
 
+    if (BZDB.isSet("panelheight"))
+      RENDERER.setPanelHeight(BZDB.getIntClamped("panelheight", 0, GUIOptionsMenu::maxRadarSize));
+
     if (BZDB.isSet("mouseboxsize"))
       RENDERER.setMaxMotionFactor(atoi(BZDB.get("mouseboxsize").c_str()));
   }
@@ -1330,6 +1366,11 @@ int			main(int argc, char** argv)
   }
 
   // shut down
+
+
+  killGlobalAres();
+  AresHandler::globalShutdown();
+
   if (filter != NULL)
     delete filter;
   filter = NULL;
@@ -1378,6 +1419,14 @@ int			main(int argc, char** argv)
 
 int WINAPI		WinMain(HINSTANCE instance, HINSTANCE, LPSTR _cmdLine, int)
 {
+  // Tell Windows that we are DPI aware so that it stop trying to scale for us
+  HMODULE hUser32 = LoadLibrary(_T("user32.dll"));
+  typedef BOOL (*SetProcessDPIAwareFunc)();
+  SetProcessDPIAwareFunc setDPIAware = (SetProcessDPIAwareFunc)GetProcAddress(hUser32, "SetProcessDPIAware");
+  if (setDPIAware)
+    setDPIAware();
+  FreeLibrary(hUser32);
+
   // convert command line to argc and argv.  note that it's too late
   // to do this right because spaces that were embedded in a single
   // argument now look like like normal spaces.  not much we can do
