@@ -1,14 +1,14 @@
 /* bzflag
-* Copyright (c) 1993-2010 Tim Riker
-*
-* This package is free software;  you can redistribute it and/or
-* modify it under the terms of the license found in the file
-* named COPYING that should have accompanied this file.
-*
-* THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
-* IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
-* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-*/
+ * Copyright (c) 1993-2016 Tim Riker
+ *
+ * This package is free software;  you can redistribute it and/or
+ * modify it under the terms of the license found in the file
+ * named COPYING that should have accompanied this file.
+ *
+ * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /*
 * EffectsRenderer:
@@ -31,10 +31,13 @@
 
 #include "Singleton.h"
 
+#include "TankSceneNode.h"
+#include "Flag.h"
+#include "Player.h"
+
 
 #define EFFECTS (EffectsRenderer::instance())
 
-
 class BasicEffect
 {
 public:
@@ -63,155 +66,26 @@ protected:
 	float	lastTime;
 	float	deltaTime;
 	float	age;
+	float	lifeParam;
+};
+
+class DeathEffect : public BasicEffect, public TankDeathOverride
+{
+public:
+	DeathEffect() : BasicEffect(),TankDeathOverride(),player(NULL) {};
+	virtual ~DeathEffect(){/*if(player)player->setDeathEffect(NULL)*/;}
+
+	virtual bool SetDeathRenderParams ( TankDeathOverride::DeathParams &UNUSED(params) ){return false;}
+	virtual bool ShowExplosion ( void ){return true;}
+	virtual bool GetDeathVector ( fvec3 &UNUSED(vel) ){return false;}
+
+	void setPlayer ( Player* p){player=p;}
+protected:
+	Player *player;
 };
 
 typedef std::vector<BasicEffect*>	tvEffectsList;
 
-class StdSpawnEffect : public BasicEffect
-{
-public:
-	StdSpawnEffect();
-	virtual ~StdSpawnEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-
-protected:
-	int				texture;
-	OpenGLGState	ringState;
-
-	float			radius;
-};
-
-class ConeSpawnEffect : public StdSpawnEffect
-{
-public:
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-};
-
-class RingSpawnEffect : public StdSpawnEffect
-{
-public:
-	RingSpawnEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-
-private:
-	void drawRing(int n, float coreAlpha);
-
-	float maxZ;
-	float ringRange;
-	float numRings;
-};
-
-class StdShotEffect : public BasicEffect
-{
-public:
-	StdShotEffect();
-	virtual ~StdShotEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-
-protected:
-	int				texture;
-	OpenGLGState	ringState;
-
-	float			radius;
-};
-
-class FlashShotEffect : public StdShotEffect
-{
-public:
-	FlashShotEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-
-private:
-	float	     length;
-};
-
-class StdDeathEffect : public BasicEffect
-{
-public:
-	StdDeathEffect();
-	virtual ~StdDeathEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-
-protected:
-	int				texture;
-	OpenGLGState	ringState;
-
-	float			radius;
-};
-
-class StdLandEffect : public BasicEffect
-{
-public:
-	StdLandEffect();
-	virtual ~StdLandEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-
-protected:
-	int				texture;
-	OpenGLGState	ringState;
-
-	float			radius;
-};
-
-class StdGMPuffEffect : public BasicEffect
-{
-public:
-	StdGMPuffEffect();
-	virtual ~StdGMPuffEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-protected:
-	int				texture;
-	OpenGLGState	ringState;
-
-	float			radius;
-};
-
-class StdRicoEffect : public BasicEffect
-{
-public:
-	StdRicoEffect();
-	virtual ~StdRicoEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-protected:
-	int				texture;
-	OpenGLGState	ringState;
-
-	float			radius;
-};
-
-class StdShotTeleportEffect : public BasicEffect
-{
-public:
-	StdShotTeleportEffect();
-	virtual ~StdShotTeleportEffect();
-
-	virtual bool update ( float time );
-	virtual void draw ( const SceneRenderer& sr );
-protected:
-	int				texture;
-	OpenGLGState	ringState;
-
-	float			radius;
-};
-
-
 class EffectsRenderer : public Singleton<EffectsRenderer>
 {
 public:
@@ -243,7 +117,7 @@ public:
 	std::vector<std::string> getGMPuffEffectTypes ( void );
 
 	// death effects
-	void addDeathEffect ( const float* rgb, const float* pos, float rot );
+	DeathEffect* addDeathEffect ( const float* rgb, const float* pos, float rot, int reason, Player *player, FlagType* flag = NULL );
 	std::vector<std::string> getDeathEffectTypes ( void );
 
 	// landing effects
@@ -278,4 +152,3 @@ protected:
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
