@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -34,14 +34,17 @@
 #include "TimeKeeper.h"
 #include "TextUtils.h"
 
+#if !defined(CPPUTEST)
 // bzfs specific headers
 #include "bzfs.h"
+#endif // CPPUTEST
 
 
 void AccessControlList::ban(in_addr &ipAddr, const char *bannedBy, int period,
-			    const char *reason, bool fromMaster)
+			    unsigned char cidr, const char *reason,
+			    bool fromMaster)
 {
-  BanInfo toban(ipAddr, bannedBy, period,fromMaster);
+  BanInfo toban(ipAddr, bannedBy, period, cidr, fromMaster);
   if (reason) toban.reason = reason;
   banList_t::iterator oldit = std::find(banList.begin(), banList.end(), toban);
   if (oldit != banList.end()) // IP already in list? -> replace
@@ -67,17 +70,18 @@ bool AccessControlList::ban(const char *ipList, const char *bannedBy, int period
   bool added = false;
 
   in_addr mask;
+  unsigned char cidr;
   while ((pSep = strchr(pStart, ',')) != NULL) {
     *pSep = 0;
-    if (convert(pStart, mask)) {
-      ban(mask, bannedBy, period, NULL, fromMaster);
+    if (convert(pStart, mask, cidr)) {
+      ban(mask, bannedBy, period, cidr, NULL, fromMaster);
       added = true;
     }
     *pSep = ',';
     pStart = pSep + 1;
   }
-  if (convert(pStart, mask)) {
-    ban(mask, bannedBy, period, reason, fromMaster);
+  if (convert(pStart, mask, cidr)) {
+    ban(mask, bannedBy, period, cidr, reason, fromMaster);
     added = true;
   }
   free(buf);
@@ -113,9 +117,9 @@ void AccessControlList::idBan(std::string idpat, const char *bannedBy, int perio
 }
 
 
-bool AccessControlList::unban(in_addr &ipAddr)
+bool AccessControlList::unban(in_addr &ipAddr, unsigned char cidr)
 {
-  banList_t::iterator it = std::remove(banList.begin(), banList.end(), BanInfo(ipAddr));
+  banList_t::iterator it = std::remove(banList.begin(), banList.end(), BanInfo(ipAddr, "", 0, cidr));
   if (it != banList.end()) {
     banList.erase(it, banList.end());
     return true;
@@ -138,15 +142,16 @@ bool AccessControlList::unban(const char *ipList)
   bool success = false;
 
   in_addr mask;
+  unsigned char cidr;
   while ((pSep = strchr(pStart, ',')) != NULL) {
     *pSep = 0;
-    if (convert(pStart, mask))
-      success|=unban(mask);
+    if (convert(pStart, mask, cidr))
+      success|=unban(mask, cidr);
     *pSep = ',';
     pStart = pSep + 1;
   }
-  if (convert(pStart, mask))
-    success|=unban(mask);
+  if (convert(pStart, mask, cidr))
+    success|=unban(mask, cidr);
   free(buf);
   return success;
 }
@@ -179,16 +184,7 @@ bool AccessControlList::validate(const in_addr &ipAddr, BanInfo *info)
   expire();
 
   for (banList_t::iterator it = banList.begin(); it != banList.end(); ++it) {
-    in_addr mask = it->addr;
-
-    if ((ntohl(mask.s_addr) & 0x00ffffff) == 0x00ffffff)
-      mask.s_addr = htonl((ntohl(mask.s_addr) & 0xff000000) | (ntohl(ipAddr.s_addr) & 0x00ffffff));
-    else if ((ntohl(mask.s_addr) & 0x0000ffff) == 0x0000ffff)
-      mask.s_addr = htonl((ntohl(mask.s_addr) & 0xffff0000) | (ntohl(ipAddr.s_addr) & 0x0000ffff));
-    else if ((ntohl(mask.s_addr) & 0x000000ff) == 0x000000ff)
-      mask.s_addr = htonl((ntohl(mask.s_addr) & 0xffffff00) | (ntohl(ipAddr.s_addr) & 0x000000ff));
-
-    if (mask.s_addr == ipAddr.s_addr)	{
+    if (it->contains(ipAddr)) {
       if (info)
 	*info = *it;
       return false;
@@ -198,39 +194,15 @@ bool AccessControlList::validate(const in_addr &ipAddr, BanInfo *info)
 }
 
 
-bool AccessControlList::does_match(const char *targ, int targlen, const char *pat, int patlen)
-{
-  if (!targlen)
-    return patlen == 0;
-  if (!patlen)
-    return targlen == 0;
-
-  while (*pat != '*') {
-    if (*pat != *targ)
-      return false;
-
-    pat++; patlen--;
-    targ++; targlen--;
-    if (!targlen)
-      return patlen == 0;
-    if (!patlen)
-      return targlen == 0;
-  }
-
-  // found a *, search for matches in the rest of the string
-  for (int pos = 0; pos <= targlen; pos++)
-    if (does_match(targ+pos, targlen-pos, pat+1, patlen-1))
-      return true;
-  return false;
-}
-
-
 bool AccessControlList::hostValidate(const char *hostname, HostBanInfo *info)
 {
   expire();
 
+  const std::string upperHost = TextUtils::toupper(hostname);
+
   for (hostBanList_t::iterator it = hostBanList.begin(); it != hostBanList.end(); ++it) {
-    if (does_match(hostname, strlen(hostname), it->hostpat.c_str(), it->hostpat.length())) {
+    const std::string upperPattern = TextUtils::toupper(it->hostpat);
+    if (glob_match(upperPattern, upperHost)) {
       if (info)
 	*info = *it;
       return false;
@@ -277,33 +249,53 @@ static std::string makeGlobPattern(const char* str)
   return pattern;
 }
 
-
-static std::string getBanMaskString(in_addr mask)
+std::string AccessControlList::getBanMaskString(in_addr mask, unsigned char cidr)
 {
+  // Check for out of range CIDR
+  if (cidr == 0 || cidr > 32)
+    return "";
+
   std::ostringstream os;
-  os << (ntohl(mask.s_addr) >> 24) << '.';
-  if ((ntohl(mask.s_addr) & 0x00ffffff) == 0x00ffffff) {
-    os << "*.*.*";
-  } else {
-    os << ((ntohl(mask.s_addr) >> 16) & 0xff) << '.';
-    if ((ntohl(mask.s_addr) & 0x0000ffff) == 0x0000ffff) {
-      os << "*.*";
+
+  // Generate /8, /16, and /24 in the wildcard format, and show /32 without
+  // a CIDR
+  if (cidr % 8 == 0) {
+    os << (ntohl(mask.s_addr) >> 24) << '.';
+    if (cidr == 8) {
+      os << "*.*.*";
     } else {
-      os << ((ntohl(mask.s_addr) >> 8) & 0xff) << '.';
-      if ((ntohl(mask.s_addr) & 0x000000ff) == 0x000000ff)
-	os << "*";
-      else
-	os << (ntohl(mask.s_addr) & 0xff);
+      os << ((ntohl(mask.s_addr) >> 16) & 0xff) << '.';
+      if (cidr == 16) {
+	os << "*.*";
+      } else {
+	os << ((ntohl(mask.s_addr) >> 8) & 0xff) << '.';
+	if (cidr == 24) {
+	  os << "*";
+	} else {
+	  os << (ntohl(mask.s_addr) & 0xff);
+	}
+      }
     }
+  } else {
+    // Handle other CIDR values
+    mask.s_addr &= htonl(0xffffffff << (32 - cidr)); // zero out the host bits
+
+    os << (ntohl(mask.s_addr) >> 24) << '.';
+    os << ((ntohl(mask.s_addr) >> 16) & 0xff) << '.';
+    os << ((ntohl(mask.s_addr) >> 8) & 0xff) << '.';
+    os << (ntohl(mask.s_addr) & 0xff);
+    os << '/' << (unsigned int)cidr;
   }
+
   return os.str();
 }
 
 
+#if !defined(CPPUTEST)
 void AccessControlList::sendBan(PlayerId id, const BanInfo &baninfo)
 {
   std::ostringstream os;
-  os << getBanMaskString(baninfo.addr);
+  os << getBanMaskString(baninfo.addr, baninfo.cidr);
 
   // print duration when < 1 year
   double duration = baninfo.banEnd - TimeKeeper::getCurrent();
@@ -314,13 +306,13 @@ void AccessControlList::sendBan(PlayerId id, const BanInfo &baninfo)
     os << " (m)";
   if (baninfo.bannedBy.length())
     os << " banned by: " << baninfo.bannedBy;
-  sendMessage(ServerPlayer, id, os.str().c_str());
+    bz_sendTextMessage(BZ_SERVER, id, os.str().c_str());
 
   // add reason, if any
   if (baninfo.reason.size()) {
     std::ostringstream ost;
     ost << "   reason: " << baninfo.reason;
-    sendMessage(ServerPlayer, id, ost.str().c_str());
+    bz_sendTextMessage(BZ_SERVER, id, ost.str().c_str());
   }
 }
 
@@ -328,8 +320,8 @@ void AccessControlList::sendBan(PlayerId id, const BanInfo &baninfo)
 void AccessControlList::sendBans(PlayerId id, const char* pattern)
 {
   expire();
-  sendMessage(ServerPlayer, id, "IP Ban List");
-  sendMessage(ServerPlayer, id, "-----------");
+  bz_sendTextMessage(BZ_SERVER, id, "IP Ban List");
+  bz_sendTextMessage(BZ_SERVER, id, "-----------");
 
   const std::string glob = makeGlobPattern(pattern);
 
@@ -337,7 +329,7 @@ void AccessControlList::sendBans(PlayerId id, const char* pattern)
   for (banList_t::iterator it = banList.begin(); it != banList.end(); ++it) {
     const BanInfo& bi = *it;
     if (bi.fromMaster &&
-	(glob_match(glob, getBanMaskString(bi.addr)) ||
+	(glob_match(glob, getBanMaskString(bi.addr, bi.cidr)) ||
 	 glob_match(glob, TextUtils::toupper(bi.reason)) ||
 	 glob_match(glob, TextUtils::toupper(bi.bannedBy)))) {
       sendBan(id, *it);
@@ -348,7 +340,7 @@ void AccessControlList::sendBans(PlayerId id, const char* pattern)
   for (banList_t::iterator it = banList.begin(); it != banList.end(); ++it) {
     const BanInfo& bi = *it;
     if (!bi.fromMaster &&
-	(glob_match(glob, getBanMaskString(bi.addr)) ||
+	(glob_match(glob, getBanMaskString(bi.addr, bi.cidr)) ||
 	 glob_match(glob, TextUtils::toupper(bi.reason)) ||
 	 glob_match(glob, TextUtils::toupper(bi.bannedBy)))) {
       sendBan(id, *it);
@@ -376,23 +368,30 @@ void AccessControlList::sendHostBans(PlayerId id, const char* pattern)
     }
 
     char *pMsg = banlistmessage;
-    sprintf(pMsg, "%s", bi.hostpat.c_str());
+    snprintf(pMsg, MessageLen, "%s", bi.hostpat.c_str());
 
     // print duration when < 1 year
     double duration = bi.banEnd - TimeKeeper::getCurrent();
-    if (duration < 365.0f * 24 * 3600)
-      sprintf(pMsg + strlen(pMsg)," (%.1f minutes)", duration / 60);
-    if (bi.bannedBy.length())
-      sprintf(pMsg + strlen(pMsg), " banned by: %s", bi.bannedBy.c_str());
-    if (bi.fromMaster)
-      sprintf(pMsg + strlen(pMsg), "(m)");
+    int remaining;
+    remaining = MessageLen - strlen(pMsg);
+    if (duration < 365.0f * 24 * 3600) {
+      snprintf(pMsg + strlen(pMsg), remaining, " (%.1f minutes)", duration / 60);
+    }
+    remaining = MessageLen - strlen(pMsg);
+    if (bi.bannedBy.length()) {
+      snprintf(pMsg + strlen(pMsg), remaining, " banned by: %s", bi.bannedBy.c_str());
+    }
+    remaining = MessageLen - strlen(pMsg);
+    if (bi.fromMaster) {
+      snprintf(pMsg + strlen(pMsg), remaining, "(m)");
+    }
 
     sendMessage(ServerPlayer, id, banlistmessage);
 
     // add reason, if any
     if (bi.reason.size()) {
       pMsg = banlistmessage;
-      sprintf(pMsg, "   reason: %s", bi.reason.c_str());
+      snprintf(pMsg, MessageLen, "   reason: %s", bi.reason.c_str());
       sendMessage(ServerPlayer, id, banlistmessage);
     }
   }
@@ -421,26 +420,33 @@ void AccessControlList::sendIdBans(PlayerId id, const char* pattern)
 
     bool useQuotes = (bi.idpat.find_first_of(" \t") != std::string::npos);
     if (useQuotes) {
-      sprintf(pMsg, "\"%s\"", bi.idpat.c_str());
+      snprintf(pMsg, MessageLen, "\"%s\"", bi.idpat.c_str());
     } else {
-      sprintf(pMsg, "%s", bi.idpat.c_str());
+      snprintf(pMsg, MessageLen, "%s", bi.idpat.c_str());
     }
 
     // print duration when < 1 year
     double duration = bi.banEnd - TimeKeeper::getCurrent();
-    if (duration < 365.0f * 24 * 3600)
-      sprintf(pMsg + strlen(pMsg)," (%.1f minutes)", duration / 60);
-    if (bi.bannedBy.length())
-      sprintf(pMsg + strlen(pMsg), " banned by: %s", bi.bannedBy.c_str());
-    if (bi.fromMaster)
-      sprintf(pMsg + strlen(pMsg), "(m)");
+    int remaining;
+    remaining = MessageLen - strlen(pMsg);
+    if (duration < 365.0f * 24 * 3600) {
+      snprintf(pMsg + strlen(pMsg), remaining, " (%.1f minutes)", duration / 60);
+    }
+    remaining = MessageLen - strlen(pMsg);
+    if (bi.bannedBy.length()) {
+      snprintf(pMsg + strlen(pMsg), remaining, " banned by: %s", bi.bannedBy.c_str());
+    }
+    remaining = MessageLen - strlen(pMsg);
+    if (bi.fromMaster) {
+      snprintf(pMsg + strlen(pMsg), remaining, "(m)");
+    }
 
     sendMessage(ServerPlayer, id, banlistmessage);
 
     // add reason, if any
     if (bi.reason.size()) {
       pMsg = banlistmessage;
-      sprintf(pMsg, "   reason: %s", bi.reason.c_str());
+      snprintf(pMsg, MessageLen, "   reason: %s", bi.reason.c_str());
       sendMessage(ServerPlayer, id, banlistmessage);
     }
   }
@@ -509,12 +515,14 @@ bool AccessControlList::load() {
       idBan(bzId, (bannedBy.size() ? bannedBy.c_str(): NULL), banEnd,
 	    (reason.size() > 0 ? reason.c_str() : NULL));
     } else {
-      std::string::size_type n;
-      while ((n = ipAddress.find('*')) != std::string::npos) {
-	ipAddress.replace(n, 1, "255");
+      // Handle CIDR ban formats
+      in_addr ip;
+      unsigned char cidr;
+      if (convert(ipAddress, ip, cidr)) {
+	ban(ip, (bannedBy.size() ? bannedBy.c_str(): NULL), banEnd,
+	    cidr, (reason.size() > 0 ? reason.c_str() : NULL));
       }
-      if (!ban(ipAddress, (bannedBy.size() ? bannedBy.c_str(): NULL), banEnd,
-	       (reason.size() > 0 ? reason.c_str() : NULL))) {
+      else {
 	logDebugMessage(3,"Banfile: bad ban\n");
 	return false;
       }
@@ -607,23 +615,7 @@ void AccessControlList::save() {
   for (banList_t::const_iterator it = banList.begin(); it != banList.end(); ++it) {
     if (!it->fromMaster) {	// don't save stuff from the master list
       // print address
-      in_addr mask = it->addr;
-      os << ((ntohl(mask.s_addr) >> 24) % 256) << '.';
-      if ((ntohl(mask.s_addr) & 0x00ffffff) == 0x00ffffff) {
-	os << "*.*.*";
-      } else {
-	os << ((ntohl(mask.s_addr) >> 16) % 256) << '.';
-	if ((ntohl(mask.s_addr) & 0x0000ffff) == 0x0000ffff) {
-	  os << "*.*";
-	} else {
-	  os << ((ntohl(mask.s_addr) >> 8) % 256) << '.';
-	  if ((ntohl(mask.s_addr) & 0x000000ff) == 0x000000ff)
-	    os << "*";
-	  else
-	    os << (ntohl(mask.s_addr) % 256);
-	}
-      }
-      os << '\n';
+      os << getBanMaskString(it->addr, it->cidr) << '\n';
 
       // print ban end, banner, and reason
       if (it->banEnd.getSeconds() ==
@@ -681,21 +673,21 @@ void AccessControlList::purge(bool master) {
     if (bItr->fromMaster == master)
       bItr = banList.erase(bItr);
     else
-      bItr++;
+      ++bItr;
   }
   hostBanList_t::iterator	hItr = hostBanList.begin();
   while (hItr != hostBanList.end()) {
     if (hItr->fromMaster == master)
       hItr = hostBanList.erase(hItr);
     else
-      hItr++;
+      ++hItr;
   }
   idBanList_t::iterator	iItr = idBanList.begin();
   while (iItr != idBanList.end()) {
     if (iItr->fromMaster == master) {
       iItr = idBanList.erase(iItr);
     } else {
-      iItr++;
+      ++iItr;
     }
   }
 }
@@ -719,7 +711,7 @@ std::vector<std::pair<std::string, std::string> > AccessControlList::listMasterB
   std::string explain;
 
   banList_t::const_iterator bItr;
-  for (bItr = banList.begin(); bItr != banList.end(); bItr++) {
+  for (bItr = banList.begin(); bItr != banList.end(); ++bItr) {
     if (bItr->fromMaster) {
       explain = TextUtils::format("%s (banned by %s)",
 				  bItr->reason.c_str(), bItr->bannedBy.c_str());
@@ -729,7 +721,7 @@ std::vector<std::pair<std::string, std::string> > AccessControlList::listMasterB
     }
   }
   hostBanList_t::const_iterator hItr;
-  for (hItr = hostBanList.begin(); hItr != hostBanList.end(); hItr++) {
+  for (hItr = hostBanList.begin(); hItr != hostBanList.end(); ++hItr) {
     if (hItr->fromMaster) {
       explain = TextUtils::format("%s (banned by %s)",
 				  hItr->reason.c_str(), hItr->bannedBy.c_str());
@@ -739,7 +731,7 @@ std::vector<std::pair<std::string, std::string> > AccessControlList::listMasterB
     }
   }
   idBanList_t::const_iterator iItr;
-  for (iItr = idBanList.begin(); iItr != idBanList.end(); iItr++) {
+  for (iItr = idBanList.begin(); iItr != idBanList.end(); ++iItr) {
     if (iItr->fromMaster) {
       explain = TextUtils::format("%s (banned by %s)",
 				  iItr->reason.c_str(), iItr->bannedBy.c_str());
@@ -751,31 +743,75 @@ std::vector<std::pair<std::string, std::string> > AccessControlList::listMasterB
 
   return bans;
 }
+#endif
 
-
-bool AccessControlList::convert(char *ip, in_addr &mask) {
+bool AccessControlList::convert(std::string ip, in_addr &mask, unsigned char &_cidr) {
+  std::vector<std::string> ipParts;
   unsigned char b[4];
-  char *pPeriod;
+  unsigned char cidr = 32;
 
-  for (int i = 0; i < 3; i++) {
-    pPeriod = strchr(ip, '.');
-    if (pPeriod) {
-      *pPeriod = 0;
-      if (strcmp("*", ip) == 0)
-	b[i] = 255;
-      else
-	b[i] = atoi(ip);
-      *pPeriod = '.';
-      ip = pPeriod + 1;
-    } else {
+  // Check if we have a CIDR and pull it off if so
+  if (ip.find("/") != std::string::npos) {
+    // CIDR bans can't also contain wildcards
+    if (ip.find("*") != std::string::npos)
       return false;
+
+    // Split it into the IP and CIDR parts
+    std::vector<std::string> ipcidrParts = TextUtils::tokenize(ip, "/");
+
+    // If we do not have exactly two parts, bail
+    if (ipcidrParts.size() != 2)
+      return false;
+
+    // Split the IP octets
+    ipParts = TextUtils::tokenize(ipcidrParts[0], ".");
+
+    // If we do not have exactly four parts, bail
+    if (ipParts.size() != 4)
+      return false;
+
+    // Convert the CIDR string to a numeric value
+    const int val = atoi(ipcidrParts[1].c_str());
+    if (0 < val && val <= 32)
+      cidr = (unsigned char)val;
+    else
+      return false;
+  }
+  else {
+    // Split the IP octets
+    ipParts = TextUtils::tokenize(ip, ".");
+
+    // If we do not have exactly four parts, bail
+    if (ipParts.size() != 4)
+      return false;
+
+    // Check for wildcards
+    if (ipParts[3] == "*") {
+      cidr = 24;
+      ipParts[3] = "0";
+      if (ipParts[2] == "*") {
+	cidr = 16;
+	ipParts[2] = "0";
+	if (ipParts[1] == "*") {
+	  cidr = 8;
+	  ipParts[1] = "0";
+	  // Don't allow *.*.*.*
+	  if (ipParts[0] == "*")
+	    return false;
+	}
+      }
     }
   }
-  if (strcmp("*", ip) == 0)
-    b[3] = 255;
-  else
-    b[3] = atoi(ip);
 
+  for (int i = 0; i <= 3; i++) {
+    const int val = atoi(ipParts[i].c_str());
+    if (0 <= val && val < 256)
+      b[i] = (unsigned char)val;
+    else
+      return false;
+  }
+
+  _cidr = cidr;
   mask.s_addr= htonl(((unsigned int)b[0] << 24) |
 		     ((unsigned int)b[1] << 16) |
 		     ((unsigned int)b[2] << 8)  |
