@@ -1,9 +1,9 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
- * named LICENSE that should have accompanied this file.
+ * named COPYING that should have accompanied this file.
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
@@ -56,11 +56,12 @@ typedef std::map<FlagType*,bool> FlagOptionMap;
 struct CmdLineOptions
 {
   CmdLineOptions()
-  : wksPort(ServerPort), gameStyle(PlainGameStyle),
+  : wksPort(ServerPort), gameType(TeamFFA), gameOptions(0),
     rabbitSelection(ScoreRabbitSelection), msgTimer(0), spamWarnMax(5),
     servermsg(""), advertisemsg(""), worldFile(""),
     pingInterface(""), password(""),
-    listServerOverridden(false), publicizedTitle(""), publicizedAddress(""),
+    listServerOverridden(false),
+    publicizedTitle(""), publicizedAddress(""), publicizedKey(""),
     advertiseGroups("EVERYONE"),
     suppressMasterBanList(false), masterBanListOverridden(false),
     maxShots(1), maxTeamScore(0), maxPlayerScore(0),
@@ -68,14 +69,15 @@ struct CmdLineOptions
     numAllowedFlags(0), shakeWins(0), shakeTimeout(0),
     teamFlagTimeout(30), maxlagwarn(10000), maxjitterwarn(10000), maxpacketlosswarn(10000),
     adminlagannounce(-1.0), lagannounce(-1.0), lagwarnthresh(-1.0), jitterwarnthresh(-1.0),
+    packetlosswarnthresh(-1.0),
     idlekickthresh(-1.0), timeLimit(0.0f), timeElapsed(0.0f), addedTime(0.0f),
     linearAcceleration(_DEFAULT_LIN_ACCEL), angularAcceleration(_DEFAULT_ANGLE_ACCELL), useGivenPort(false),
-    useFallbackPort(false), requireUDP(false), randomBoxes(false),
+    useFallbackPort(false), UPnP(false), randomBoxes(false),
     randomCTF(false), flagsOnBuildings(false), respawnOnBuildings(false),
     oneGameOnly(false), timeManualStart(false), randomHeights(false),
     useTeleporters(false), teamKillerDies(true), printScore(false),
     publicizeServer(false), replayServer(false), startRecording(false),
-    timestampLog(false), timestampMicros(false),
+    timestampLog(false), timestampMicros(false), timestampUTC(false), countdownPaused(false),
     filterFilename(""), filterCallsigns(false), filterChat(false), filterSimple(false),
     banTime(300), voteTime(60), vetoTime(2), votesRequired(2),
     votePercentage(50.1f), voteRepeatTime(300),
@@ -99,7 +101,8 @@ struct CmdLineOptions
   }
 
   int			wksPort;
-  int			gameStyle;
+  GameType			gameType;
+  int			gameOptions;
   int			rabbitSelection;
   int			msgTimer;
   int			spamWarnMax;
@@ -115,6 +118,7 @@ struct CmdLineOptions
 
   std::string	publicizedTitle;
   std::string	publicizedAddress;
+  std::string	publicizedKey;
   std::string	advertiseGroups;
 
   bool			suppressMasterBanList;
@@ -133,6 +137,7 @@ struct CmdLineOptions
   int			maxlagwarn;
   int			maxjitterwarn;
   int			maxpacketlosswarn;
+	int			countdownStarter;
 
   float			adminlagannounce;
   float			lagannounce;
@@ -148,7 +153,7 @@ struct CmdLineOptions
 
   bool			useGivenPort;
   bool			useFallbackPort;
-  bool			requireUDP;
+  bool			UPnP;
   bool			randomBoxes;
   bool			randomCTF;
   bool			flagsOnBuildings;
@@ -164,6 +169,7 @@ struct CmdLineOptions
   bool			startRecording;
   bool			timestampLog;
   bool			timestampMicros;
+  bool			timestampUTC;
   bool			countdownPaused;
 
   uint16_t		maxTeam[NumTeams];
