@@ -1,13 +1,13 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
- * named LICENSE that should have accompanied this file.
+ * named COPYING that should have accompanied this file.
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef __PACKVARS_H__
@@ -20,12 +20,6 @@
 #include "Pack.h"
 #include "StateDatabase.h"
 
-/* FIXME - external dependancies that need to be cleaned up and separated out
- * into an interface.
- */
-extern void directMessage(int playerIndex, uint16_t code, int len, const void *msg);
-
-
 /** class to send a bunch of BZDB variables via MsgSetVar.
  * dtor does the actual send
  */
