@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
-
 /* interface header */
 #include "Permissions.h"
 
@@ -34,7 +30,6 @@
 
 PlayerAccessMap	groupAccess;
 PlayerAccessMap	userDatabase;
-PasswordMap	passwordDatabase;
 
 uint8_t GetPlayerProperties(bool registered, bool verified, bool admin) {
   uint8_t result = 0;
@@ -47,8 +42,6 @@ uint8_t GetPlayerProperties(bool registered, bool verified, bool admin) {
   return result;
 }
 
-void setUserPassword(const std::string &nick, const std::string &pass);
-
 PlayerAccessInfo::PlayerAccessInfo()
   : verified(false), loginTime(TimeKeeper::getCurrent()), loginAttempts (0),
     serverop(false), passwordAttempts(0)
@@ -62,17 +55,6 @@ void PlayerAccessInfo::setName(const char* callSign) {
   makeupper(regName);
 }
 
-bool PlayerAccessInfo::gotAccessFailure() {
-  bool accessFailure = loginAttempts >= 5;
-  if (accessFailure)
-    logDebugMessage(1,"Too Many Identifys %s\n", getName().c_str());
-  return accessFailure;
-}
-
-void PlayerAccessInfo::setLoginFail() {
-  loginAttempts++;
-}
-
 void PlayerAccessInfo::setPermissionRights() {
   verified = true;
   // get their real info
@@ -110,6 +92,8 @@ bool PlayerAccessInfo::isAdmin() const {
 bool PlayerAccessInfo::showAsAdmin() const {
   if (hasPerm(hideAdmin))
     return false;
+  else if (hasPerm(showAdmin))
+    return true;
   else
     return isAdmin();
 }
@@ -127,54 +111,25 @@ std::string PlayerAccessInfo::getName() {
   return regName;
 }
 
-bool PlayerAccessInfo::hasRealPassword() {
-  return checkPasswordExistence(regName.c_str());
-}
-
-bool PlayerAccessInfo::isPasswordMatching(const char* pwd) {
-  return verifyUserPassword(regName.c_str(), pwd);
-}
-
 bool PlayerAccessInfo::isRegistered() const {
   return userExists(regName);
 }
 
-bool PlayerAccessInfo::isIdentifyRequired() {
-  return getUserInfo(regName).hasPerm(requireIdentify);
-}
-
 bool PlayerAccessInfo::isAllowedToEnter() {
-  return verified || !isRegistered() || !isIdentifyRequired();
+  return verified || !isRegistered();
 }
 
 bool PlayerAccessInfo::isVerified() const{
   return verified;
 }
 
-void PlayerAccessInfo::storeInfo(const char* pwd) {
+void PlayerAccessInfo::storeInfo() {
   PlayerAccessInfo _info;
   _info.addGroup("VERIFIED");
-
-  if (pwd == NULL) {
-    // automatically give global users permission to use local accounts
-    // since they either already have it, or there's no existing local account.
-    _info.addGroup("LOCAL.GLOBAL");
-    setUserPassword(regName.c_str(), "");
-    logDebugMessage(1,"Global Temp Register %s\n", regName.c_str());
-  } else {
-    std::string pass = pwd;
-    setUserPassword(regName.c_str(), pass.c_str());
-    logDebugMessage(1,"Register %s %s\n", regName.c_str(), pwd);
-  }
   userDatabase[regName] = _info;
   updateDatabases();
 }
 
-void PlayerAccessInfo::setPasswd(const std::string&  pwd) {
-  setUserPassword(regName.c_str(), pwd.c_str());
-  updateDatabases();
-}
-
 uint8_t PlayerAccessInfo::getPlayerProperties() {
   return GetPlayerProperties(isRegistered(), verified, showAsAdmin());
 }
@@ -244,7 +199,7 @@ bool PlayerAccessInfo::hasPerm(PlayerAccessInfo::AccessPerm right) const
 	isAllowed = true;
     }
   }
-  if (publiclyDisconected)
+  if (publiclyDisconnected)
   {
 	  PlayerAccessMap::iterator group = groupAccess.find(std::string("DISCONNECTED"));
 		if (group != groupAccess.end())
@@ -258,7 +213,7 @@ bool PlayerAccessInfo::hasPerm(PlayerAccessInfo::AccessPerm right) const
   return isAllowed || hasALLPerm;
 }
 
-// grant and revoke perms used with /mute and /unmute
+// grant and revoke perms
 void PlayerAccessInfo::grantPerm(PlayerAccessInfo::AccessPerm right)
 {
   explicitAllows.set(right);
@@ -272,14 +227,14 @@ void PlayerAccessInfo::revokePerm(PlayerAccessInfo::AccessPerm right)
 }
 
 
-// custom perms are ONLY on groups
-bool	PlayerAccessInfo::hasCustomPerm(const char* right) const
+bool PlayerAccessInfo::hasCustomPerm(const char* right) const
 {
 	if (serverop || hasALLPerm)
 		return true;
 
 	std::string perm = TextUtils::toupper(std::string(right));
 
+	// check for custom permissions in groups
 	for (std::vector<std::string>::const_iterator itr=groups.begin(); itr!=groups.end(); ++itr)
 	{
 		PlayerAccessMap::iterator group = groupAccess.find(*itr);
@@ -293,7 +248,7 @@ bool	PlayerAccessInfo::hasCustomPerm(const char* right) const
 		}
 	}
 
-	if (publiclyDisconected)
+	if (publiclyDisconnected)
 	{
 		PlayerAccessMap::iterator group = groupAccess.find(std::string("DISCONNECTED"));
 		if (group != groupAccess.end())
@@ -305,17 +260,36 @@ bool	PlayerAccessInfo::hasCustomPerm(const char* right) const
 			}
 		}
 	}
+
+	// check for custom permissions on a per player basis (stored in the customPerms vector)
+	for (unsigned int i = 0; i < customPerms.size(); i++)
+	{
+		if (perm == TextUtils::toupper(customPerms[i]))
+			return true;
+	}
+
 	return false;
 }
 
+void PlayerAccessInfo::grantCustomPerm(const char *right)
+{
+  customPerms.push_back(right);
+}
+
+void PlayerAccessInfo::revokeCustomPerm(const char *right)
+{
+  std::vector<std::string>::iterator position = std::find(customPerms.begin(), customPerms.end(), right);
+
+  if (position != customPerms.end())
+    customPerms.erase(position);
+}
+
 bool userExists(const std::string &nick)
 {
   std::string str = nick;
   makeupper(str);
   PlayerAccessMap::iterator itr = userDatabase.find(str);
-  if (itr == userDatabase.end())
-    return false;
-  return true;
+  return itr != userDatabase.end();
 }
 
 //FIXME - check for non-existing user (throw?)
@@ -331,43 +305,6 @@ PlayerAccessInfo &PlayerAccessInfo::getUserInfo(const std::string &nick)
   return itr->second;
 }
 
-bool checkPasswordExistence(const std::string &nick)
-{
-  std::string str1 = nick;
-  makeupper(str1);
-  PasswordMap::iterator itr = passwordDatabase.find(str1);
-  if (itr == passwordDatabase.end())
-    return false;
-  if (itr->second == "*" || itr->second == "")
-    return false;
-  return true;
-}
-
-bool verifyUserPassword(const std::string &nick, const std::string &pass)
-{
-  std::string str1 = nick;
-  makeupper(str1);
-  PasswordMap::iterator itr = passwordDatabase.find(str1);
-  if (itr == passwordDatabase.end())
-    return false;
-  return itr->second == MD5(pass).hexdigest();
-}
-
-void setUserPassword(const std::string &nick, const std::string &pass)
-{
-  std::string str1 = nick;
-  makeupper(str1);
-  if (pass.size() == 0) {
-    passwordDatabase[str1] = "*";
-  } else if (pass == "*") {
-    // never encode *, this would change the person's password from NULL to *.
-    passwordDatabase[str1] = "*";
-  } else {
-    // assume it's already a hash when length is 32 (FIXME?)
-    passwordDatabase[str1] = pass.size()==32 ? pass : MD5(pass).hexdigest();
-  }
-}
-
 std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
 {
   switch (perm) {
@@ -375,7 +312,6 @@ std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
     case PlayerAccessInfo::adminMessageReceive: return "adminMessageReceive";
     case PlayerAccessInfo::adminMessageSend: return "adminMessageSend";
     case PlayerAccessInfo::antiban : return "antiban";
-    case PlayerAccessInfo::antideregister : return "antideregister";
     case PlayerAccessInfo::antikick : return "antikick";
     case PlayerAccessInfo::antikill : return "antikill";
     case PlayerAccessInfo::antipoll : return "antipoll";
@@ -384,6 +320,7 @@ std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
     case PlayerAccessInfo::antipollkill : return "antipollkill";
     case PlayerAccessInfo::ban: return "ban";
     case PlayerAccessInfo::banlist: return "banlist";
+    case PlayerAccessInfo::clientQuery: return "clientQuery";
     case PlayerAccessInfo::countdown: return "countdown";
     case PlayerAccessInfo::date: return "date";
     case PlayerAccessInfo::endGame: return "endGame";
@@ -399,11 +336,13 @@ std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
     case PlayerAccessInfo::lagwarn: return "lagwarn";
     case PlayerAccessInfo::jitterwarn: return "jitterwarn";
     case PlayerAccessInfo::listPerms: return "listPerms";
+    case PlayerAccessInfo::listPlugins: return "listPlugins";
     case PlayerAccessInfo::masterBan: return "masterban";
     case PlayerAccessInfo::modCount: return "modCount";
     case PlayerAccessInfo::mute: return "mute";
     case PlayerAccessInfo::packetlosswarn: return "packetlosswarn";
     case PlayerAccessInfo::playerList: return "playerList";
+    case PlayerAccessInfo::plugins: return "plugins";
     case PlayerAccessInfo::poll: return "poll";
     case PlayerAccessInfo::pollBan: return "pollBan";
     case PlayerAccessInfo::pollKick: return "pollKick";
@@ -415,13 +354,13 @@ std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
     case PlayerAccessInfo::rejoin: return "rejoin";
     case PlayerAccessInfo::removePerms: return "removePerms";
     case PlayerAccessInfo::replay: return "replay";
-    case PlayerAccessInfo::requireIdentify: return "requireIdentify";
+    case PlayerAccessInfo::report: return "report";
     case PlayerAccessInfo::say: return "say";
     case PlayerAccessInfo::sendHelp : return "sendHelp";
     case PlayerAccessInfo::setAll: return "setAll";
-    case PlayerAccessInfo::setPassword: return "setPassword";
     case PlayerAccessInfo::setPerms: return "setPerms";
     case PlayerAccessInfo::setVar: return "setVar";
+    case PlayerAccessInfo::showAdmin: return "showAdmin";
     case PlayerAccessInfo::showOthers: return "showOthers";
     case PlayerAccessInfo::shortBan: return "shortBan";
     case PlayerAccessInfo::shutdownServer: return "shutdownServer";
@@ -443,7 +382,6 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   if (name == "ADMINMESSAGERECEIVE") return PlayerAccessInfo::adminMessageReceive;
   if (name == "ADMINMESSAGESEND") return PlayerAccessInfo::adminMessageSend;
   if (name == "ANTIBAN") return PlayerAccessInfo::antiban;
-  if (name == "ANTIDEREGISTER") return PlayerAccessInfo::antideregister;
   if (name == "ANTIKICK") return PlayerAccessInfo::antikick;
   if (name == "ANTIKILL") return PlayerAccessInfo::antikill;
   if (name == "ANTIPOLL") return PlayerAccessInfo::antipoll;
@@ -452,6 +390,7 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   if (name == "ANTIPOLLKILL") return PlayerAccessInfo::antipollkill;
   if (name == "BAN") return PlayerAccessInfo::ban;
   if (name == "BANLIST") return PlayerAccessInfo::banlist;
+  if (name == "CLIENTQUERY") return PlayerAccessInfo::clientQuery;
   if (name == "COUNTDOWN") return PlayerAccessInfo::countdown;
   if (name == "DATE") return PlayerAccessInfo::date;
   if (name == "ENDGAME") return PlayerAccessInfo::endGame;
@@ -467,11 +406,13 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   if (name == "LAGWARN") return PlayerAccessInfo::lagwarn;
   if (name == "JITTERWARN") return PlayerAccessInfo::jitterwarn;
   if (name == "LISTPERMS") return PlayerAccessInfo::listPerms;
+  if (name == "LISTPLUGINS") return PlayerAccessInfo::listPlugins;
   if (name == "MASTERBAN") return PlayerAccessInfo::masterBan;
   if (name == "MODCOUNT") return PlayerAccessInfo::modCount;
   if (name == "MUTE") return PlayerAccessInfo::mute;
   if (name == "PACKETLOSSWARN") return PlayerAccessInfo::packetlosswarn;
   if (name == "PLAYERLIST") return PlayerAccessInfo::playerList;
+  if (name == "PLUGINS") return PlayerAccessInfo::plugins;
   if (name == "POLL") return PlayerAccessInfo::poll;
   if (name == "POLLBAN") return PlayerAccessInfo::pollBan;
   if (name == "POLLKICK") return PlayerAccessInfo::pollKick;
@@ -483,14 +424,14 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   if (name == "REJOIN") return PlayerAccessInfo::rejoin;
   if (name == "REMOVEPERMS") return PlayerAccessInfo::removePerms;
   if (name == "REPLAY") return PlayerAccessInfo::replay;
-  if (name == "REQUIREIDENTIFY") return PlayerAccessInfo::requireIdentify;
+  if (name == "REPORT") return PlayerAccessInfo::report;
   if (name == "SAY") return PlayerAccessInfo::say;
   if (name == "SENDHELP") return PlayerAccessInfo::sendHelp;
   if (name == "SETALL") return PlayerAccessInfo::setAll;
-  if (name == "SETPASSWORD") return PlayerAccessInfo::setPassword;
   if (name == "SETPERMS") return PlayerAccessInfo::setPerms;
   if (name == "SETVAR") return PlayerAccessInfo::setVar;
   if (name == "SHORTBAN") return PlayerAccessInfo::shortBan;
+  if (name == "SHOWADMIN") return PlayerAccessInfo::showAdmin;
   if (name == "SHOWOTHERS") return PlayerAccessInfo::showOthers;
   if (name == "SHUTDOWNSERVER") return PlayerAccessInfo::shutdownServer;
   if (name == "SPAWN") return PlayerAccessInfo::spawn;
@@ -504,13 +445,17 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   return PlayerAccessInfo::lastPerm;
 }
 
-void parsePermissionString(const std::string &permissionString, PlayerAccessInfo &info)
+// Parse a list of permissions &permissionString and set the corrosponding Permissions
+// in &info. Return true if a group is referenced but not defined yet, else false.
+// return value is only needed for groupdb parsing, not for userdb.
+bool parsePermissionString(const std::string &permissionString, PlayerAccessInfo &info)
 {
   if (permissionString.length() < 1)
-    return;
+    return false;
 
   std::istringstream permStream(permissionString);
   std::string word;
+  bool invokeGroupdbRecursion = false;
 
   while (permStream >> word) {
     makeupper(word);
@@ -525,7 +470,7 @@ void parsePermissionString(const std::string &permissionString, PlayerAccessInfo
     // Operators are not allowed for userdb
     if (!info.groupState.test(PlayerAccessInfo::isGroup) && first != '\0'){
       logDebugMessage(1,"userdb: illegal permission string, operators are not allowed in userdb\n");
-      return;
+      return false;
     }
 
     // if we have an operator, lets handle it
@@ -540,9 +485,8 @@ void parsePermissionString(const std::string &permissionString, PlayerAccessInfo
 	  if (refgroup != groupAccess.end()) {
 	    info.explicitAllows |= refgroup->second.explicitAllows;
 	    info.explicitDenys |= refgroup->second.explicitDenys;
-	    refgroup->second.groupState.set(PlayerAccessInfo::isReferenced);
 	  } else {
-	    logDebugMessage(1,"groupdb: unknown group \"%s\" was referenced\n", word.c_str());
+	    invokeGroupdbRecursion = true;
 	  }
 
 	  continue;
@@ -602,113 +546,83 @@ void parsePermissionString(const std::string &permissionString, PlayerAccessInfo
 	info.explicitAllows[PlayerAccessInfo::lastPerm] = false;
 	info.hasALLPerm = true;
       } else {
-	//logDebugMessage(1,"groupdb: Cannot set unknown permission %s\n", word.c_str());
-				info.customPerms.push_back(word);
+	// Easy access
+	std::vector<std::string>& c = info.customPerms;
+
+	// Only store the custom permission if it doesn't exist, in order to prevent duplicates
+	if (std::find(c.begin(), c.end(), word) == c.end()) {
+	  c.push_back(word);
+	}
       }
     }
   }
+  return invokeGroupdbRecursion;
 }
 
 
-bool readPassFile(const std::string &filename)
-{
-  std::ifstream in(filename.c_str());
-  if (!in)
-    return false;
-
-  std::string line;
-  while (std::getline(in, line)) {
-    // Should look at an unescaped ':'
-    int colonpos = TextUtils::unescape_lookup(line, '\\', ':');
-    if (colonpos == -1)
-      continue;
-    {
-      std::string name = TextUtils::unescape(line.substr(0, colonpos), '\\');
-      std::string pass = line.substr(colonpos + 1);
-      makeupper(name);
-      setUserPassword(name.c_str(), pass.c_str());
-    }
-  }
-
-  return (passwordDatabase.size() > 0);
-}
-
-bool writePassFile(const std::string &filename)
-{
-  std::ofstream out(filename.c_str());
-  if (!out)
-    return false;
-  PasswordMap::iterator itr = passwordDatabase.begin();
-  while (itr != passwordDatabase.end()) {
-    if (itr->second != "*") {
-      out << TextUtils::escape(itr->first, '\\') << ':' << itr->second << std::endl;
-    }
-    itr++;
-  }
-  out.close();
-  return true;
-}
-
 bool PlayerAccessInfo::readGroupsFile(const std::string &filename)
 {
-  std::ifstream in(filename.c_str());
+  std::ifstream in(filename);
   if (!in)
     return false;
 
-  int linenum = 0;
-  std::string line;
-  while (std::getline(in, line)) {
-    linenum++;
+  int recursionNeeded = 1;
+  bool initialRun = true;
 
-    // check for a comment string
-    bool skip = true;
-    for (std::string::size_type pos = 0; pos < line.size(); pos++) {
-      const char c = line[pos];
-      if (!TextUtils::isWhitespace(c)) {
-	if (c != '#') {
-	  skip = false;
-	}
-	break;
-      }
-    }
-    if (skip) continue;
+   // read groupdb and check for unsolved group references, read the file again
+  // for each of them. One more recursion should make sure everything is fine.
+  do {
+    in.clear();
+    in.seekg(0, std::ios::beg);
+    int linenum = 0;
 
-    makeupper(line);
+    std::string line;
+    while (std::getline(in, line)) {
+      linenum++;
 
-    std::string::size_type colonpos = line.find(':');
-    if (colonpos != std::string::npos) {
-      std::string name = line.substr(0, colonpos);
-      std::string perm = line.substr(colonpos + 1);
+      // strip leading whitespace
+      line.erase(0 , line.find_first_not_of(" \t"));
 
-      // check if we already have this group, else make a new
-      PlayerAccessInfo info;
-      PlayerAccessMap::iterator oldgroup = groupAccess.find(name);
-      if (oldgroup != groupAccess.end())
-	info = oldgroup->second;
-      else
-	info.groupState[PlayerAccessInfo::isGroup] = true;
-
-      // don't allow changing permissions for a group
-      // that was used as a reference before
-      if (info.groupState.test(isReferenced)) {
-	logDebugMessage(1,"groupdb: skipping groupdb line (%i), group was used as reference before\n", linenum);
+      // check for a comment string or empty line
+      if(line.empty() || line[0] == '#')
 	continue;
-      }
-      parsePermissionString(perm, info);
-      info.verified = true;
-      groupAccess[name] = info;
-    } else {
-      logDebugMessage(1,"WARNING: bad groupdb line (%i)\n", linenum);
-    }
 
-  }
+      makeupper(line);
+
+      std::string::size_type colonpos = line.find(':');
+      if (colonpos == std::string::npos)
+	logDebugMessage(1,"WARNING: bad groupdb line (%i)\n", linenum);
+      else {
+	std::string name = line.substr(0, colonpos);
+	std::string perm = line.substr(colonpos + 1);
+
+	// check if we already have this group, else make a new
+	PlayerAccessInfo accessInfo;
+	PlayerAccessMap::iterator oldgroup = groupAccess.find(name);
+	if (oldgroup != groupAccess.end())
+	  accessInfo = oldgroup->second;
+	else
+	  accessInfo.groupState[PlayerAccessInfo::isGroup] = true;
+
+	// Parse the permission string. If it contains a yet undefined group
+	// add a recursion
+	if(parsePermissionString(perm, accessInfo) && initialRun){
+	  recursionNeeded++;
+	}
+
+	accessInfo.verified = true;
+	groupAccess[name] = accessInfo;
+      }
+    }
+    initialRun = false;
+  } while(recursionNeeded--);
 
   return true;
 }
 
 bool PlayerAccessInfo::readPermsFile(const std::string &filename)
 {
-  std::ifstream in(filename.c_str());
+  std::ifstream in(filename);
   if (!in)
     return false;
 
@@ -718,7 +632,7 @@ bool PlayerAccessInfo::readPermsFile(const std::string &filename)
     if (!std::getline(in, name))
       break;
 
-    PlayerAccessInfo info;
+    PlayerAccessInfo accessInfo;
 
     // 2nd line - groups
     std::string groupline;
@@ -726,22 +640,22 @@ bool PlayerAccessInfo::readPermsFile(const std::string &filename)
     std::istringstream groupstream(groupline);
     std::string group;
     while (groupstream >> group) {
-      info.addGroup(group);
+      accessInfo.addGroup(group);
     }
 
     // 3rd line - allows
     std::string perms;
     std::getline(in, perms);
-    parsePermissionString(perms, info);
+    parsePermissionString(perms, accessInfo);
 
     // 4th line - denies
     // FIXME: not nice ... any ideas how to make it better?
     std::getline(in, perms);
     PlayerAccessInfo dummy;
     parsePermissionString(perms, dummy);
-    info.explicitDenys = dummy.explicitAllows;
+    accessInfo.explicitDenys = dummy.explicitAllows;
 
-    userDatabase[name] = info;
+    userDatabase[name] = accessInfo;
   }
 
   return true;
@@ -750,7 +664,7 @@ bool PlayerAccessInfo::readPermsFile(const std::string &filename)
 bool PlayerAccessInfo::writePermsFile(const std::string &filename)
 {
   int i;
-  std::ofstream out(filename.c_str());
+  std::ofstream out(filename);
   if (!out)
     return false;
   PlayerAccessMap::iterator itr = userDatabase.begin();
@@ -760,7 +674,7 @@ bool PlayerAccessInfo::writePermsFile(const std::string &filename)
     group = itr->second.groups.begin();
     while (group != itr->second.groups.end()) {
       out << (*group) << ' ';
-      group++;
+      ++group;
     }
     out << std::endl;
     // allows
@@ -773,20 +687,17 @@ bool PlayerAccessInfo::writePermsFile(const std::string &filename)
       if (itr->second.explicitDenys.test(i))
 	out << nameFromPerm((PlayerAccessInfo::AccessPerm) i);
     out << std::endl;
-    itr++;
+    ++itr;
   }
   out.close();
   return true;
 }
 
 std::string		groupsFile;
-std::string		passFile;
 std::string		userDatabaseFile;
 
 void PlayerAccessInfo::updateDatabases()
 {
-  if (passFile.size())
-    writePassFile(passFile);
   if (userDatabaseFile.size())
     writePermsFile(userDatabaseFile);
 }
