@@ -1,9 +1,9 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
- * named LICENSE that should have accompanied this file.
+ * named COPYING that should have accompanied this file.
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
@@ -17,12 +17,6 @@
 //   for name matching (so that messages aren't sent to ghosts)
 // - improve skipping
 
-
-// OOPS, get rid of these during the next protocol change
-static const int PACKET_SIZE_STUFFING = 8;
-static const int HEADER_SIZE_STUFFING = 0;
-
-
 // interface header
 #include "RecordReplay.h"
 
@@ -37,10 +31,8 @@ static const int HEADER_SIZE_STUFFING = 0;
 #ifndef _WIN32
 #  include <sys/time.h>
 #  include <unistd.h>
-typedef int64_t s64;
 #else
 #  include <direct.h>
-typedef __int64 s64;
 #  ifndef S_ISDIR
 #    define S_ISDIR(m) ((m) & _S_IFDIR)
 #  endif
@@ -50,7 +42,6 @@ typedef __int64 s64;
 #endif
 
 // common headers
-#include "global.h"
 #include "bzglob.h"
 #include "Pack.h"
 #include "GameTime.h"
@@ -68,32 +59,6 @@ typedef __int64 s64;
 // Type Definitions
 // ----------------
 
-typedef uint16_t u16;
-typedef uint32_t u32;
-typedef s64 RRtime; // should last a while
-
-enum RecordType {
-  StraightToFile  = 0,
-  BufferedRecord = 1
-};
-
-typedef struct RRpacket {
-  struct RRpacket *next;
-  struct RRpacket *prev;
-  u16 mode;
-  u16 code;
-  u32 len;
-  u32 nextFilePos;
-  u32 prevFilePos;
-  RRtime timestamp;
-  char *data;
-} RRpacket;
-//static const unsigned int RRpacketHdrSize =
-//  sizeof(RRpacket) - (2 * sizeof(RRpacket*) - sizeof(char*));
-static const unsigned int RRpacketHdrSize =
-  PACKET_SIZE_STUFFING +
-  (2 * sizeof(u16)) + (3 * sizeof(u32)) + sizeof(RRtime);
-
 typedef struct {
   u32 byteCount;
   u32 packetCount;
@@ -102,30 +67,6 @@ typedef struct {
   RRpacket *tail; // first packet in
 } RRbuffer;
 
-typedef struct {
-  u32 magic;		    // record file type identifier
-  u32 version;		  // record file version
-  u32 offset;		   // length of the full header
-  RRtime filetime;	      // amount of time in the file
-  u32 player;		   // player that saved this record file
-  u32 flagsSize;		// size of the flags data
-  u32 worldSize;		// size of world database
-  char callSign[CallSignLen];   // player's callsign
-  char email[EmailLen];	 // player's email
-  char serverVersion[8];	// BZFS protocol version
-  char appVersion[MessageLen];  // BZFS application version
-  char realHash[64];	    // hash of worldDatabase
-  char worldSettings[4 + WorldSettingsSize]; // the game settings
-  char *flags;		  // a list of the flags types
-  char *world;		  // the world
-} ReplayHeader;
-//static const unsigned int ReplayHeaderSize =
-//  sizeof(ReplayHeader) - (2 * sizeof(char*));
-static const unsigned int ReplayHeaderSize =
-  HEADER_SIZE_STUFFING +
-  (sizeof(u32) * 6) + sizeof(RRtime) +
-  CallSignLen + EmailLen + 8 + MessageLen + 64 + 4 + WorldSettingsSize;
-
 typedef struct {
   std::string file;
   float time;
@@ -191,7 +132,7 @@ static bool saveVariablesState();
 static bool saveGameTimeState();
 static bool resetStates();
 
-static bool setVariables(void *data);
+static bool setVariables(const void *data);
 static bool preloadVariables();
 
 static void rewind();
@@ -237,7 +178,7 @@ static void initPacket(u16 mode, u16 code, int len, const void *data,
 
 static RRtime getRRtime();
 static void *nboPackRRtime(void *buf, RRtime value);
-static void *nboUnpackRRtime(void *buf, RRtime& value);
+static const void *nboUnpackRRtime(const void *buf, RRtime& value);
 
 static bool checkReplayMode(int playerIndex);
 
@@ -841,9 +782,9 @@ bool Replay::loadFile(int playerIndex, const char *filename)
   snprintf(buffer, MessageLen, "Loaded file:  %s", name.c_str());
   sendMessage(ServerPlayer, playerIndex, buffer);
   snprintf(buffer, MessageLen, "  author:     %s (%s)",
-	    header.callSign, header.email);
+	    header.callSign, header.motto);
   sendMessage(ServerPlayer, playerIndex, buffer);
-  snprintf(buffer, MessageLen, "  protocol:   %.8s", header.serverVersion);
+  snprintf(buffer, MessageLen, "  protocol:   %.8s", header.ServerVersion);
   sendMessage(ServerPlayer, playerIndex, buffer);
   snprintf(buffer, MessageLen, "  server:     %s", header.appVersion);
   sendMessage(ServerPlayer, playerIndex, buffer);
@@ -1246,8 +1187,6 @@ bool Replay::sendPackets()
   }
 
   while ((p != NULL) && (Replay::nextTime() < 0.0f)) {
-    int i;
-
     if (p == NULL) {
       // this is a safety, it shouldn't happen
       resetStates();
@@ -1261,6 +1200,8 @@ bool Replay::sendPackets()
 	    (int)p->mode, p->len, msgString(p->code), p->data);
 
     if (p->mode != HiddenPacket) {
+      int i;
+
       // set the database variables if this is MsgSetVar
       if (p->code == MsgSetVar) {
 	setVariables(p->data);
@@ -1392,7 +1333,7 @@ static void rewind()
 }
 
 
-static bool setVariables(void *data)
+static bool setVariables(const void *data)
 {
   // copied this function from [playing.cxx]
 
@@ -1622,7 +1563,7 @@ static bool saveFlagsState()
 
 static bool saveRabbitState()
 {
-  if (clOptions->gameStyle & int(RabbitChaseGameStyle)) {
+  if (clOptions->gameType == RabbitChase) {
     char bufStart[MaxPacketLen];
     void *buf;
     buf = nboPackUByte(bufStart, rabbitIndex);
@@ -1866,7 +1807,7 @@ static RRpacket *loadPacket(FILE *f)
 {
   RRpacket *p;
   char bufStart[RRpacketHdrSize];
-  void *buf;
+  const void *buf;
 
   if (f == NULL) {
     return NULL;
@@ -1896,12 +1837,13 @@ static RRpacket *loadPacket(FILE *f)
     p->data = NULL;
   }
   else {
-    p->data = new char [p->len];
-    if (fread(p->data, p->len, 1, f) != 1) {
-      delete[] p->data;
+    char *d = new char [p->len];
+    if (fread(d, p->len, 1, f) != 1) {
+      delete[] d;
       delete p;
       return NULL;
     }
+    p->data = d;
   }
 
   logDebugMessage(4,"loadRRpacket(): mode = %i, len = %4i, code = %s, data = %p\n",
@@ -2021,9 +1963,9 @@ static bool saveHeader(int p, RRtime filetime, FILE *f)
     return false;
   }
 
-  // player callsign and email
+  // player callsign and motto
   const char* callsign = "SERVER";
-  const char* email = "";
+  const char* motto = "";
   if (p != ServerPlayer) {
     GameKeeper::Player *gkPlayer = GameKeeper::Player::getPlayerByIndex(p);
     if (gkPlayer == NULL) {
@@ -2031,17 +1973,17 @@ static bool saveHeader(int p, RRtime filetime, FILE *f)
     } else {
       PlayerInfo *pi = &gkPlayer->player;
       callsign = pi->getCallSign();
-      email = pi->getEMail();
+      motto = pi->getMotto();
     }
   }
 
   // setup the data
   memset(&hdr, 0, sizeof(hdr));
   strncpy(hdr.callSign, callsign, sizeof(hdr.callSign));
-  strncpy(hdr.email, email, sizeof(hdr.email));
-  strncpy(hdr.serverVersion, getServerVersion(), sizeof(hdr.serverVersion));
+  strncpy(hdr.motto, motto, sizeof(hdr.motto));
+  strncpy(hdr.ServerVersion, getServerVersion(), sizeof(hdr.ServerVersion));
   strncpy(hdr.appVersion, getAppVersion(), sizeof(hdr.appVersion));
-  strncpy(hdr.realHash, hexDigest, sizeof(hdr.realHash));
+  strncpy(hdr.realHash, hexDigest.c_str(), sizeof(hdr.realHash));
   packFlagTypes(flagsBuf, &hdr.flagsSize);
   hdr.flags = flagsBuf;
 
@@ -2056,8 +1998,8 @@ static bool saveHeader(int p, RRtime filetime, FILE *f)
   buf = nboPackUInt(buf, hdr.flagsSize);
   buf = nboPackUInt(buf, worldDatabaseSize);
   buf = nboPackString(buf, hdr.callSign, sizeof(hdr.callSign));
-  buf = nboPackString(buf, hdr.email, sizeof(hdr.email));
-  buf = nboPackString(buf, hdr.serverVersion, sizeof(hdr.serverVersion));
+  buf = nboPackString(buf, hdr.motto, sizeof(hdr.motto));
+  buf = nboPackString(buf, hdr.ServerVersion, sizeof(hdr.ServerVersion));
   buf = nboPackString(buf, hdr.appVersion, sizeof(hdr.appVersion));
   buf = nboPackString(buf, hdr.realHash, sizeof(hdr.realHash));
   buf = nboPackString(buf, worldSettings, sizeof(worldSettings));
@@ -2084,7 +2026,7 @@ static bool saveHeader(int p, RRtime filetime, FILE *f)
 static bool loadHeader(ReplayHeader *h, FILE *f)
 {
   char buffer[ReplayHeaderSize];
-  void *buf;
+  const void *buf;
 
   if (fread(buffer, ReplayHeaderSize, 1, f) != 1) {
     return false;
@@ -2098,8 +2040,8 @@ static bool loadHeader(ReplayHeader *h, FILE *f)
   buf = nboUnpackUInt(buf, h->flagsSize);
   buf = nboUnpackUInt(buf, h->worldSize);
   buf = nboUnpackString(buf, h->callSign, sizeof(h->callSign));
-  buf = nboUnpackString(buf, h->email, sizeof(h->email));
-  buf = nboUnpackString(buf, h->serverVersion, sizeof(h->serverVersion));
+  buf = nboUnpackString(buf, h->motto, sizeof(h->motto));
+  buf = nboUnpackString(buf, h->ServerVersion, sizeof(h->ServerVersion));
   buf = nboUnpackString(buf, h->appVersion, sizeof(h->appVersion));
   buf = nboUnpackString(buf, h->realHash, sizeof(h->realHash));
   buf = nboUnpackString(buf, h->worldSettings, sizeof(h->worldSettings));
@@ -2233,7 +2175,7 @@ static bool loadFileTime(RRtime *filetime, FILE *f)
 static bool replaceFlagTypes(ReplayHeader *h)
 {
   bool replace = false;
-  void *buf = h->flags;
+  const void *buf = h->flags;
   FlagOptionMap headerFlag;
   FlagTypeMap::iterator it;
 
@@ -2289,7 +2231,8 @@ static bool replaceSettings(ReplayHeader *h)
     sizeof(uint16_t) + // packet len
     sizeof(uint16_t) + // packet code
     sizeof(float)    + // world size
-    sizeof(uint16_t);  // gamestyle
+    sizeof(uint16_t) + // gamestyle
+    sizeof(uint16_t);  // gameoptions
   char *hdrMaxPlayersPtr = h->worldSettings + maxPlayersOffset;
   nboPackUShort(hdrMaxPlayersPtr, MaxPlayers + ReplayObservers);
 
@@ -2321,9 +2264,8 @@ static bool replaceWorldDatabase(ReplayHeader *h)
     MD5 md5;
     md5.update((unsigned char *)worldDatabase, worldDatabaseSize);
     md5.finalize();
-    std::string hash = md5.hexdigest();
-    hexDigest[0] = h->realHash[0];
-    strncpy(hexDigest + 1, hash.c_str(), sizeof(hexDigest) - 1);
+    hexDigest = h->realHash[0];
+    hexDigest += md5.hexdigest();
 
     delete[] oldWorld;
     return true;   // the world was replaced
@@ -2377,7 +2319,7 @@ static void initPacket(u16 mode, u16 code, int len, const void *data, RRpacket *
   p->mode = mode;
   p->code = code;
   p->len = len;
-  p->data = (char*) data; // dirty little trick
+  p->data = (const char *)data;
 }
 
 
@@ -2388,10 +2330,11 @@ static RRpacket *newPacket(u16 mode, u16 code, int len, const void *data)
   p->next = NULL;
   p->prev = NULL;
 
-  p->data = new char [len];
-  if (data != NULL) {
-    memcpy(p->data, data, len);
+  char *d = new char [len];
+  if (d != NULL) {
+    memcpy(d, data, len);
   }
+  p->data = d;
   initPacket(mode, code, len, p->data, p);
 
   return p;
@@ -2551,7 +2494,7 @@ static void *nboPackRRtime(void *buf, RRtime value)
 }
 
 
-static void *nboUnpackRRtime(void *buf, RRtime& value)
+static const void *nboUnpackRRtime(const void *buf, RRtime& value)
 {
   u32 msb, lsb;
   buf = nboUnpackUInt(buf, msb);
@@ -2612,7 +2555,6 @@ static const char *msgString(u16 code)
 
       STRING_CASE (MsgUDPLinkRequest);
       STRING_CASE (MsgUDPLinkEstablished);
-      STRING_CASE (MsgServerControl);
       STRING_CASE (MsgLagPing);
 
     default:
