@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786 )
-#endif
-
 // class-interface header
 #include "WorldWeapons.h"
 
@@ -31,13 +27,10 @@
 
 // bzfs specific headers
 #include "bzfs.h"
-
-char *getDirectMessageBuffer();
-void broadcastMessage(uint16_t code, int len, const void *msg);
-
+#include "ShotManager.h"
 
 static int fireWorldWepReal(FlagType* type, float lifetime, PlayerId player,
-			    TeamColor teamColor, float *pos, float tilt, float dir,
+			    TeamColor teamColor, float *pos, float tilt, float dir, float shotSpeed,
 			    int shotID, float dt)
 {
   void *buf, *bufStart = getDirectMessageBuffer();
@@ -48,7 +41,8 @@ static int fireWorldWepReal(FlagType* type, float lifetime, PlayerId player,
   firingInfo.lifetime = lifetime;
   firingInfo.shot.player = player;
   memmove(firingInfo.shot.pos, pos, 3 * sizeof(float));
-  const float shotSpeed = BZDB.eval(StateDatabase::BZDB_SHOTSPEED);
+  if (shotSpeed < 0)
+	  shotSpeed = BZDB.eval(StateDatabase::BZDB_SHOTSPEED);
   const float tiltFactor = cosf(tilt);
   firingInfo.shot.vel[0] = shotSpeed * tiltFactor * cosf(dir);
   firingInfo.shot.vel[1] = shotSpeed * tiltFactor * sinf(dir);
@@ -63,13 +57,16 @@ static int fireWorldWepReal(FlagType* type, float lifetime, PlayerId player,
   if (BZDB.isTrue(StateDatabase::BZDB_WEAPONS)) {
     broadcastMessage(MsgShotBegin, (char *)buf - (char *)bufStart, bufStart);
   }
+
+
+  ShotManager.AddShot(firingInfo,player);
   return shotID;
 }
 
 
 static int fireWorldGMReal ( FlagType* type, PlayerId targetPlayerID, float
     lifetime, PlayerId player, float *pos, float tilt, float dir, int shotID,
-    float dt)
+    float dt, TeamColor shotTeam = RogueTeam)
 {
 
   void *buf, *bufStart = getDirectMessageBuffer();
@@ -88,7 +85,7 @@ static int fireWorldGMReal ( FlagType* type, PlayerId targetPlayerID, float
   firingInfo.shot.id = shotID;
   firingInfo.shot.dt = dt;
 
-  firingInfo.shot.team = RogueTeam;
+  firingInfo.shot.team = shotTeam;
 
   buf = firingInfo.pack(bufStart);
 
@@ -97,6 +94,9 @@ static int fireWorldGMReal ( FlagType* type, PlayerId targetPlayerID, float
 		     bufStart);
   }
 
+  uint32_t shotGUID = ShotManager.AddShot(firingInfo,player);
+  ShotManager.SetShotTarget(shotGUID,targetPlayerID);
+
     // Target the gm.
     // construct and send packet
 
@@ -156,9 +156,10 @@ void WorldWeapons::fire()
        it != weapons.end(); ++it) {
     Weapon *w = *it;
     if (w->nextTime <= nowTime) {
+      FlagType type = *(w->type);	// non-const copy
 
-      fireWorldWepReal((FlagType*)w->type, BZDB.eval(StateDatabase::BZDB_RELOADTIME),
-		       ServerPlayer, w->teamColor, w->origin, w->tilt, w->direction,
+      fireWorldWepReal(&type, BZDB.eval(StateDatabase::BZDB_RELOADTIME),
+		       ServerPlayer, w->teamColor, w->origin, w->tilt, w->direction, -1,
 		       getNewWorldShotID(), 0);
 
       //Set up timer for next shot, and eat any shots that have been missed
@@ -250,7 +251,32 @@ int WorldWeapons::getNewWorldShotID(void)
   return worldShotId++;
 }
 
+bool shotUsedInList(int shotID, Shots::ShotList& list)
+{
+	for(size_t s = 0; s < list.size(); s++)
+	{
+		if (list[s]->GetLocalShotID() == shotID)
+			return true;
+	}
+	return false;
+}
 
+int WorldWeapons::getNewWorldShotID(PlayerId player)
+{
+	int maxID = _MAX_WORLD_SHOTS;
+	if (player != ServerPlayer)
+		maxID = clOptions->maxShots;
+
+	Shots::ShotList liveShots = ShotManager.LiveShotsForPlayer(player);
+	Shots::ShotList deadShots = ShotManager.DeadShotsForPlayer(player);
+
+	for (int i = 0; i < maxID; i++)
+	{
+		if (!shotUsedInList(i,liveShots) && !shotUsedInList(i,deadShots))
+			return i;
+	}
+	return -1;
+}
 //----------WorldWeaponGlobalEventHandler---------------------
 // where we do the world weapon handling for event based shots since they are not really done by the "world"
 
@@ -280,33 +306,33 @@ void WorldWeaponGlobalEventHandler::process (bz_EventData *eventData)
   if (!eventData || eventData->eventType != bz_eCaptureEvent)
     return;
 
-  bz_CTFCaptureEventData *capEvent = (bz_CTFCaptureEventData*)eventData;
+  bz_CTFCaptureEventData_V1 *capEvent = (bz_CTFCaptureEventData_V1*)eventData;
 
   if ( capEvent->teamCapped != team )
 	  return;
 
   fireWorldWepReal(type, BZDB.eval(StateDatabase::BZDB_RELOADTIME),
-		   ServerPlayer, RogueTeam, origin, tilt, direction,
+		   ServerPlayer, RogueTeam, origin, tilt, direction, -1,
 		   world->getWorldWeapons().getNewWorldShotID(),0);
 }
 
 
 // for bzfsAPI: it needs to be global
 int fireWorldWep(FlagType* type, float lifetime, PlayerId player,
-			float *pos, float tilt, float direction,
-			int shotID, float dt)
+			float *pos, float tilt, float direction, float speed,
+			int shotID, float dt, TeamColor shotTeam)
 {
-  return fireWorldWepReal(type, lifetime, player, RogueTeam,
-			  pos, tilt, direction, shotID, dt);
+  return fireWorldWepReal(type, lifetime, player, shotTeam,
+			  pos, tilt, direction, speed, shotID, dt);
 }
 
 
 int fireWorldGM(FlagType* type, PlayerId targetPlayerID, float lifetime,
 		PlayerId player, float *pos, float tilt, float direction,
-		int shotID, float dt)
+		int shotID, float dt, TeamColor shotTeam)
 {
   return fireWorldGMReal(type, targetPlayerID, lifetime, player, pos, tilt,
-			 direction, shotID, dt);
+			 direction, shotID, dt, shotTeam);
 }
 
 // Local Variables: ***
