@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,10 +13,6 @@
 #ifndef __WORLDWEAPON_H__
 #define __WORLDWEAPON_H__
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
-
 /* common header */
 #include "common.h"
 
@@ -28,8 +24,9 @@
 #include "TimeKeeper.h"
 
 #include "WorldEventManager.h"
+#include "PlayerInfo.h"
 
-#define _MAX_WORLD_SHOTS 30
+#define _MAX_WORLD_SHOTS 255
 
 /** WorldWeapons is a container class that holds weapons
  */
@@ -50,6 +47,7 @@ public:
   void *pack(void *buf) const;
 
   int getNewWorldShotID ( void );
+  int getNewWorldShotID(PlayerId player);
 
 private:
   struct Weapon
@@ -88,9 +86,9 @@ protected:
 	bz_eTeamType	team;
 };
 
-int fireWorldWep ( FlagType* type, float lifetime, PlayerId player, float *pos, float tilt, float direction, int shotID, float dt );
+int fireWorldWep ( FlagType* type, float lifetime, PlayerId player, float *pos, float tilt, float direction, float speed, int shotID, float dt, TeamColor shotTeam = RogueTeam );
 
-int fireWorldGM(FlagType* type, PlayerId targetPlayerID, float lifetime, PlayerId player, float *pos, float tilt, float direction, int shotID, float dt);
+int fireWorldGM(FlagType* type, PlayerId targetPlayerID, float lifetime, PlayerId player, float *pos, float tilt, float direction, int shotID, float dt, TeamColor shotTeam = RogueTeam);
 #endif
 
 // Local Variables: ***
