@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,81 +10,88 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning(4: 4786)
-#endif
 #include "common.h"
 #include <cmath>
 
 // interface header
 #include "BZDBCache.h"
 
-bool  BZDBCache::displayMainFlags;
-bool  BZDBCache::blend;
-bool  BZDBCache::texture;
-bool  BZDBCache::shadows;
-bool  BZDBCache::stencilShadows;
-bool  BZDBCache::zbuffer;
-bool  BZDBCache::tesselation;
-bool  BZDBCache::lighting;
-bool  BZDBCache::smooth;
-bool  BZDBCache::colorful;
-bool  BZDBCache::animatedTreads;
-bool  BZDBCache::leadingShotLine;
-int   BZDBCache::radarStyle;
-float BZDBCache::radarTankPixels;
-int   BZDBCache::linedRadarShots;
-int   BZDBCache::sizedRadarShots;
-int   BZDBCache::flagChunks;
-float BZDBCache::pulseRate;
-float BZDBCache::pulseDepth;
-bool  BZDBCache::showCollisionGrid;
-bool  BZDBCache::showCullingGrid;
+BZDBCache::Bool  BZDBCache::displayMainFlags;
+BZDBCache::Bool  BZDBCache::blend;
+BZDBCache::Bool  BZDBCache::texture;
+BZDBCache::Bool  BZDBCache::shadows;
+BZDBCache::Bool  BZDBCache::stencilShadows;
+BZDBCache::Bool  BZDBCache::zbuffer;
+BZDBCache::Bool  BZDBCache::useMeshForRadar;
+BZDBCache::Bool  BZDBCache::tesselation;
+BZDBCache::Bool  BZDBCache::lighting;
+BZDBCache::Bool  BZDBCache::smooth;
+BZDBCache::Bool  BZDBCache::colorful;
+BZDBCache::Bool  BZDBCache::animatedTreads;
+BZDBCache::Int   BZDBCache::leadingShotLine;
+BZDBCache::Int   BZDBCache::radarStyle;
+BZDBCache::Float BZDBCache::radarTankPixels;
+BZDBCache::Float BZDBCache::linedRadarShots;
+BZDBCache::Float BZDBCache::sizedRadarShots;
+BZDBCache::Int   BZDBCache::radarPosition;
+BZDBCache::Float BZDBCache::shotLength;
+BZDBCache::Int   BZDBCache::flagChunks;
+BZDBCache::Float BZDBCache::pulseRate;
+BZDBCache::Float BZDBCache::pulseDepth;
+BZDBCache::Int   BZDBCache::controlPanelTimestamp;
+BZDBCache::Bool  BZDBCache::showCollisionGrid;
+BZDBCache::Bool  BZDBCache::showCullingGrid;
 
-bool BZDBCache::drawCelestial;
-bool BZDBCache::drawClouds;
-bool BZDBCache::drawGround;
-bool BZDBCache::drawGroundLights;
-bool BZDBCache::drawMountains;
-bool BZDBCache::drawSky;
+BZDBCache::Bool  BZDBCache::drawCelestial;
+BZDBCache::Bool  BZDBCache::drawClouds;
+BZDBCache::Bool  BZDBCache::drawGround;
+BZDBCache::Bool  BZDBCache::drawGroundLights;
+BZDBCache::Bool  BZDBCache::drawMountains;
+BZDBCache::Bool  BZDBCache::drawSky;
 
-float BZDBCache::worldSize;
-float BZDBCache::radarLimit;
-float BZDBCache::gravity;
-float BZDBCache::tankWidth;
-float BZDBCache::tankLength;
-float BZDBCache::tankHeight;
-float BZDBCache::tankSpeed;
-float BZDBCache::tankRadius;
-float BZDBCache::flagRadius;
-float BZDBCache::flagPoleSize;
-float BZDBCache::flagPoleWidth;
-float BZDBCache::maxLOD;
+BZDBCache::Float BZDBCache::worldSize;
+BZDBCache::Float BZDBCache::radarLimit;
+BZDBCache::Float BZDBCache::gravity;
+BZDBCache::Float BZDBCache::tankWidth;
+BZDBCache::Float BZDBCache::tankLength;
+BZDBCache::Float BZDBCache::tankHeight;
+BZDBCache::Float BZDBCache::tankSpeed;
+BZDBCache::Float BZDBCache::tankRadius;
+BZDBCache::Float BZDBCache::flagRadius;
+BZDBCache::Float BZDBCache::flagPoleSize;
+BZDBCache::Float BZDBCache::flagPoleWidth;
+BZDBCache::Float BZDBCache::maxLOD;
 
-float BZDBCache::hudGUIBorderOpacityFactor;
+BZDBCache::Float BZDBCache::gmSize;
 
-static float getGoodPosValue (float oldVal, const std::string var )
+BZDBCache::Float BZDBCache::hudGUIBorderOpacityFactor;
+BZDBCache::Float BZDBCache::shotBrightness;
+
+
+static float getGoodPosValue(float oldVal, const std::string &var)
 {
-	float newVal = BZDB.eval(var);
-	if (isnan(newVal) || newVal <= 0.0f)	// it's bad
-	{
-		BZDB.setFloat(var,oldVal,BZDB.getPermission(var));
-		return oldVal;
-	}
-	return newVal;
+  float newVal = BZDB.eval(var);
+  if (isnan(newVal) || newVal <= 0.0f) {
+    // it's bad
+    BZDB.setFloat(var, oldVal, BZDB.getPermission(var));
+    return oldVal;
+  }
+  return newVal;
 }
 
-static float getGoodNonZeroValue (float oldVal, const std::string var )
+
+static float getGoodNonZeroValue(float oldVal, const std::string &var)
 {
-	float newVal = BZDB.eval(var);
-	if (isnan(newVal) || newVal == 0.0f)	// it's bad
-	{
-		BZDB.setFloat(var,oldVal,BZDB.getPermission(var));
-			return oldVal;
-	}
-	return newVal;
+  float newVal = BZDB.eval(var);
+  if (isnan(newVal) || newVal == 0.0f) {
+    // it's bad
+    BZDB.setFloat(var, oldVal, BZDB.getPermission(var));
+    return oldVal;
+  }
+  return newVal;
 }
 
+
 void BZDBCache::init()
 {
   // Client-side variables
@@ -96,18 +103,23 @@ void BZDBCache::init()
   BZDB.addCallback("shadows", clientCallback, NULL);
   BZDB.addCallback("stencilShadows", clientCallback, NULL);
   BZDB.addCallback("zbuffer", clientCallback, NULL);
+  BZDB.addCallback("useMeshForRadar", clientCallback, NULL);
   BZDB.addCallback("tesselation", clientCallback, NULL);
   BZDB.addCallback("lighting", clientCallback, NULL);
   BZDB.addCallback("smooth", clientCallback, NULL);
   BZDB.addCallback("colorful", clientCallback, NULL);
   BZDB.addCallback("animatedTreads", clientCallback, NULL);
+  BZDB.addCallback("shotLength", clientCallback, NULL);
   BZDB.addCallback("leadingShotLine", clientCallback, NULL);
+  BZDB.addCallback("radarPosition", clientCallback, NULL);
   BZDB.addCallback("flagChunks", clientCallback, NULL);
   BZDB.addCallback("pulseRate", clientCallback, NULL);
   BZDB.addCallback("pulseDepth", clientCallback, NULL);
+  BZDB.addCallback("controlPanelTimestamp", clientCallback, NULL);
   BZDB.addCallback("showCollisionGrid", clientCallback, NULL);
   BZDB.addCallback("showCullingGrid", clientCallback, NULL);
   BZDB.addCallback("hudGUIBorderOpacityFactor", clientCallback, NULL);
+  BZDB.addCallback("shotBrightness", clientCallback, NULL);
 
   // Server-side variables
   BZDB.addCallback(StateDatabase::BZDB_DRAWCELESTIAL, serverCallback, NULL);
@@ -127,6 +139,7 @@ void BZDBCache::init()
   BZDB.addCallback(StateDatabase::BZDB_FLAGRADIUS, serverCallback, NULL);
   BZDB.addCallback(StateDatabase::BZDB_FLAGPOLESIZE, serverCallback, NULL);
   BZDB.addCallback(StateDatabase::BZDB_FLAGPOLEWIDTH, serverCallback, NULL);
+  BZDB.addCallback(StateDatabase::BZDB_GMSIZE, serverCallback, NULL);
 
   drawCelestial = BZDB.isTrue(StateDatabase::BZDB_DRAWCELESTIAL);
   drawClouds = BZDB.isTrue(StateDatabase::BZDB_DRAWCLOUDS);
@@ -148,9 +161,12 @@ void BZDBCache::init()
   flagPoleSize = getGoodPosValue(flagPoleSize,StateDatabase::BZDB_FLAGPOLESIZE);
   flagPoleWidth = getGoodPosValue(flagPoleWidth,StateDatabase::BZDB_FLAGPOLEWIDTH);
 
+  gmSize = getGoodPosValue(flagPoleWidth,StateDatabase::BZDB_GMSIZE);
+
   update();
 }
 
+
 void BZDBCache::clientCallback(const std::string& name, void *)
 {
   if (name == "blend")
@@ -165,6 +181,8 @@ void BZDBCache::clientCallback(const std::string& name, void *)
     stencilShadows = BZDB.isTrue("stencilShadows");
   else if (name == "zbuffer")
     zbuffer = BZDB.isTrue("zbuffer");
+  else if (name == "useMeshForRadar")
+    useMeshForRadar = BZDB.isTrue("useMeshForRadar");
   else if (name == "tesselation")
     tesselation = BZDB.isTrue("tesselation");
   else if (name == "lighting")
@@ -179,22 +197,31 @@ void BZDBCache::clientCallback(const std::string& name, void *)
     radarTankPixels = BZDB.eval("radarTankPixels");
   else if (name == "animatedTreads")
     animatedTreads = BZDB.isTrue("animatedTreads");
+  else if (name == "shotLength")
+    shotLength = BZDB.eval("shotLength");
   else if (name == "leadingShotLine")
-    leadingShotLine = BZDB.isTrue("leadingShotLine");
+    leadingShotLine = BZDB.evalInt("leadingShotLine");
+  else if (name == "radarPosition")
+    radarPosition = BZDB.evalInt("radarPosition");
   else if (name == "flagChunks")
     flagChunks = BZDB.evalInt("flagChunks");
   else if (name == "pulseRate")
     pulseRate = BZDB.eval("pulseRate");
   else if (name == "pulseDepth")
     pulseDepth = BZDB.eval("pulseDepth");
+  else if (name == "controlPanelTimestamp")
+    controlPanelTimestamp = BZDB.evalInt("controlPanelTimestamp");
   else if (name == "showCollisionGrid")
     showCollisionGrid = BZDB.isTrue("showCollisionGrid");
   else if (name == "showCullingGrid")
     showCullingGrid = BZDB.isTrue("showCullingGrid");
   else if (name == "hudGUIBorderOpacityFactor")
-	hudGUIBorderOpacityFactor = BZDB.eval("hudGUIBorderOpacityFactor");
+    hudGUIBorderOpacityFactor = BZDB.eval("hudGUIBorderOpacityFactor");
+  else if (name == "shotBrightness")
+    shotBrightness = BZDB.eval("shotBrightness");
 }
 
+
 void BZDBCache::serverCallback(const std::string& name, void *)
 {
   if (name == StateDatabase::BZDB_DRAWCELESTIAL) {
@@ -249,12 +276,17 @@ void BZDBCache::serverCallback(const std::string& name, void *)
   else if (name == StateDatabase::BZDB_FLAGPOLEWIDTH) {
     flagPoleWidth = getGoodPosValue(flagPoleWidth,StateDatabase::BZDB_FLAGPOLEWIDTH);
   }
+  else if (name == StateDatabase::BZDB_GMSIZE) {
+    gmSize = getGoodPosValue(flagPoleWidth,StateDatabase::BZDB_GMSIZE);
+  }
 }
 
-void BZDBCache::update() {
+
+void BZDBCache::update()
+{
   tankRadius = BZDB.eval(StateDatabase::BZDB_TANKRADIUS);
-  linedRadarShots = static_cast<int>(BZDB.eval("linedradarshots"));
-  sizedRadarShots = static_cast<int>(BZDB.eval("sizedradarshots"));
+  linedRadarShots = BZDB.eval("linedradarshots");
+  sizedRadarShots = BZDB.eval("sizedradarshots");
 }
 
 
