@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -39,7 +39,7 @@ PlayerState::PlayerState()
   : order(0), status(DeadStatus), azimuth(0.0f), angVel(0.0f)
 {
   pos[0] = pos[1] = pos[2] = 0.0f;
-  velocity[0] = velocity[0] = velocity[2] = 0.0f;
+  velocity[0] = velocity[1] = velocity[2] = 0.0f;
   phydrv = -1;
   userSpeed = 0.0f;
   userAngVel = 0.0f;
@@ -144,7 +144,7 @@ void*	PlayerState::pack(void* buf, uint16_t& code)
 }
 
 
-void*	PlayerState::unpack(void* buf, uint16_t code)
+const void*	PlayerState::unpack(const void* buf, uint16_t code)
 {
   int32_t inOrder;
   int16_t inStatus;
