@@ -1,19 +1,15 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
- * named LICENSE that should have accompanied this file.
+ * named COPYING that should have accompanied this file.
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4:4786)
-#endif
-
 // interface header
 #include "VotingBooth.h"
 
@@ -61,7 +57,7 @@ VotingBooth *YesNoVotingBooth(std::string question)
 }
 
 
-bool VotingBooth::addResponse(const std::string response)
+bool VotingBooth::addResponse(const std::string &response)
 {
   if (response.size() == 0) {
     return false;
@@ -73,7 +69,7 @@ bool VotingBooth::addResponse(const std::string response)
 }
 
 
-bool VotingBooth::hasVoted(const std::string voterName) const
+bool VotingBooth::hasVoted(const std::string &voterName) const
 {
   if (voterName.size() <= 0) {
     return false;
@@ -85,7 +81,7 @@ bool VotingBooth::hasVoted(const std::string voterName) const
 }
 
 
-bool VotingBooth::vote(std::string voterName, std::string response)
+bool VotingBooth::vote(const std::string &voterName, const std::string &response)
 {
   if (this->hasVoted(voterName)) {
     /* voters are not allowed to vote multiple times */
@@ -104,7 +100,7 @@ bool VotingBooth::vote(std::string voterName, std::string response)
   return true;
 }
 
-bool VotingBooth::retractVote(const std::string voterName)
+bool VotingBooth::retractVote(const std::string &voterName)
 {
   VoterResponseMap::iterator i = _vote.find(voterName);
 
@@ -118,7 +114,7 @@ bool VotingBooth::retractVote(const std::string voterName)
   return false;
 }
 
-unsigned long int VotingBooth::getVoteCount(const std::string response) const
+unsigned long int VotingBooth::getVoteCount(const std::string &response) const
 {
   unsigned long int total=0;
 
