@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -11,6 +11,7 @@
  */
 
 #include "common.h"
+#include "version.h"
 
 /* system headers */
 #include <sstream>
@@ -20,64 +21,51 @@
 
 
 // opaque version number increments on protocol incompatibility
+// update the following files (and their protocol implementations) to match:
+//  misc/bzfquery.php
+//  misc/bzfquery.pl
+//  misc/bzfquery.py
+//  misc/bzls.lua
 #ifndef BZ_PROTO_VERSION
-#  define BZ_PROTO_VERSION	"0026"
+#  define BZ_PROTO_VERSION	"0221"
 #endif
 
-// version numbers - also update:
+// version numbers - also update as needed:
 //  ChangeLog
+//  MSVC/bzflag.rc
 //  README
-//  package/win32/nsis/*.nsi
-//  package/win32/*.nsi
-//  tools/TextTool-W32/TextTool.rc
-//  win32/VC6/installer.dsp
+//  configure.ac
+//  include/version.h
+//  package/win32/nsis/BZFlag.nsi
 #ifndef BZ_MAJOR_VERSION
 #  define BZ_MAJOR_VERSION	2
 #endif
 
 #ifndef BZ_MINOR_VERSION
-#  define BZ_MINOR_VERSION	0
+#  define BZ_MINOR_VERSION	4
 #endif
 
 #ifndef BZ_REV
-#  define BZ_REV		16
+#  define BZ_REV		6
 #endif
 
 // DEVEL | RC# | STABLE | MAINT
 #ifndef BZ_BUILD_TYPE
-#  define BZ_BUILD_TYPE		"DEVEL"
+#  define BZ_BUILD_TYPE		"MAINT"
 #endif
 
-const char *bzfcopyright = "Copyright (c) 1993-2010 Tim Riker";
+const char *bzfcopyright = "Copyright (c) 1993-2016 Tim Riker";
 
-
-//
-//  Although the ./configure process will generate
-//  -DBZ_BUILD_DATE for the build, here it's voided.
-//
-//  Could someone explain the reason for the
-//  inconience caused by the ./configure method? This
-//  way is simple, touch the *.cxx to get a new time
-//  stamp (no big recompiles). If this file is updated,
-//  you are also forced to get a new timestamp.
-//
-//  Using __DATE__ for all OSes is more consistent.
-//
-#undef BZ_BUILD_DATE
-
-
-#ifndef BZ_BUILD_DATE
-/* to get the version in the right format YYYYMMDD */
-/* yes this is horible but it needs to be done to get it right */
-/* windows should pull from a resouce */
-/* *nix gets this from the passed from my the Makefile */
-char buildDate[] = {__DATE__};
-
-int getBuildDate()
+static int getBuildDate()
 {
   int year = 1900, month = 0, day = 0;
+#ifdef BUILD_DATE
+  // the BUILD_DATE define looks like "YYYY-MM-DD"
+  sscanf(BUILD_DATE, "%d-%d-%d", &year, &month, &day);
+#else
   char monthStr[512];
-  sscanf(buildDate, "%s %d %d", monthStr, &day, &year);
+  // the __DATE__ macro looks like "Jun 15 2013" (*with* the quotes)
+  sscanf(__DATE__, "%s %d %d", monthStr, &day, &year);
 
   // we want it not as a name but a number
   if (strcmp(monthStr, "Jan") == 0)
@@ -104,12 +92,10 @@ int getBuildDate()
     month = 11;
   else if (strcmp(monthStr, "Dec") == 0)
     month = 12;
-
-  return (year*10000) + (month*100)+ day;
-}
 #endif
-// down here so above gets created
-#include "version.h"
+
+  return (year*10000) + (month*100) + day;
+}
 
 const char*		getProtocolVersion()
 {
@@ -151,10 +137,13 @@ const char*		getAppVersion()
   if (!appVersion.size()){
     std::ostringstream	appVersionStream;
     // TODO add current platform, release, cpu, etc
-    appVersionStream << getMajorMinorRevVersion() << "." << BZ_BUILD_DATE
+    appVersionStream << getMajorMinorRevVersion() << "." << getBuildDate()
 	<< "-" << BZ_BUILD_TYPE << "-" << BZ_BUILD_OS;
 #ifdef HAVE_SDL
     appVersionStream << "-SDL";
+#ifdef HAVE_SDL2
+    appVersionStream << "2";
+#endif
 #endif
     appVersion = appVersionStream.str();
   }
