@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -65,7 +65,7 @@ CacheManager::~CacheManager()
 }
 
 
-bool CacheManager::isCacheFileType(const std::string name) const
+bool CacheManager::isCacheFileType(const std::string &name) const
 {
   if (strncasecmp(name.c_str(), "http://", 7) == 0) {
     return true;
@@ -77,7 +77,7 @@ bool CacheManager::isCacheFileType(const std::string name) const
 }
 
 
-std::string CacheManager::getLocalName(const std::string name) const
+std::string CacheManager::getLocalName(const std::string &name) const
 {
   std::string local = "";
   if (strncasecmp(name.c_str(), "http://", 7) == 0) {
@@ -130,12 +130,12 @@ bool CacheManager::addFile(CacheRecord& record, const void* data)
     replacement = true;
   }
 
-  out->write((char*)data, rec->size);
+  out->write((const char *)data, rec->size);
 
   rec->usedDate = time(NULL); // update the timestamp
 
   MD5 md5;
-  md5.update((unsigned char *)data, rec->size);
+  md5.update((const unsigned char *)data, rec->size);
   md5.finalize();
   rec->key = md5.hexdigest();
 
