@@ -1,9 +1,9 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
- * named LICENSE that should have accompanied this file.
+ * named COPYING that should have accompanied this file.
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
@@ -12,12 +12,17 @@
 
 /* interface header */
 #include "NetHandler.h"
+// #include "MsgStrings.h"
 
 // system headers
 #include <errno.h>
 
 #include "bzfsAPI.h"
 
+#ifndef SHUT_RDWR
+  #define SHUT_RDWR -2
+#endif
+
 const int udpBufSize = 128000;
 
 std::vector<NetworkDataLogCallback*> logCallbacks;
@@ -110,8 +115,10 @@ void NetHandler::setFd(fd_set *read_set, fd_set *write_set, int &maxFile) {
 
   for (int i = 0; i < maxHandlers; i++) {
     NetHandler *player = netPlayer[i];
-    if (player) {
-      player->ares.setFd(read_set, write_set, maxFile);
+    if (player)
+    {
+      if (player->ares)
+	player->ares->setFd(read_set, write_set, maxFile);
     }
   }
 }
@@ -124,7 +131,6 @@ int NetHandler::udpReceive(char *buffer, struct sockaddr_in *uaddr,
 			   bool &udpLinkRequest) {
   AddrLen recvlen = sizeof(*uaddr);
   int n;
-  int id;
   uint16_t len;
   uint16_t code;
   while (true) {
@@ -134,18 +140,20 @@ int NetHandler::udpReceive(char *buffer, struct sockaddr_in *uaddr,
       break;
   }
   // Error receiving data (or no data)
-  if (n < 0)
+  if (n < 0 || uaddr->sin_port < 1024)
     return -1;
 
   // read head
-  void *buf = buffer;
+  const void *buf = buffer;
   buf = nboUnpackUShort(buf, len);
   buf = nboUnpackUShort(buf, code);
+//  if (code != MsgPlayerUpdateSmall && code != MsgPlayerUpdate)
+//    logDebugMessage(1,"rcvd %s len %d\n",MsgStrings::strMsgCode(code),len);
   if (n == 6 && len == 2 && code == MsgPingCodeRequest)
     // Ping code request
     return -2;
 
-  id = -1;
+  int id(-1);	  // player index of the matched player
   int pi;
   udpLinkRequest = false;
   for (pi = 0; pi < maxHandlers; pi++)
@@ -167,15 +175,15 @@ int NetHandler::udpReceive(char *buffer, struct sockaddr_in *uaddr,
 	  netPlayer[index]->uaddr.sin_port = uaddr->sin_port;
 	netPlayer[index]->udpin = true;
 	udpLinkRequest = true;
-	logDebugMessage(2,"Player %s [%d] inbound UDP up %s:%d actual %d\n",
-	       netPlayer[index]->info->getCallSign(), index,
+	logDebugMessage(2,"Player slot %d inbound UDP up %s:%d actual %d\n",
+	       index,
 	       inet_ntoa(uaddr->sin_addr),
 	       ntohs(netPlayer[index]->uaddr.sin_port),
 	       ntohs(uaddr->sin_port));
       } else {
-	logDebugMessage(2,"Player %s [%d] inbound UDP rejected %s:%d different IP \
+	logDebugMessage(2,"Player slot %d inbound UDP rejected %s:%d different IP \
 than %s:%d\n",
-	   netPlayer[index]->info->getCallSign(), index,
+	   index,
 	   inet_ntoa(netPlayer[index]->uaddr.sin_addr),
 	   ntohs(netPlayer[index]->uaddr.sin_port),
 	   inet_ntoa(uaddr->sin_addr), ntohs(uaddr->sin_port));
@@ -184,20 +192,20 @@ than %s:%d\n",
   }
 
   if (id == -1) {
+	  if (debugLevel < 4)
+		  return -1;
     // no match, discard packet
-    logDebugMessage(2,"uread() discard packet! %s:%d choices p(l) h:p",
+    logDebugMessage(3,"uread() discard packet! %s:%d choices p(l) h:p",
 	   inet_ntoa(uaddr->sin_addr), ntohs(uaddr->sin_port));
-    for (pi = 0; pi < maxHandlers; pi++) {
-      if (netPlayer[pi] && !netPlayer[pi]->closed)
-	logDebugMessage(3," %d(%d-%d) %s:%d", pi, netPlayer[pi]->udpin,
-	       netPlayer[pi]->udpout,
-	       inet_ntoa(netPlayer[pi]->uaddr.sin_addr),
-	       ntohs(netPlayer[pi]->uaddr.sin_port));
+    for (pi = 0; pi < maxHandlers; pi++)
+	{
+		if (netPlayer[pi] && !netPlayer[pi]->closed)
+			logDebugMessage(4," %d(%d-%d) %s:%d", pi, netPlayer[pi]->udpin,  netPlayer[pi]->udpout,  inet_ntoa(netPlayer[pi]->uaddr.sin_addr), ntohs(netPlayer[pi]->uaddr.sin_port));
     }
-    logDebugMessage(2,"\n");
+    logDebugMessage(3,"\n");
   } else {
-    logDebugMessage(4,"Player %s [%d] uread() %s:%d len %d from %s:%d on %i\n",
-	   netPlayer[id]->info->getCallSign(), id,
+    logDebugMessage(4,"Player slot %d uread() %s:%d len %d from %s:%d on %i\n",
+	   id,
 	   inet_ntoa(netPlayer[id]->uaddr.sin_addr),
 	   ntohs(netPlayer[id]->uaddr.sin_port), n,
 	   inet_ntoa(uaddr->sin_addr), ntohs(uaddr->sin_port),
@@ -210,8 +218,7 @@ than %s:%d\n",
 
     if (code == MsgUDPLinkEstablished) {
       netPlayer[id]->udpout = true;
-      logDebugMessage(2,"Player %s [%d] outbound UDP up\n",
-	      netPlayer[id]->info->getCallSign(), id);
+      logDebugMessage(2,"Player %d outbound UDP up\n", id);
     }
   }
   return id;
@@ -228,7 +235,10 @@ void NetHandler::checkDNS(fd_set *read_set, fd_set *write_set) {
   for (int i = 0; i < maxHandlers; i++) {
     NetHandler *player = netPlayer[i];
     if (player)
-      player->ares.process(read_set, write_set);
+    {
+      if (player->ares)
+	player->ares->process(read_set, write_set);
+    }
   }
 }
 
@@ -237,17 +247,14 @@ NetHandler *NetHandler::netPlayer[maxHandlers] = {NULL};
 
 NetHandler::NetHandler(PlayerInfo* _info, const struct sockaddr_in &clientAddr,
 		       int _playerIndex, int _fd)
-  : ares(_playerIndex), info(_info), playerIndex(_playerIndex), fd(_fd),
+  : ares(new AresHandler(_playerIndex)), info(_info), uaddr(clientAddr),
+    playerIndex(_playerIndex), fd(_fd), peer(clientAddr),
     tcplen(0), closed(false),
-    outmsgOffset(0), outmsgSize(0), outmsgCapacity(0), outmsg(NULL),
-    udpOutputLen(0), udpin(false), udpout(false), toBeKicked(false) {
-  // store address information for player
-  AddrLen addr_len = sizeof(clientAddr);
-  memcpy(&uaddr, &clientAddr, addr_len);
-  peer = Address(uaddr);
-
+    outmsgOffset(0), outmsgSize(0), outmsgCapacity(0), outmsg(0),
+    udpOutputLen(0), udpin(false), udpout(false), toBeKicked(false),
+    time(_info->now)
+{
   // update player state
-  time = info->now;
 #ifdef NETWORK_STATS
 
   // initialize the inbound/outbound counters to zero
@@ -265,19 +272,69 @@ NetHandler::NetHandler(PlayerInfo* _info, const struct sockaddr_in &clientAddr,
   perSecondCurrentBytes[1] = 0;
   perSecondMaxBytes[1] = 0;
 
+  acceptUDP = true;
+
 #endif
   if (!netPlayer[playerIndex])
     netPlayer[playerIndex] = this;
-  ares.queryHostname((struct sockaddr *) &clientAddr);
+  ares->queryHostname((const struct sockaddr *) &clientAddr);
+}
+
+NetHandler::NetHandler(const struct sockaddr_in &_clientAddr, int _fd)
+  : ares(0), info(0), playerIndex(-1), fd(_fd),
+    tcplen(0), closed(false),
+    outmsgOffset(0), outmsgSize(0), outmsgCapacity(0), outmsg(0),
+    udpOutputLen(0), udpin(false), udpout(false), toBeKicked(false),
+    time(TimeKeeper::getCurrent())
+{
+  // store address information for player
+  AddrLen addr_len = sizeof(_clientAddr);
+  memcpy(&uaddr, &_clientAddr, addr_len);
+  peer = Address(uaddr);
+
+#ifdef NETWORK_STATS
+
+  // initialize the inbound/outbound counters to zero
+  msgBytes[0] = 0;
+  perSecondTime[0] = time;
+  perSecondCurrentMsg[0] = 0;
+  perSecondMaxMsg[0] = 0;
+  perSecondCurrentBytes[0] = 0;
+  perSecondMaxBytes[0] = 0;
+
+  msgBytes[1] = 0;
+  perSecondTime[1] = time;
+  perSecondCurrentMsg[1] = 0;
+  perSecondMaxMsg[1] = 0;
+  perSecondCurrentBytes[1] = 0;
+  perSecondMaxBytes[1] = 0;
+
+  acceptUDP = true;
+
+#endif
+}
+
+void NetHandler::setPlayer ( PlayerInfo* p, int index )
+{
+  ares = new AresHandler(index);
+
+  playerIndex = index;
+  info = p;
+
+  if (!netPlayer[playerIndex])
+    netPlayer[playerIndex] = this;
+  ares->queryHostname((struct sockaddr *) &uaddr);
 }
 
 NetHandler::~NetHandler() {
 #ifdef NETWORK_STATS
-  if (info->isPlaying())
+  if (info && info->isPlaying())
     dumpMessageStats();
 #endif
+  if (ares)
+    delete(ares);
   // shutdown TCP socket
-  shutdown(fd, 2);
+  shutdown(fd, SHUT_RDWR);
   close(fd);
 
   delete[] outmsg;
@@ -342,7 +399,7 @@ int NetHandler::bufferedSend(const void *buffer, size_t length) {
       return -1;
     }
     if (n > 0) {
-      buffer  = (void*)(((const char*)buffer) + n);
+      buffer  = (const void*)(((const char*)buffer) + n);
       length -= n;
     }
   }
@@ -359,8 +416,10 @@ int NetHandler::bufferedSend(const void *buffer, size_t length) {
       // are the network is down or too unreliable to that player.
       // FIXME -- is 20kB too big?  too small?
       if (newCapacity >= 20 * 1024) {
-	logDebugMessage(2,"Player %s [%d] drop, unresponsive with %d bytes queued\n",
-	       info->getCallSign(), playerIndex, outmsgSize + length);
+	if (info != NULL && playerIndex >= 0) {
+	  logDebugMessage(2,"Player %s [%d] drop, unresponsive with %d bytes queued\n",
+		info->getCallSign(), playerIndex, outmsgSize + length);
+	}
 	toBeKicked = true;
 	toBeKickedReason = "send queue too big";
 	return 0;
@@ -399,6 +458,11 @@ void NetHandler::closing()
   closed = true;
 }
 
+void NetHandler::SetAllowUDP(bool set)
+{
+	acceptUDP = set;
+}
+
 int NetHandler::pwrite(const void *b, int l) {
 
   if (l == 0) {
@@ -408,10 +472,12 @@ int NetHandler::pwrite(const void *b, int l) {
   if (closed)
     return 0;
 
-  void *buf = (void *)b;
+  const void *buf = b;
   uint16_t len, code;
   buf = nboUnpackUShort(buf, len);
   buf = nboUnpackUShort(buf, code);
+//  if (code != MsgPlayerUpdateSmall && code != MsgPlayerUpdate && code != MsgGameTime)
+//    logDebugMessage(1,"send %s len %d\n",MsgStrings::strMsgCode(code),len);
 #ifdef NETWORK_STATS
   countMessage(code, len, 1);
 #endif
@@ -455,24 +521,28 @@ int NetHandler::pflush(fd_set *set) {
 RxStatus NetHandler::tcpReceive() {
   // read header if we don't have it yet
   RxStatus e = receive(4);
-  if (e != ReadAll)
+  if (e != ReadAll) {
     // if header not ready yet then skip the read of the body
     return e;
-
+  }
+  
   // read body if we don't have it yet
   uint16_t len, code;
-  void *buf = tcpmsg;
+  const void *buf = tcpmsg;
   buf = nboUnpackUShort(buf, len);
   buf = nboUnpackUShort(buf, code);
+//  logDebugMessage(1,"rcvd %s len %d\n",MsgStrings::strMsgCode(code),len);
   if (len > MaxPacketLen) {
     logDebugMessage(1,"Player [%d] sent huge packet length (len=%d), possible attack\n",
 	   playerIndex, len);
     return ReadHuge;
   }
+  // We haven't accounted for the header yet, so only ask receive() to get len (the payload) more bytes.
   e = receive(4 + (int) len);
-  if (e != ReadAll)
+  if (e != ReadAll) {
     // if body not ready yet then skip the command handling
     return e;
+  }
 
   // clear out message
   tcplen = 0;
@@ -482,18 +552,32 @@ RxStatus NetHandler::tcpReceive() {
 
   callNetworkDataLog (false, false, (const unsigned char*)buf,len,this);
 
-  if (code == MsgUDPLinkEstablished) {
-    udpout = true;
-    logDebugMessage(2,"Player %s [%d] outbound UDP up\n", info->getCallSign(),
-	   playerIndex);
+  if (code == MsgUDPLinkEstablished)
+  {
+	  if (!acceptUDP)
+	  {
+		  closing();
+		  return ReadError;
+	  }
+	  else
+	  {
+		  udpout = true;
+		  logDebugMessage(2,"Player %s [%d] outbound UDP up\n", info->getCallSign(), playerIndex);
+	  }
   }
   return ReadAll;
 }
 
-RxStatus NetHandler::receive(size_t length) {
-  RxStatus returnValue;
-  if ((int)length <= tcplen)
-    return ReadAll;
+RxStatus NetHandler::receive(size_t length, bool *retry) {
+  RxStatus returnValue(ReadError);
+  
+  if (retry)
+    *retry = false;
+
+  // Degenerate case, becase a closed socket should not be sending data, but be paranoid and test for it anyway
+  if (closed) return returnValue;
+  
+  if ((int)length <= tcplen) return ReadAll;
   int size = recv(fd, tcpmsg + tcplen, (int)length - tcplen, 0);
   if (size > 0) {
     tcplen += size;
@@ -507,9 +591,11 @@ RxStatus NetHandler::receive(size_t length) {
     const int err = getErrno();
 
     // ignore if it's one of these errors
-    if (err == EAGAIN || err == EINTR)
+    if (err == EAGAIN || err == EINTR){
+      if (retry)
+	*retry = true;
       returnValue = ReadPart;
-    else if (err == ECONNRESET || err == EPIPE) {
+    } else if (err == ECONNRESET || err == EPIPE) {
       // if socket is closed then give up
       returnValue = ReadReset;
     } else {
@@ -602,7 +688,7 @@ void NetHandler::dumpMessageStats() {
     logDebugMessage(1,"Player messages %s:", direction ? "out" : "in");
 
     for (MessageCountMap::iterator i = msg[direction].begin();
-	 i != msg[direction].end(); i++) {
+	 i != msg[direction].end(); ++i) {
       logDebugMessage(1," %c%c:%u(%u)", i->first >> 8, i->first & 0xff,
 	     i->second.count, i->second.maxSize);
       total += i->second.count;
@@ -659,8 +745,8 @@ bool NetHandler::isMyUdpAddrPort(struct sockaddr_in _uaddr) {
     (memcmp(&uaddr.sin_addr, &_uaddr.sin_addr, sizeof(uaddr.sin_addr)) == 0);
 }
 
-void NetHandler::getPlayerList(char *list) {
-  sprintf(list, "[%d]%-16s: %s%s%s%s%s%s", playerIndex, info->getCallSign(),
+const std::string NetHandler::getPlayerHostInfo() {
+  return TextUtils::format("%s%s%s%s%s%s",
 	  peer.getDotNotation().c_str(),
 	  getHostname() ? " (" : "",
 	  getHostname() ? getHostname() : "",
@@ -710,12 +796,17 @@ in_addr NetHandler::getIPAddress() {
 }
 
 const char *NetHandler::getHostname() {
-  return ares.getHostname();
+  if (!ares)
+    return NULL;
+  return ares->getHostname();
 }
 
 bool NetHandler::reverseDNSDone()
 {
-  AresHandler::ResolutionStatus status = ares.getStatus();
+  if (!ares)
+    return false;
+
+  AresHandler::ResolutionStatus status = ares->getStatus();
   return (status == AresHandler::Failed)
     || (status == AresHandler::HbASucceeded);
 }
