@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -42,7 +42,7 @@ using namespace TankGeometryUtils;
 static GLuint displayLists[LastTankShadow][LastTankLOD]
 			  [LastTankSize][LastTankPart];
 
-// triangle counds
+// triangle counts
 static int partTriangles[LastTankShadow][LastTankLOD]
 			[LastTankSize][LastTankPart];
 
@@ -287,7 +287,7 @@ const float* TankGeometryMgr::getScaleFactor(TankSize size)
 // ---------------
 
 
-static void bzdbCallback(const std::string& /*name*/, void * /*data*/)
+static void bzdbCallback(const std::string& UNUSED(name), void * UNUSED(data))
 {
   deleteLists();
   buildLists();
@@ -295,7 +295,7 @@ static void bzdbCallback(const std::string& /*name*/, void * /*data*/)
 }
 
 
-static void freeContext(void * /*data*/)
+static void freeContext(void * UNUSED(data))
 {
   // delete all of the lists
   deleteLists();
@@ -303,7 +303,7 @@ static void freeContext(void * /*data*/)
 }
 
 
-static void initContext(void * /*data*/)
+static void initContext(void * UNUSED(data))
 {
   buildLists();
   return;
@@ -403,4 +403,3 @@ void TankGeometryUtils::doTexCoord2f(GLfloat x, GLfloat y)
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
