@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -65,6 +65,7 @@ void GroupInstance::init()
   material = NULL;
   driveThrough = false;
   shootThrough = false;
+  ricochet     = false;
 
   return;
 }
@@ -156,6 +157,12 @@ void GroupInstance::setShootThrough()
   return;
 }
 
+void GroupInstance::setCanRicochet()
+{
+  ricochet = true;
+  return;
+}
+
 
 void GroupInstance::addMaterialSwap(const BzMaterial* srcMat,
 				    const BzMaterial* dstMat)
@@ -196,7 +203,7 @@ void* GroupInstance::pack(void* buf)
     p = nboPackUByte(buffer, 0); // terminate
     p = nboPackInt(p, count);
     MaterialMap::const_iterator it;
-    for (it = matMap.begin(); it != matMap.end(); it++) {
+    for (it = matMap.begin(); it != matMap.end(); ++it) {
       int srcIndex = MATERIALMGR.getIndex(it->first);
       int dstIndex = MATERIALMGR.getIndex(it->second);
       p = nboPackInt(p, srcIndex);
@@ -218,6 +225,7 @@ void* GroupInstance::pack(void* buf)
   if (modifyMaterial)	   bits |= (1 << 3);
   if (driveThrough)	   bits |= (1 << 4);
   if (shootThrough)	   bits |= (1 << 5);
+  if (ricochet)	    bits |= (1 << 6);
   buf = nboPackUByte(buf, bits);
 
   if (modifyTeam) {
@@ -239,14 +247,14 @@ void* GroupInstance::pack(void* buf)
 }
 
 
-void* GroupInstance::unpack(void* buf)
+const void* GroupInstance::unpack(const void* buf)
 {
   buf = nboUnpackStdString(buf, groupdef);
 
   buf = nboUnpackStdStringRaw(buf, name);
   if (strlen(name.c_str()) != name.size()) {
     // hack to extract material map data
-    void* p = (void*)(name.c_str() + strlen(name.c_str()) + 1);
+    const void* p = name.c_str() + strlen(name.c_str()) + 1;
     nboUseErrorChecking(false);
     {
       int32_t count;
@@ -274,6 +282,7 @@ void* GroupInstance::unpack(void* buf)
   modifyMaterial =	((bits & (1 << 3)) == 0) ? false : true;
   driveThrough =	((bits & (1 << 4)) == 0) ? false : true;
   shootThrough =	((bits & (1 << 5)) == 0) ? false : true;
+  ricochet =	    ((bits & (1 << 6)) == 0) ? false : true;
 
   if (modifyTeam) {
     uint16_t tmpTeam;
@@ -365,7 +374,7 @@ void GroupInstance::print(std::ostream& out, const std::string& indent) const
   }
   else if (matMap.size() > 0) {
     MaterialMap::const_iterator it;
-    for (it = matMap.begin(); it != matMap.end(); it++) {
+    for (it = matMap.begin(); it != matMap.end(); ++it) {
       out << indent << "  matswap ";
       MATERIALMGR.printReference(out, it->first);
       out << " ";
@@ -374,13 +383,9 @@ void GroupInstance::print(std::ostream& out, const std::string& indent) const
     }
   }
 
-  if (driveThrough) {
-    out << indent << "  driveThrough " << phydrv << std::endl;
-  }
-  if (shootThrough) {
-    out << indent << "  shootTHrough " << phydrv << std::endl;
-  }
-
+  if (driveThrough) {out << indent << "  driveThrough"  << std::endl;}
+  if (shootThrough) {out << indent << "  shootThrough"  << std::endl;}
+  if (ricochet)     {out << indent << "  ricochet"      << std::endl;}
   out << indent << "end" << std::endl;
 
   return;
@@ -543,7 +548,7 @@ void GroupDefinition::appendGroupName(const GroupInstance* group) const
 }
 
 
-static MeshObstacle* makeContainedMesh(int type, const Obstacle* obs)
+static MeshObstacle* makeContainedMesh(int type, Obstacle* obs)
 {
   MeshObstacle* mesh = NULL;
   switch (type) {
@@ -572,7 +577,7 @@ void GroupDefinition::makeGroups(const MeshTransform& xform,
 				 const ObstacleModifier& obsMod) const
 {
   if (active) {
-    DEBUG1("warning: avoided recursion, groupdef \"%s\"\n", name.c_str());
+    logDebugMessage(1,"warning: avoided recursion, groupdef \"%s\"\n", name.c_str());
     return; // avoid recursion
   }
 
@@ -655,7 +660,7 @@ void GroupDefinition::makeGroups(const MeshTransform& xform,
       depthName = tmpDepthName;
     }
     else {
-      DEBUG1("warning: group definition \"%s\" is missing\n",
+      logDebugMessage(1,"warning: group definition \"%s\" is missing\n",
 	     group->getGroupDef().c_str());
     }
   }
@@ -676,7 +681,7 @@ void GroupDefinition::replaceBasesWithBoxes()
       new BoxBuilding(base->getPosition(), base->getRotation(),
 		      baseSize[0], baseSize[1], baseSize[2],
 		      base->isDriveThrough(), base->isShootThrough(),
-		      false);
+		      base->canRicochet(), false);
     delete base;
     list.remove(i);
     i--;
@@ -736,7 +741,7 @@ void GroupDefinition::deleteInvalidObstacles()
     for (unsigned int i = 0; i < list.size(); i++) {
       Obstacle* obs = list[i];
       if (!obs->isValid()) {
-	DEBUG1("Deleted invalid %s obstacle\n", obs->getType());
+	logDebugMessage(1,"Deleted invalid %s obstacle\n", obs->getType());
 	delete obs;
 	list.remove(i);
 	i--; // don't miss the substitute
@@ -811,7 +816,7 @@ void* GroupDefinition::pack(void* buf) const
 }
 
 
-void* GroupDefinition::unpack(void* buf)
+const void* GroupDefinition::unpack(const void* buf)
 {
   buf = nboUnpackStdString(buf, name);
 
@@ -882,7 +887,7 @@ void GroupDefinition::printGrouped(std::ostream& out,
   for (int type = 0; type < ObstacleTypeCount; type++) {
     const ObstacleList& list = getList(type);
     for (unsigned int i = 0; i < list.size(); i++) {
-      const Obstacle* obs = list[i];
+      Obstacle* obs = list[i];
 
       if (!obs->isFromGroupDef() && !obs->isFromContainer()) {
 	if (!saveAsMeshes) {
@@ -1005,8 +1010,8 @@ void GroupDefinitionMgr::tighten()
 
 static int compareHeights(const void* a, const void* b)
 {
-  const Obstacle* obsA = *((const Obstacle**)a);
-  const Obstacle* obsB = *((const Obstacle**)b);
+  const Obstacle* obsA = *((const Obstacle* const *)a);
+  const Obstacle* obsB = *((const Obstacle* const *)b);
   const Extents& eA = obsA->getExtents();
   const Extents& eB = obsB->getExtents();
 
@@ -1097,7 +1102,7 @@ void* GroupDefinitionMgr::pack(void* buf) const
 }
 
 
-void* GroupDefinitionMgr::unpack(void* buf)
+const void* GroupDefinitionMgr::unpack(const void* buf)
 {
   buf = world.unpack(buf);
   uint32_t i, count;
@@ -1167,4 +1172,3 @@ void GroupDefinitionMgr::print(std::ostream& out,
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
