@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -33,7 +33,7 @@ TeleporterSceneNodeGenerator::~TeleporterSceneNodeGenerator()
 }
 
 WallSceneNode*		TeleporterSceneNodeGenerator::getNextNode(
-				float /*uRepeats*/, float /*vRepeats*/,
+				float UNUSED(uRepeats), float UNUSED(vRepeats),
 				bool lod)
 {
   static const float texCoords[][4][2] = {
