@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,33 +20,9 @@
 
 #include "BzfJoystick.h"
 
-#if !defined(BROKEN_DINPUT)
-
-  // only require a runtime that has what we actually use (e.g. force feedback support)
-  #define DIRECTINPUT_VERSION 0x0700
-  #include <dinput.h>
-
-  // Don't try compile this if we don't have an up-to-date DX
-  #if defined(DIRECTINPUT_HEADER_VERSION) && (DIRECTINPUT_HEADER_VERSION >= 0x0700)
-    // We can use DInput.  It's not broken, and it's new enough
-    #define USE_DINPUT 1
-  #else
-    // DInput is not new enough to use
-    #if defined(USE_DINPUT)
-      #undef USE_DINPUT
-    #endif
-  #endif
-
-#else
-
-  // Make sure we don't use DInput at all (even headers) if it's broken
-  #if defined(USE_DINPUT)
-  #undef USE_DINPUT
-  #endif
-
-#endif
-
-#if defined(USE_DINPUT)
+// only require a runtime that has what we actually use (e.g. force feedback support)
+#define DIRECTINPUT_VERSION 0x0800
+#include <dinput.h>
 
 #include <vector>
 #include <string>
@@ -63,10 +39,12 @@ class DXJoystick : public BzfJoystick {
     bool	joystick() const;
     void	getJoy(int& x, int& y);
     unsigned long getJoyButtons();
+    int 	getNumHats();
+    void	getJoyHat(int hat, float &hatX, float &hatY);
     void	getJoyDevices(std::vector<std::string> &list) const;
     void	getJoyDeviceAxes(std::vector<std::string> &list) const;
-    void	setXAxis(const std::string axis);
-    void	setYAxis(const std::string axis);
+    void	setXAxis(const std::string &axis);
+    void	setYAxis(const std::string &axis);
     bool	ffHasRumble() const;
     void	ffRumble(int count,
 			 float delay, float duration,
@@ -84,31 +62,34 @@ class DXJoystick : public BzfJoystick {
     void	ffDirectionalResistance(float time, float coefficient,
 				      float saturation, ResistanceType type);
 
+	int		numberOfHats;
   private:
     DIJOYSTATE	pollDevice();
     void	reaquireDevice();
     void	enumerateDevices();
     void	resetFF();
 
+
+
     void	DXError(const char* situation, HRESULT problem);
 
     std::map<std::string,bool> axes;
     std::string xAxis;
     std::string yAxis;
+   
+    std::vector<float> hataxes;
 
     static std::vector<DIDEVICEINSTANCE> devices;
     static EffectMap effectDatabase;
 
-    IDirectInput7* directInput;
-    IDirectInputDevice7* device;
+    IDirectInput8* directInput;
+    IDirectInputDevice8* device;
 
     /* Nasty callbacks 'cause DirectX sucks */
 
     static BOOL CALLBACK deviceEnumCallback(LPCDIDEVICEINSTANCE device, void*);
 };
 
-#endif // USE_DINPUT
-
 #endif // BZF_DXJOY_H
 
 // Local Variables: ***
