@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,7 +12,13 @@
 
 #include "SDLPlatformFactory.h"
 #include "SDLMedia.h"
+#ifdef HAVE_SDL2
+#include "SDL2Display.h"
+#include "SDL2Visual.h"
+#include "SDL2Window.h"
+#else
 #include "SDLDisplay.h"
+#endif
 #include "SDLJoystick.h"
 #include "EvdevJoystick.h"
 
@@ -80,4 +86,3 @@ BzfJoystick* SdlPlatformFactory::createJoystick()
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
