@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -213,7 +213,7 @@ bool XDisplay::setupEvent(BzfEvent& event, const XEvent& xevent) const
       break;
 
     case ClientMessage: {
-      XClientMessageEvent* cme = (XClientMessageEvent*)&xevent;
+      const XClientMessageEvent* cme = (const XClientMessageEvent*)&xevent;
       if (cme->format == 32) {
 	if ((Atom)cme->data.l[0] == XInternAtom(rep->getDisplay(),
 					"WM_DELETE_WINDOW", true)) {
@@ -234,7 +234,8 @@ bool			XDisplay::getKey(const XEvent& xevent,
 {
   char buf[3];
   KeySym keysym;
-  if (XLookupString((XKeyEvent*)&xevent.xkey, buf, 1, &keysym, NULL) == 1) {
+  XKeyEvent xkey = xevent.xkey;		// non-const copy
+  if (XLookupString(&xkey, buf, 1, &keysym, NULL) == 1) {
     key.ascii = buf[0];
     key.button = BzfKeyEvent::NoButton;
 
@@ -280,9 +281,9 @@ bool			XDisplay::getKey(const XEvent& xevent,
   return true;
 }
 
-bool			XDisplay::doSetResolution(int modeIndex)
+bool			XDisplay::doSetResolution(int _modeIndex)
 {
-  return mode->set(modeIndex);
+  return mode->set(_modeIndex);
 }
 
 bool			XDisplay::doSetDefaultResolution()
@@ -328,4 +329,3 @@ bool			XDisplayMode::setDefault(int mode)
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
