@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2010 Tim Riker
+ * Copyright (c) 1993-2016 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -37,8 +37,8 @@
 // utility function
 static int compareZExtents(const void* a, const void* b)
 {
-  const SceneNode* nodeA = *((const SceneNode**)a);
-  const SceneNode* nodeB = *((const SceneNode**)b);
+  const SceneNode* nodeA = *((const SceneNode* const *)a);
+  const SceneNode* nodeB = *((const SceneNode* const *)b);
   const Extents& eA = nodeA->getExtents();
   const Extents& eB = nodeB->getExtents();
   if (eA.maxs[2] > eB.maxs[2]) {
@@ -90,7 +90,7 @@ void ZSceneDatabase::finalizeStatics()
 }
 
 
-bool ZSceneDatabase::addStaticNode(SceneNode* object, bool /*dontFree*/)
+bool ZSceneDatabase::addStaticNode(SceneNode* object, bool UNUSED(dontFree))
 {
   if (staticCount == staticSize) {
     if (staticSize == 0) staticSize = 15;
